#----------------------------------------------------------------------
# This file was generated by makeicons.py
#
from wx.lib.embeddedimage import PyEmbeddedImage

catalog = {}
index = []

eelbrain160 = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAKAAAACgCAYAAACLz2ctAAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAuIwAALiMBeKU/dgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAAEl0RVh0Q29weXJpZ2h0AFB1Ymxp"
    "YyBEb21haW4gaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9t"
    "YWluL1nD/soAACAASURBVHic7V13nFTV2X7ec6fsUhXpEkVFygoIiiX4qZRVAY0tsiFRFBuI"
    "ClGKmmhCNkZRQKwooJ9o7PiZ/OyVYolBQBRFUEFFRZalqEjbnZl7nu+PaffO3Gk7d3YXnef3"
    "2505Z055z73Pfd/3nHuKkEQRRTQUVEMLUMQvG56GFqAxo7KyUr3nO3o/M6DbUdjOJHYsmHLa"
    "0liC6mtPhzZ7Q0QQfpjDn8IagDtB/ATonaCxAwZ3gNwBw7sNrW/d2FBtamz4xRLwlBmvNZUA"
    "u4lS3Uj9KwDtSLYl2U6AdppsB9WvNUPagBAENSC/jhVQNak1BPdDsRmQwo0RAFCAMJJEANMk"
    "qiY+iQ47xwJzgtGk/Sc81sukOUqEn2mozzTl8+W3n1dVyGvQGPCLIeCp0xe3B/VQwhxG4lhF"
    "6UQFkDrMDRJRf1iTABiPB0HyvoVTfhPXfgauAdksd0koUPg9Njfbhra4Nhrrr/V9tdu/5woS"
    "fkBDkTjqqnk/Aficmp+B+jOCS1u03rhg0ZQpoXyuRWOC/Nw7IafdtuhsrXk9yL4AJdzcCNkY"
    "oRnjZLN+D/8GgKjywej+0pShPwEAqq46AIZnJUhf3SUTjVCgB/a/a0M05piJD71CLacg+gA4"
    "y7qZwFMKfGz5PaPfq3v9jQM/Ww049JbFnZWH94A8NWoiozc0bjEt3yMPYpx8iN10Qq6LkQ8A"
    "4PlLfuQDACp4/CMBTI3GiJbnCZ5ilTWqH6IPA4G2IMeZwLi+l89dB9GPwZTHPpg9Zm1+8jQM"
    "9uJesAi2TOiCqslnAZW2B+mMOxe0Ux6+GyNflE1w0HqIm146mF4QH52I9x+NFV51dQ8ojHCn"
    "DTwfqIzdgxDV8zH5kEzC5AeGXUCZAoXP+46d8+YRl83p545c9Ye9yARXGNjSuT9MDgbYD8AR"
    "ELYE5XK0n/FwNFVlZaVa1vSEVwmWh3mW1pylNb0kIeDQN6ac/kpMjM2T54P6VPfa5Tkd7W5d"
    "EA0dddWDK0HpnU7WNPeMAB4KBY0/fXz/JdXuyVg4NG4TvGFCKbyewYD+DeSAYaDZKtyzjIB4"
    "2Eo+AFjW9MTJMfLlaXoBLLSRr3risQBcJB8AhE4HECOgQF4m2NvB9Fq0dkoIgAs9PnNY3yvu"
    "P/uDWZe+666s7qNxmuBNf26DTZP/Do9aD5hPATwPZCt7IlkLUZOtMcPuftlPcGLUic/T9FKD"
    "11rLh8jf3W+s9LKGNLEms+nNAKIdqBf1vXzuJS4KWhA0LgJuvbYjNk+aBgmugeiJkFTDHBJC"
    "SI1Cu+m7rLEqUDoCYBsgrRNv1yTxBIjd5fD3pxZNOX15rPCqSaeAPC7vNia35TBA4npd+IXt"
    "4XF4YLKED+D9fS+fO9pNad1G4yBg1aQjUT1pDrT5CcgrAF2aNj2xFvtP+zApmhznjumVoIJx"
    "va1wxb/VqW0ZoZth87iDY0EJfREWJSfTmwa8t+9lc4blK2Wh0HAE3DChFJsnno/NE9+B4lsR"
    "M5vd0IbC14lRw6YvPATkkS6YXgB6zutTTv0yVvimCUcD6J1Ha9OD/p7Rr+/fMXoTid2RH3Iz"
    "vc4woPBUn7Gz97fFVk9uC1TWYSDdXdRvJ+T7yhYI7jwR0OXwqOEgW9axpCQCirAcFDdMLxHS"
    "d9gLV+chDx2UEeT+8a9gv3H8iuRhdTS9TmgmSm4FcF4sRonC5h1rYE6ejdpms9B5yo/5VlIX"
    "FFgDjvFi4zXHYdPkv6B60kIEd24A9JMALoHUmXyAOBAQUu5CrxcEXltw45lfxApeX1kC4pw6"
    "y5oV7Awj5Yv8TW9iFfhDn7Gzj46F20zbBGIdlP4zSnZ8hurJ/whrxfpFATTgGC+qWg6G6OFA"
    "81NhmM3jv7l0OUP41hoUQIYSA+tqem1mW8t9trpKfjwNour+sGQDQtsj9G4XTG8iRCk1BkD8"
    "fbbgBRBHhzt7vBpQl2HzpIcQ0Lej08zv3Ko4HVzSgBUGtk0ehE2T7kN18/VQ5jMQjoCweea8"
    "dYJNAw65ZfGBIPerq+mNmW3g29Zral6w1UTPeSg0lJ2AJFq6ZHptIHnmwErLWyPF5+0pdCnI"
    "sfAZH6N64nhb77xAyI+A68b7sWXyeFQf8AVC+nkIzwe4j0uypYONgMowuwN5ml4CpH52/vzh"
    "Zqzgrdd3gMKgQjUiBpEaewRbFsjjbPXDpnaDY6HWt30OIPkdMrUfwFRsmvQSvhvfqTCihFF3"
    "AlZPPgPNfSug9dTo2Fv9QHajw4ytCZHd8ja9IBRloa1UXTMY0EYhWxOGJM77a+mi6U2oSoYn"
    "RDzvnBCA6BNg+JZh6wSX3n0now4EFMGmyVMA/TjAzq5LlAnkN8lR7J6X6Q0HtVcF3rQXLN1c"
    "lt4ZBjdYg9R5dNAyQAC7GYa8kDo1AGELmPK/2DzpIawb73dbnhwJWKmweeI8iL7GbUGyhogD"
    "AdE9H9MbIeFHr0wZ/n1C0V3dFt8RNOwOv6CQnZ79ftjcIe5WtJuxFJDMExfI4Wju+2fizKN8"
    "kRsBN++cCHJ45oQFRdIQDMBu+ZjeyPftDuV2dl/8xCpkJ1rfuiMalMpKBaCgA8RCbbmHJMAX"
    "s8vJ07B5xwPWKWT5IvuCNk04GuQNblWcB2wEHFb5cgsAHfIwvYis+EjusYsUfpKnQsAaHLD+"
    "wDwnumYDOctmhrWR2g9MBDkcm3bMcquHnB0Bv69sATEeAtjw07e03Qek39ctT9MLABDRLZLr"
    "8l3t0EFwFxQb4RbNG1UDp56pu9jvx6r2A2OhXTVvgrIz69zC87Fp4lg3BMmOgKGddwP6QDcq"
    "zBsJPiCpu+dpeiN55ZCBN/z7f2x1tb95CyATC9sep/ffXJ4c5y6ocHYs0OWuWih5Lcci/orN"
    "17fLV47MBNwy8XegLvCrqBwgYjPBFPbIx/Ra8ooWPjfghv+z+7j0FnZSJ+nDhgm22T+EvF/Q"
    "OgEI5KgEOd5MkTRFAWwOXTs1c8L0yEDAMV5oNSXfStyD2oN20zdbYwQoy8f0JuTdV1PipgkA"
    "jF2FH1j3wDYpVSkUXgOCh1VUPG1YIlbmXIjwd6iacHw+cqQn4KYW5zUa0wsA4LcOcWX5mV57"
    "Xgi22IrXJQe43oykJqgjrEEVlP8CSBxsdxUClKxr9X18nDOkVwHKTJPFGYb8MR850hBwjBfC"
    "hhvvc4K2m99hd7/sJ3FwnqY3Ia9OICC9LrciGQoDrMHlc0YHATzqnNhFGDg89r3TzD2gzr3z"
    "o3lSPr5gagJWNxsJsPBPfy5Q9h6w7GZXEGEzkp/pRTSlmAkaUFgfr+KGYNOfba8zTUMeLHi1"
    "tBAwLEfSLPPUeRm9bh5w9+/rKoIzAVdX+iDSuLQfkDQP0DSNHm6Z3thEBiQRsEOBWmOB9sII"
    "XmSN+eju0R9DCu4L9rGFhJn9QCJ+bSN/NHlBXQVwJuC+uwaB/FVdCy0YEscAwbJ4IF/TG84W"
    "UtrWyYHQfpMKBZNXYUOlbeWf6MJqQY0EDagyaMBE4jHyAAu7YtP4o9PmTQFnAirT5bWvboH2"
    "IRigB10yvdE1IWaiD5ioJQoFYQv4frJZHZb4niBQkypL3lUC7Q8fOzs+C9rjcdaAcXOLmAVJ"
    "IKPW+vy6yOBAQBFAhtalsIKCsgMBf8xJHli52ANyAOCO6Y1+lPo6bItXOsYLqLiWLTjUaFRd"
    "FfO7P7h91I8ieK6gNVLiWnDfW7YDsj4WTkE8wh4HEgKcg6oxTXKuPymm6qq+QH34PblAmVAY"
    "iQOm/hCN8fn2nIbwRj3hiDxNL0BA8MOiKQPiW59ta35IZHJm/YDaD8NzpS3OxMMpUrsDI7Ej"
    "wpWOfl4K4lnSNAc9Z+RafTIBxdP4zK/mJLSd8bo1ihoXAe6Z3vA1pd38hgz7Usb6gMZIa/DQ"
    "71u9SmBTweoj7XMeiZWOfl5q4sXiqHPvjDj5gMfm3IhCQmQWOsyYa40acvOrHQAMddH0Rr8l"
    "dEBC9W8JhC2w9dqO0eD8+cNNCB8rWHWQhC1P9KpUfl4q4sXCgv/BNxcfjByQTECl62NNR3YQ"
    "9TLaNr8uMVpr3gFGZua4YXqjH4kaEKoBXBFZh5rgD/Y4letEgaxBwE7AELdmNLcptCBpioYn"
    "p85IMgEphV2CmD0+guweBUyxrRg75eZXRkNYUXfTayUkLXkJaEkgoG7veqvSQWQFJHA2Os3c"
    "Y41WEvysgLXuawuVmtszmtsk4lkIq/S5QEXWg/dOJnhfh7h6hmxBkOegzSzbHLWTbnypF8k7"
    "EodecjO9VrMd15JhaLvmodSTBpQaUN2CtjsGoe1dXyT+Su09rWA1J2rA3U1+SufnJfl9SWnQ"
    "0fymRdZ70ThNME2emFmvUCaUjESnGbZ1EkOmvnq8KHkGZHjqUuxiuGB6I3mpkDgtv8AEFIKY"
    "D80p6DgjaaJF94sfbF7qC94GwaWFkoCJCsent8O0kiqSCpbPGPGQkCYSJ7w+vNgpbodSIUED"
    "igBs2B2zFG5Am2lvW6OGTH35Uq31AgBtCmF6o3mFsOwDDUAKSEBRb0ObJ6D9jIvQ8bYk8vUd"
    "O3tAqT/4USHJF0GzfmPmxidctJu+C2AotZ+n41ovRRohe5nfXPjbbCpP0IDDG3i7NnkBbabf"
    "FQ1VPP20sX1t89tJjAOAwpleRlzAhIVJlPaWRG5hLWDcgLbTHJdDHjv+7hY1pvdGERkHoOA7"
    "EwBAUOl9YR0BIH8C2Mqu8QCblos96dZwPE6J3ABU/BuYn3aKVwIB921AAoqGwb9EQ5WVlepH"
    "7zHPSnRLXCY31C3TG8urxaIBK5sB2r2pWCIboDkV7Vs8CiSf89FvzFyvNngZ4f2LQOpxoT/g"
    "1aoV7ENQ3wJsZSde5NOReNGwhbDkofqb0vOMA9IPpNsJV9Wx8HPfUkHwTGSrCADAf7zHXi/A"
    "qdm+603UZpYfM5reaB2KFg24YbtLowGyGZTJ+CnQG+1veyiRfCKQPmNnV5gG1xC4C/VMPgDQ"
    "QpsfSJhrnTsYyeY2KRzJRxDU/BNWV6Rd5WfXgJ5d+yfu01R/kNgEzPKbF7QzwCl285ne9DIP"
    "04toucqiAT2qZX7mV36EYCYos9HevpVwFH3Hzh7QZyymIXF9Rj0j5E1YEae5jgLYr3P00yEu"
    "+iAnxAn4K92kZJQCbC8SrLATMIRDGmzPVOX7JPrVgNkbsE80LajpjeQ1acY1oJK67c8iqhYa"
    "d8LX7Ha0mvKTU5LDx87uqURugUijeO3ZRGrts4wMrhWNjH5eNM7mHyaQk1pPxvoL/4nO8xxn"
    "9dgJKDqn1yh5g7ITgsUAXkfrmyzrb3XP+jS9Ee0ZMnRJ/J2rKS1zfhgpb0PJOLSf5ji1/fDx"
    "D3RSIfPvSuQCNJb9uYHtS+4aZ3tQCGwVK9lS+HnhmBRaMZpG0FGz5mIFzHKq3E5AxYPysjoZ"
    "IYTwQ2j1Bsg30GHHe9YTI6MgURb+rCfTG45Z9d+Zw+NvIDxmy6zdEZEfAPwJ7WY84vRzvzFz"
    "W4Y8+jpF+SOA9Buw1zOESNprx0O00inNrZV4SKkV49AgMREbKh5Ep/m2NzxAUi9YOufn9zhB"
    "qqGxAB55HSEuRIfbMq/2EvSFrj/TG4mM7xwKACFpCZXpWgih+SSA6xy2jINUVqo+1R3GwmCl"
    "UPbL2O4GAB22O9Yhsw2iPiAinyn8PCetaCkpGtcuWKsu8QJ3J9ZlJyBxYB3bYYfIdwD/Bc1/"
    "of3MZQ6S2TCwcvE+Xk+wC2AeKuQQCI6sR9MbFhlYZhPKyOQDqiUgr0OH25Y5/dp73Nxefcz2"
    "9wM8Jl3bGxwOGhDUrcNbv2QiXjTsRLxomnBOIc9DVgSs89CnbILg34A8g7YzlsSlmumY+vTb"
    "FreuDQZGCnGxz8fDYi+1pX5NbyyPol0D0mmn14g2V+pZtHMeSO4/4fbS3bWlfzUok9DYj0ID"
    "AMWkB4iK5WEFmKWfF4O2pbHlE/bEhnMORaf/s/nH8Qv0zZ/2hT/HA5hF1QL6cZjyJDo0fzc+"
    "c2V6yixDpy3qBoQmUXOkEH6rFrI1qJ5Mb0T//ee9GSM/tolNqQHldQCrYejV0PwA7W/7BGlw"
    "xOX3lxNNZgtwSLp0jQbEsx/ce9lD1ijz64vPEuAIm9bLws9LJl5yvlANz/FYjqcFrAQsqd0X"
    "zFb9qSDAfyJYO8164HIqnDzt9Y4G1JkCng1yEBjVs7S0J9F8Rn+ui+m15k1vekHuMk252Mpj"
    "AED76TdmeTHQ69IH2nm85gxYz+Fo5BDgbZb4R9ljKz1K6SlaW8iWvZ+XQDynfDwHKQlIYycy"
    "dvskBOJxcM8t6HCPw0aRYVTc/t/S3brmBGieREG5B6o3YqeVJ2ihJPPphumN+3+xC+FgejW5"
    "xSBPW3LHyDrNtxtYWenZXt1+rMeLG4GC7mrqHgTVojl5xX2XJfXYza/Xnw/oQx3NbRo/z5l4"
    "ifkIAN0DX5/Ww3fgC2uipVh9FMfReovk26DNU9Dh9jVJvwAy7PbFRyrKSSDKSX0cQX9Ypiy0"
    "kFX4+uv1LiCN0e/O/EP8SK4s0Xfs7M4icjHR/mIUfMqWK1grIq9qrV/1mGrh8jljdiel+PLc"
    "Q2F4/lw3c+tE2GjYHqcCxjkAYtbFfmB19aQdcJyOJbtBDEP7GTaHtbISakWLtys09fUAetrI"
    "ZtNCEeJZNVgiIWnRbNYerEUT5pbXOZ2QVVo4Ycn0kU8mtzMZAysrPTu2dOhNoj8h/Qn2B3lg"
    "NnkbEDtALBTIqyExX/3o3rGpH7ItFc1CO0uuFcGVQHSvwmyJF03jRLzoZ0Kc6LWeLs/F1lon"
    "vAnhShB97RIqE5QL0H6ajXyn3/H2EWjBRwn0CMuRoxZyML22Rrtvek0RuUfX4q9L7jrP8RUZ"
    "APSf8HRpMLj9GIqcIMAJmvsfC7ApY+UlmqIGRQjAFyA+FcGnFH6qRa3xBrEissFRWphfjaqA"
    "KrlJBB1t2iovPw8J4YR8Jg4NrBtW5uvy0mogkYAaT0ASCKj0/6LNbS9Zo868853xIKYD8Nme"
    "gBzH3mxCR/PCQiqXTC+BJUpk7H+m/cFx64mjJ8w7GBoXkCgH2I+ifCChUzww9Q0CNYpYTcEq"
    "AJ+S/NRQ+lMJedZlQ7QY1l9YEoJ5IpQaAnKICA+wkcYdPy+JnAQAS8dGaBwDwIGA8M8HAjcj"
    "uhc0ZSdM383WFGfe/vbVWjDTroWiQsKiraI5bFooVk699HrBKoA3LJl+7rzEXm5FxdPG+v13"
    "jwB4CSgnkpSEvA6at+AwKVgrGqtE8LEWrIKoVSvbbFzHKVPqME+pUuGbzzubpnegUhhKpU8U"
    "ogm0ht1MIoF8+fl5tnw6oR4QoO4LYB6Q6AMCwOZJz4AcAgBQciPazLgl+tPpd75zGshnQaro"
    "zU/nt9m0n/VmJprepDiHPCnT2esGCE3uEnDGTm1OXzl9ZFLn6pirHz1TaE7Vgu65+psuwgTk"
    "E0AvhWApNZbv8gZXr71rXG3OJVWNaYKa0KGmgW4i7AqyK4FuQnYBUOL2eF4SEbMlXvzzfW+3"
    "F08AnEbqtfkERA2BSAC1zWPzuMbMfd8r5J1kZBZHCt+L4HYB5xL4F8XUMHEYIScDHFE/ppeL"
    "vCG54M3bfp+0zuKYq//5awhmQNCfacpJ5avmiS8JWQpwGUSWekJYsXzO6OTeaDqsv6J9yG92"
    "lWCwmyijq1B3I9kVQCcYlNjbCwKC+HV11FaF8vN0QnqnT7InFg/0YMCiUDIBv9/nOey3Yy2I"
    "Neg0JXZy0KY9u0cRONh6QxxM77dQGPLixPLVlhKXApg35OZXHyXwJBl+22IjFeONzsP01pK8"
    "/t1pv5+ZaDEPn/xI0xKNqSK4MnxvUpHeNdO7GcAyAZaKYKlHQsveu+eKbRlzRfHd+E5goLdW"
    "KEPI7Ealugp0VxhooUKIrB3TcY1tu06piBcNOxEvIZ8Lfl5KAoZl9te0L+lUAqxPJmDZlAC2"
    "Xns1TDa1xRMnZ9JCGjj3lYmDV4tIDwCTAHQB8CGAW0i+eMpNr1wLYFYBer2rNcwR79567se4"
    "1d6cYyY/MqhU4wEAB+VD+jTYCfB9QJYCskxUcOmKe65IOUhvR6UH31R1hcfTW2vzcAEOB9ib"
    "wL6IahMlEEbdv8yaKaW/ltQWN/w8J+I5pHeQ2WCwFYD1yT5gDCJWiU+f+c7HEJ1yrI/Agpcm"
    "DyoXkT4AFgKw7iq1BcCxIKtPuumlL0l0zslnjDbA2d98I1Qa+u2SKefahlaOHf9YC+XjdA1c"
    "ClLS+5uJbaEtnQVBQD4iuAzAUii1dGWbjWuy6iBUjWkCbfQG0FsLDxeo3iDLAJQkPXjRG5V4"
    "89Nopsbn5znLHL+n+kx/jzdeTzNbIy51xdNPG5B2h6br9YqW/0aS/wV28gFAGwB/JPCnk4j3"
    "QHauixZK1mD64Zoffrp0+S32oYj+Ex8bLD49j5BfRYmLWF4H8sHR9BLhE4uWCmWZiLm0xZ7S"
    "DyMnGWUBEXw3rjeUHkwt5RDvryH0gYA4ECut2UyjmRqxn5cUR4t8AmM/IMvpQsH1+3WmJ0Kq"
    "VB0AZUYnZB6aophwPKXKJqD1otkJEBE6gTAxGXTlO1NH/C2xkuMmP34tFW4CxchuqEfvAWU9"
    "ga8E+isQX4GyEn7v8g9uH/VjNtcnhi3XtIfeM0ibKBdcOQjCNiAijHO4KZZ2ZnPzMxMvGnYi"
    "XkK+rP08C4GAXPy8eL7EBwOMHY2WFQG119s9PHZkvZkWwoDQWkVfr3wO5+lIkSWXuk++vV4K"
    "Jr9z84gZ1sIHVj7drGZn8CGAv7XmZbiSryH4gprrlchXmvjKUPorBtRXS2ddVPe999ZfWILS"
    "ffrrkC4XhXKAh4HR1eTpNROT0jjdxOR8kSuQUK5TPqDOfl7GDkZC+lT5kuSzPEDkD0CWBDS1"
    "3i1I1EJxwkQae3Lk5Mq/AxiEZB/wjsE3vbC/QI5O1kLWcizfHTSYELPfnlphI1+/SU+09iks"
    "AtgT5FcA3hXqFdB6Rcgf+GD5LaMdjmKtIzaNLwNVOSjl9LfoD61LRVlvQBrNZHtoE9Nk1kx7"
    "m5+XLF9cRgXZBGRJwCbiW1Kja4MEvDahY2wGAHSk37iL5CgROQ7JveDNJ934wvMkm1jz2m5K"
    "RtOLl9t/IbYtbE+Z/EhTrzLmi+ZyU/Hy96afZ9tXJj+M8eK7ZmUQHgHRv4bIIFCFj4aVVDcg"
    "tWZqvH6eE/ES0jt9Zk08a74wTIVqD5zehKTAabctfhfkr5N7ipGq447+c4bHHPPi5GEx0zb4"
    "phf2V1o9SOiTw9kipLLmTSRhcq+3qkRLj9dvGW7TZsdd89Qhvl2qetGs4dkfN+qICgObOnWH"
    "UkdAeARMHAGgFxDdI9rBl8nSjyIy5PuZ+nl2me3w+fwd0OWln7In4MyFt1DLtVb/Lw15ggQ+"
    "Es3PNNAd1L0IeBOGT2JCpiJzwjSrP7w9teKJrIRNiUoPNm8/AIbRGSHzIEAdHFkJeBAgXQFd"
    "6qSZknwZxxsbTx8R3kK8FPl+5n5eGnzsK1twLJDLohktbwO8Ni5L2s6DF+SRGjwylj9F7zlL"
    "07s4N/JVerBtRxcEeBhElUFYBqAMkIMAMRDSCHcVEp/Y5ItNxxuQRjNZH6qkNJk1U+H8PGeZ"
    "C+nnpYTIv6Jfsyag1yP/CQSpCSor81Oss7B9zzz2Fk2HeP5Yuwgh78go4IbKVvDuOBuCCgBH"
    "gfSF31pbx4hTXJysiRcNp9ZMRT8vM3x+9e/o96xNMACcOmPBh9Q4PEa8RA3GlOYzTrbcTW+1"
    "p6RtJ9v5HVFUVTaB/HQqlPodiPKct1Nz0A5FPy9NPofrZZc5K6zylS2IrZXOad0qTXkLog9P"
    "Y3ojclsEysv0EgRfdiTftsmDoPAEgGZg5jdh9oZYZIlc0J+Hn5e+7mTiJciVKp/D9aoD8cK5"
    "Ff5iDee0QQ6V+XZ9mt5wlCxIEmTz+EMQ4iOAzm0dc6wOy19Ma9vjksJO+dKlSZEnmo8Z0oSh"
    "AepYmpT5UpUDSz7NCPnS/NEhX9prkRtEMMfffYHtyImcCKiFbwJ8F0RYI1me0gLNcDYNI2An"
    "4NZrm0P7ngacdi5IA4ebZtvvOIcbSyv5Mtx8R+KlJXnsamcmXoaHJT/iaaS+FrmBlJ3UmOTt"
    "sWBC4m85+YBRDKxc3KzEFzzBFD1INM8g0MXq/yX5gohoP8YvJDOnC0HLX9+5tcK2kBmbJ80D"
    "WZF966P/Ymzfy/287Oom0JB+HiAIgngN5FO+ljUvodO7STtjAXUkYCLKp77ya6X1+SQqQLZK"
    "7HDYzDaRRMLI9xrR/NAULlMaSwMMLl5y67n2XRc2XnMcDDO7U4MSb7Tt4kY+f2Z+HsFtJFZA"
    "69UwZJcCaqkRAM1aGAhP9Q+hqSg21UAzIZsCuimIpgSaQdgERDMRNKXWzUg0FdFNAUl58Awh"
    "PwqxEcKNBDaKyEYQX/rMkpfQ64UfUuWLwhUCRjGwcrHHY+waoDXPBtgfxMEkm0cvpKXXGwD4"
    "KcllEC5DSJbu+n7bqvQrvCoVqn/6D4DeGQUhQwA/guADAG2heRTByKlH6bVVPI1F5qQ0mTUn"
    "U9VjywfUdTyP0FuF6kNoc6WIfBA0jRUlPZ7JciJsXVCpgE8Ei7cImu8QlB4s2PMlceTy7Ffl"
    "OcBVAjphYOULrVUo1DKo9W6/ae7+4Ycfdue0lDCK6okXwWF7LxvCN+1jQC5G+5mWjYQqDGzq"
    "cDXJ60Hr4uvUmin38bwEAqUlbBTx8TwNVgv5NYmNIqyCcKMAVVR6I0PmTwQDVL6AH6oWIc9u"
    "dH088z6LewEKTkB3IILqiasAdnb8OU6G9RDjaGk/owbABQjPytkO4BGSS1B15UgSs2OZGtbP"
    "2yyCN03qtzT5lv+Q+euyvBg/K+wdBNx67UCYoeT9+JJutJyFDjNfE5GnAQxLSHkpySew8cpX"
    "SB5f/34et0H4tpjylioNLUbH+a4eQFhR8bTx5b4/HGoa6A6gLUS3IdBMRRfLAVooe7RwF8hd"
    "mU1S4gAAC+dJREFUEAl/KrVLtN5FYDcMYxdMc5eUlOzaae7Y07LWr9/vWGXWbU1ydtg7CLh5"
    "8sOgPscWl0yQADrsaSsy93gAzzuU8j2AA7hh7NUEbqybn+dEvGjYiXgSAvRz9Jj3e341/20H"
    "VZge74/x4kj7HtoikL5XzDqA2tuTYE8BeiL81wPJSyHchLb8mdFPCi78cNaYf6XNmQaNfwfP"
    "DZWt4OPpsbCj2SRAfimYEwTm9kxRUisAHUD9aXS9VaH8PALfKeE8Bd88dJ4XmZb2VPp2rr+w"
    "JBTa3pfEURD2A3mUtMDzHuCaaJJ+Y+Ye0GcsV1F7mgOsn3O84lBwGDcWoptD2qzR+Ano2fkH"
    "MLyYx3ajkTBmpWLbpK1PUdJuANUAO2YcB6y7n7dJNG41fmw2L1FzJeHzP7Q2Ve0AAscBOArC"
    "ngC8Yid6J2uWkFeai2bztOXWM5jnbrCNn4DUoxI1k+N4HtESWy47FMDLAFYCODyhpOkkTb1h"
    "zFFxDZeBeLG4jH7ejwLOVCU770OH55x3O9hQURoKsD+0HgTBQIj0BiCxMhIGjSPV2AioQrq0"
    "gc8yTYIAeZ0t07gJWH3VMRDVI8nchgOxuOh3HTRuJDlCRIYCmAJgAOK94AfxzejDoPA71/w8"
    "TU3BbA+b/QMHz0led/J5xf4hL0dAYzBEjgXpD3OOgFgWm1tITTBGRgr3txZnKl2qGs35NmEI"
    "89sZtnETkDg/qqmciRcNh2+igL/Bxssnk5gB0P7e8evzDzJVyTwhvYn56uLnAViptXmlt8uT"
    "K5LkXjzQE9y/7eXKw+uh0SyupVP7mGHi2esRsC3WDfOjy0u1AGAo5ct14k+hQcmv49O4CQic"
    "Yp+NgWSzmWBKSfxNNlw22JQxTxjUH4SUtFUmjoX4xwnYLDXxIvkz+HkC7FKi/4HO5izD4Szc"
    "4NpzjpFOre8U0b2s78ZtMmf73pZUQVN6eYHlAKCCsto0oukaDUryydx4Cbj1qm4kIx0LB38t"
    "dQ8UBI8X4ngNgTIjv0nefh4geEVpz9U46OHkw12+OXdfMxS4UUSNgoT3Gsw0lphMvIT2hM3x"
    "0YgQcPmc0VV9L5+zFqkX/9c/+HPVgEE9IPbd9fe2Ofh5kd4tiMnGQY85jneZX444V9O8WYDW"
    "EJ1cdxo/L6m+BPmUAdtRrgTekkZEQAEyTjhIh0ZLQC0cEPPTM2imtMTLx88jNBXu94Tkb+jy"
    "aNK+0rVfVXTzaNxJ8HhJRfQMfp7jp6UMreUo61QUIRdB5OJEWRoKFL6XT/5GSsBKJRonpLop"
    "4Y9M722diBf+zO69rV6qlXm1t/P85H2lN1SUhmpwnaH4RyLSqSnY/DwetHvNkA5NerxSBQCl"
    "pXv+taemyTYAjeLwQxHJayOAxtWnj6JqSx+A+8QIYe2IMGFGcoo0tjDi4SxmMm+DyOXGQU8O"
    "ciQfgFCAN0E4CaQ3U911npXM+HR4g/qMaN3vzrx6DyizXb3edcf3KiT/l08BjZOA1L9ORRA7"
    "8dJNG7fHZZzWrqkB/q9hyOFG50cftqi0JHi0TAX5fSqS50U8xIkX/RPhWdb6vSp0D4CAC1c6"
    "Lwhwf87bDCegURJQax6RRDxmpb3sYc0QoWsJXQvoYIo8NQI+rbV5onHQ4+NxwGOZneou87eI"
    "cJITiQqyDoNm/12ryttFq1866/JNIB534VLnAW4xSeejUHNA4/QBhQKgFqQ/rIaiNyT6HQAY"
    "BLmJwioBNwLqW4DfUeNbQ5sboIwN6PxQtU2TrTuvU8hAmSIOBoU0uN3QzV7GwXO25/okGoc8"
    "81Ro7VnDAQ6NyJOHn+eQ3tZWUR6FMwHMidZvemSmYXJUjmK7BgEvWXnf2M15l9Nop2OtG+9H"
    "SW0f00RrGCyBgpemfO+RQBUMXxU6zN2WzkzWCz47o2NI+D5FWhR6vS0hK/xlbxxvjet7xZzX"
    "QJzkSltygIjMWTFr9GWulNVoCbiXIPj5GReAvNdZ26UgXlIcErSiMxTMIZ6yxbFe55FXzBmi"
    "iZfzbUOOeCG4tdVvV80f7ooP2ih9wL0J3q7PPkzhwpw6GCk7TumhYYy3ht+fNeYVAGkP0XYV"
    "gpfcJB9QJKAr0Ka+UoS703WKkoiXlCYrDK39tLyrNYLk391qR1oIXtppBM52k3xAkYCuoKTH"
    "i18DmBrXaNGz2OzjeXXRegkQmPqP1oiVsy97GhJ+V1wgBAhc92HbTb+p0zFiGVAkoEvw7Ki+"
    "G8TqJHPrDvFiEMHIwLrysmiYBEVwXb7yp8AnEHXMh/eOubVQC5OKBHQLRy4PCgLjCTIfPy8z"
    "xEBA32aNWXHPmAUA3eyMEMSd++zx9/tg1qWOb4PcQpGALsLT/Y3/kvrhPP28LCAnBD4eeKY1"
    "Rns8owHkdq6JM74TqJM/uG/MVdkfylN3FAnoMvwh/w0kt7qr9RxgGDdj/cDYZNCVd12yQQSX"
    "51FiQEQeNKF7rbj30jdckDArFMcBC4DA6vJzAD5c6HoEMttb9sZEa1yfy+c+IeCIHIrZKsBs"
    "Zcq9y+eMrnJZxIwoErBACKwunwbwioJXpDnS13NhbKJszyvubealsQTAYRlyfgLhnfvsLnmk"
    "PkxtKhQJWCgsHugJtFMvgvifQlZDyk6I5zh/2SuxvWX6jZl7iGlwGYB9E5J/BeJlEfXv+jSz"
    "6VAkYAGx84NhbXz+wJsADyxwVat8LfYMsG4C2eeKuScLMQvgKkDe1DBfXnnvWFf3o3EDRQIW"
    "GDVrBh+ogFdB/KrAVb3o27P93Hz366tvFHvBBUZJjwVf66BnKAQbMqfOC6cGSls8gvf75XZU"
    "RQOjqAHrCbUfn3SwePgKaN/twHUInvVV6/MxYFHy0RaNEEUNWE/w93r9y5BSAwi8X9CKiDMC"
    "bdXD1jHCxoyiBqxvrB9YEtgtswDJZawudxAfasN3bkn3l9cXtJ48USRgAyG4ZvBVJG8EpGBW"
    "iJAfofRF/u4LXy1UHfmiSMAGRO2a8pOg8YAIWxewGkLkVl+P428CCrfVbl1RJGBD4/OBrQNB"
    "dTcEp2dOnBfeDGq5sGnPN6oLXE9OKBKwkSCwpnwEiZkC5rXfXgZs1kpfWNJ90eIC1pETir3g"
    "RgJfjzeeNA3VD0AhX5G1VVqeD6wZfEP44JmGR1EDNkIEVw+6SEPdKLkeyJgDBHjGW7bfhXDY"
    "47A+0SiegiLs8JYtfNCv0JvkQyjQhEICvw2s3vZAQ2vCogZs5Ah+POhIbchMAfoVonwKH/P3"
    "OPGyhuohFwm4V0Ak+Ong87WJvxdiyIbkQ/7DFl3ZEDtNFE3wXgHS2/2Nh/010lsgswG66reJ"
    "yKjg6sHT3Swz67qLGnDvQ+Djk3qJx5xJSn83yxWFK7zdFzzkZpkZ6ywScO+Fuab8d6bGzZDo"
    "Wcj5ggFB6BRv2VtL3SkvM4oE3NuxZWCzQLXxZxi8HIQbcwGrglqOq683JkUC/kxQ+9nQbhIK"
    "/A2C3wD5nWNIhSV+vd9QlM0v+C6sRQL+zBBYV14mQX0Nid/mM9PGaclnIVAk4M8UtWtOPhQM"
    "TRKREWDddsLVBn5T0m3BQrdls6JIwJ85atYMPlDIiQKMBMSXU2bBBl+bZv3Q+tkdBRKvSMBf"
    "CnZ/dnJHj6mvEuGFJJpkm4/gw/6yhfls+ZEWRQL+0vD5wNaBkDGO5BgRZHX4NRXO8ndf8Foh"
    "xCkS8JeK909qGSjVY0lcIYJWGVJv9LXY09u68N0tFF/F/VJx5OvbfWULbvHXqJ4EH8mQumNw"
    "R5PRhRCjqAGLABBenyLArFTrlknZ5hezDGWLdrpZb1EDFgEA8Pd443Vfm6ZHRuYgJkGE+wVE"
    "ub7bV1EDFpGEms8GD1Ia9ybuZ0PIdr/PdxC6vOTaZuVFDVhEEkq6LVjoa637EXwAlhnZArYM"
    "7t7T1826igQswhltFu30ly38o4SCJ1BhSSzeq451s5oiAYtIC2/vt1b4uy8YbIAXAvIRIK6+"
    "FSn6gEU0KIoasIgGRZGARTQoigQsokFRJGARDYoiAYtoUBQJWESDokjAIhoURQIW0aAoErCI"
    "BkWRgEU0KIoELKJBUSRgEQ2KIgGLaFAUCVhEg+L/ATCpBu95+6DbAAAAAElFTkSuQmCC")
index.append('eelbrain160')
catalog['eelbrain160'] = eelbrain160

#----------------------------------------------------------------------
eelbrain = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAAEl0RVh0Q29weXJpZ2h0AFB1Ymxp"
    "YyBEb21haW4gaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9t"
    "YWluL1nD/soAAAZCSURBVFiF1VZ/bJXlFX7Od29722KhrdDNOZQiW7tBZ1OIBlsQBkgEQoIG"
    "NzYj4DbQCQYojftlQjN0LIoa2BxRyBJ0c8qWbMiAGBVYCxtj0Ik4fhQnBaG9IMXSlnK/7z3n"
    "2R+9ve29vUWNaLKTfLnfe+77nuc5z3nf9ztCEp/EJj/+xhc88Ucg4PB19+7bNTy3fQ6MPsw7"
    "PG5N2V7fd0P2rr7v2MeNJx9J4P2aAoRah0/7/fRLUGw3dUNVFaq64c0Hd7WAfCge6vLukznj"
    "l7xYdMDMnTdnOyUcLD+wdtGZK4X3+gWNVt2P5uq/IqPtPYgnYvJLmg01M9Ds0syS6GoQ83sW"
    "MauiqP1mM42a2nUQzKFm1N68eH0RWmoG9kcgnDRqWloOL1SNDEwDEIYYAGDLkS+9Z2Z3mClo"
    "BjP+ecn4o3cBzElarzKYZpd7eYZ7qhvh2jejuaoIXlYNCh+Lplegefmv4Xm1AGcC7CEm0vKr"
    "veXX0zTTzGBmMHX/QohlfdIhlGR7ivfWdz/I2g/BXCC2H02LbuxL4OzyKRDOSy8SG4Xu63Hp"
    "YWYgdRwEdX2mel4OhbUp3oz7ni/MBrwOkPkIRV4ARJIJEDXpwQHQazSzkQlwU9DYDsWgvnNt"
    "uqhsSXV3+BmVIP8BADAdjejD3+wh0FSTA6A0PbrX3tiSuZqmc7vB42U4D7Co73wpffrbFxoA"
    "BEleyDcAt5sWgBaALvbDHgKhi18BmPY0dASoWvCnyioz+7IlFDCYagtEhiVje7WHo3L7klfy"
    "5wOQpP8Igv4pdBOwYCpOzbsJAMLwwgVQl5KI+IBsnvXCpAGkfqdH+i4SgJ4BMDieQyOMPytb"
    "OQJC2SLgjUgxAcw5nvcQAFSQKk7d98PAj8MIND9xFii1ADcs3Xxrw+HzA6dStSZFetD0oh/q"
    "/COI2wB5cubaYW+f+jC8SogpQPpLzYTHPPXHUhxA7Xqg9+L4tBVhhJkBerETrQPvXPTq7SOp"
    "brmp3mLqwN473wxmrtlUHwjHBrD8sZI9VP0BgIo0mK0ADolIfUFusHvbg/U5ZPAoTEEmSBT4"
    "LjwjjNDAbXDtv3j41QnfhbnFqsF6GnJp9rWurBU0o6mtg/JFMy42xF6CWXZc3yiIfQLsuzZH"
    "D1XPeN+bfNO5IRAWi9Nig94D02vi0iPxawqYjhGSuGfTplDnySFRVWva9sikwxVL1tdH8gof"
    "N3VQVTNn95v6vtIeUGenTIN3jfbWlOK2Y0/c1XSDiV8pYhVUVwZoOAmElgAGFTQFEH+Heznx"
    "MZr+xJtNpjrEOf8VGitNdaiqg6muyO3IXVUxrnHwTyuPj4In5RAbCXWjSI4AVZIAUt/N+gIz"
    "Tky8FYkrV83+QNOHQMzplt7MorSsp7b+5I3fQHA3wHAiWCIjSwG33nUGVQFYMrmuo7ndGTcm"
    "fY4n1uy8JoS2Caqax8COOgsfqauuK4fqVt/p5ncORRvKSq+tSgpmCtIAWhRwB6nuLYr9V2jN"
    "tQ157QdODr4wKE9ZUvhB5hdzO73CcKw9nB3ryCl+7QzwcfqB5qpdpI750cq66ifX7b8uaFzw"
    "PVAH9arzQaiuYsguIXCVIpY/+pk7dwqxAUBemogn659dmLgrrkygadkYMtgVl7WJtNNCHcMu"
    "8JMi+nMzzRbVGtDy43XWWb+dvOD0xZyX+ol6of7ZhQXdg/QNSbdZ52gguEjzW2FBplhwPenv"
    "gflzwydOlyLmd4oGa6hBPi0AGIAWhJ6Z+bcMAG3pQgrwWtL4k/aEKeHENczYTnWV3RsQICj8"
    "3di132ojsCxlwb8RiUysf3reh92OKyvwkUaqiy0Cg86u3d2VjEe5e83suo0ATsQntlK4LKRy"
    "S29w4FMr0GXu0KTb1JNNAiY2nQj3TH9+1sqznRmlXkbk5QNr5p9Lt/aqEACA2JHJXxXjXwDc"
    "0EMCf89w2bNRuuVCf+s+ZQl6LFLy+rHAZAIp/+z2kRgbhDp3XD44NU3zEid5tRToFVL0PxNn"
    "K7wV6OkNzjGUOTVSvO3o50AgbsenRWKX/YXw8IiAeSDeyRxg4zFsR++2/eqVoI+N2BqLjHp9"
    "TUSzRpF4DsISvz30aOq0z06BFPPfnlLKkC2InLWlmLAj0QN+bgT6s8+uBP8vBP4H115R89kM"
    "CuUAAAAASUVORK5CYII=")
index.append('eelbrain')
catalog['eelbrain'] = eelbrain

#----------------------------------------------------------------------
tango_actions_document_open = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAN1wAADdcBQiibeAAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAWLSURBVFiFxZbNjxxHGcZ/9THdM7vj8e4aEcUGgYGVEguBTD6AOMk6B2Ll4EQhkD30xYIr"
    "B/4BJP8FJBcUIEJJFM0tsrgkJDJOAjgHMEgRyOKwCcEh62izMzu7szPTH9VVxWFne2d6ZozF"
    "Rsojleqz3+ep932rq0QURXyW0LezKMsTf7sGpZQuqFReT2KzGgRB79ACms2m+OHqU/zm+Reo"
    "1+sz13m/p7HdbssXX3rhsXf//u47WZJ9JwiC+FACLl68KK7/8x+sr69PEHrvcc7hnCPPc4wx"
    "xHHMt07fI47fefwbv3vjtbfma/MP9ft9M8u+/F8Crl+/LgAvpWS/CCGQUqKUQmuNUopKpUIQ"
    "BFSrVaSUPP74Ezz6vXP39+PeG1mWqVt6YHl5WWdZdsVa+0B5gfeeG//5QCilCjcDvP2Ht3HO"
    "jq3TWnPfvfeTZRlhGPL9J58S3vuzl69c/u3yV5afWFtbc1MFJEny5Wq1eu/58+d1HMcFkXMO"
    "ay2/ev45pJRjZGdXzhbt0XHnHI1Gg0uXLgHwhRNfFKe/efqxa3/9y0+1DH4+VUCWZWmtVvM3"
    "b96k1WoV8fXeY61FCIFSiiRJCMMQgD9d/SPWjm8oqFQ4c+ZBlFKcOnUKYwx5nnP3XXer9/+1"
    "9rPnfvHrZ6Io8hMCjDFJmqZiaWkRay3OuQkBUkpee/1VHll5hKWlYzz80MOAmPCClJIgCFBK"
    "Ya3FGEMQBHQ6240LFy6ExphkQgCQpmmqWq02rVarELAfAu89Sime/sFqYfjNt94cy4EyvPcE"
    "QcAD3z2D1ho/qrIs4NixY0mn01GLiwsYY8YEGGOK7N+HUopzj54bIyuTj7a11gCzBaytrWWN"
    "RkNubW0VHgCK871POmr891cuY62bIB9FUKmwsnK2+HYaxP5dMD8/b1ZXV/Xm5ibXPnRcfd8X"
    "hPshOAystSBkvrcZ8fJXu6/+CEb+hN570263dbvd5karzo+f/DZfO7HIwfywvhXLFG+URvR6"
    "q8cvX7n2YDEwotDU6/M1Ywzm35IjtYAPPumzM8gBP8z3EqYOlibEQVUPNVlmEILW/nSRWdZa"
    "0+ls02636WeOei0gdx4hQCCGJkrFzyr+oLi94pwnzixJmoMXGxMe8N6n1WrIwsICaS6YCzXe"
    "pWg5uU0/szPbNb0kZ+6IpruT45wvbrZCQJ7nWbe7S6ezjbGfpxZqPB41FHDbD4LSYu9hNzFk"
    "uSPUkjgxztr85oQAa20aBBVqRxZpzAV4QCJuEedb8A6/sd7TSwzWebQSVANFP04zIcTmhADn"
    "XLq722NjO+Po/BImdyglplifudkxpMYxSC14UYQxUJLdfpoLDpJw1AOJ1hoVhtSp0E8t1pbM"
    "i7FqmGO+qK3zOA9Z7iZOpBiq3d5NXe79pADnXNzr9Whta2oLAb3YkOYOMdxlbh3GekzuyO1e"
    "hnsxQVFqjQ/ExrLTi5WQamoIEiEEMqyjdYVubNiNDXFmMcbtuVqU7U5JkJKXRtFPc/qJ0cwI"
    "wWAw6LPVrRLW4MbmgJ3BwVNu1v7EjCQtO0cA3UFGltvK346/t3XXWkmAc24AAqfnSK2jOzBk"
    "xo1ZmHUgZ0RibFxKweZOghRyEI08zcZyII5jurHl+J0hc1VNNfj/yMaWDF0khSBOUqQUO6Pz"
    "owL6AMZXqFcF83ri/VgYm4Xy/GjfeU+nkyK82JoQ0Gw2g5WVFdsdZGwPPB9tbA+f31NZbpt0"
    "tO89bGzs2MwM/txsNnUURTnseU4Cnzt58uTTJ+5bfTY5+nU15fd/KHhwAsjT/kcfvvPyT1rv"
    "Xb0K7ERR5PavtgbwJR2Gd1SrRxuUTvhh4Jwz1lqfI5wddLrAx8A6EEdR5EUURTSbTQkEgOLg"
    "vv204YfFAHkURQ5GnmSfFf4Ly7gkKLK7Ui8AAAAASUVORK5CYII=")
index.append('tango/actions/document-open')
catalog['tango/actions/document-open'] = tango_actions_document_open

#----------------------------------------------------------------------
tango_actions_document_save = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAB2pJ"
    "REFUWIXFl31wVNUVwH/3vre7yW42a9ZAMB8QjA0hoZSaGhSQIsjnEGiFWOugDqOlY/+xM7UD"
    "rf2gHafWkXHGP9qZUmf6h9NOdbCOLS2VDtFCizpolaAdIKABA6SLJpvNvpfd9969t3+EfU0C"
    "SB3p9Myceffr3fPbc849dx/8n0VcacHMtY93aCM2SWEWg4gicIzSBzDiub49W1/7nwHUr3wy"
    "bdvebxLx2IJ5bY2J6dOq5DWV5QSBon9gSL9xpK+QGcq/rfDv7N/9vTNXFaBu9eP1EWn2t8+Z"
    "kZs/t6lKSDE9YltYEiwpkVIgBBw5fkbt2X8kXwzMrf1/2nbkqgC0dW2P5vOxVxa1N50DUX82"
    "MzzNitiV06elK+e21ElLSoqeQhtDPGYz8GGOX+9+PaM9f96plx4590kBrMkD8cYVD11blVh4"
    "LpNr6e3P7B/Kuo8ODTsv9J05X37s5LmZNzTWROyIRdFT5As+6VScZKKs/L3+oeuzvX957lN5"
    "oL7ryXIrX+y2LDHHN3rNB3/87oHx842rfnpXujrxy3vXL6gYGikSKI0xhpp0gl89fyD34fDo"
    "ok8aCjm+Y40U5hlhTgda3THZOEDfn7f9dnBw9PfH+zLKtiR+oCn6GmfU5/OtjQkLs/mTGIdJ"
    "Hpix5tEN2oiWmyveftYY84tIJLLEsqwJkMN+nNFrbmT54nYGBvMEaiwXyqKSZ198mS9UHsMY"
    "E65XSinf9593XffePXv2FCcD2OM7WlunpQ7+obX+2aZNm5Z2dnYipQw3NMaQd4vctuVppAQv"
    "0GhtGBn1qUmnkHacnTt3YowZr9YzzzxzZ3d39xvAEx8LUPT16flNH4yIQTF/xYoV/OGVHr75"
    "5EsXuc22JUIIPF+htUEbQyxi4RQ8Zm98asLaL32xmYe6VtPd3f0AsAMwE/Ya38nse+Rf0Ws2"
    "fHXZ7benLcuiY3YN379/EU+/2MPShZ+lvCyKJQW2JRGA52u0MWhtMAK2bVmNlAJj4PXD73Nu"
    "4Dzf+PJcUqkUbW1tzUKIpbt27dp3WYALcv+qVavI5/P4vs/KjkYygy67D/6T225pI5MdxS0E"
    "GAzGjIXFLQa88NcTuMWA9uYaAq/AkaN9/PxbS9EqwHEcli9fzrvvvvt1YALAhATbsGHD9VOn"
    "Tl1aV1eH4zjYto1t22xeO5cbm6t59a1jTK0qRxlDNl9k4COH984Oc+Z8nmy+SFNtijIb/v7m"
    "MR57cDHpVBwpJaOjozQ3N1NRUbF+3bp1NZcFEEI8sHHjRuG6bqmP1hqlFA/f3cG0VIxX3zpB"
    "OllGdqRIzvVQeiyktdUVzLyukn0H3+Hbd7cz87pKjDEIITDG4Ps+y5Yti0Yikc2XBFiyZIkt"
    "hLivvb2dfD6PbdsYY1BKEQQBKvD5web5RPE52XeGm2ZPIxoZK6SViSg3tdTw8sF36Fwwg46W"
    "qSilwtMjpcR1XTo6OgC2bN++XV4EkE6n1yxatKg2EolQKBSQUhIEAZ7nUSwWKRaLaBXw6AM3"
    "k8sOc3bgI+bPnka8LMKtc+t57e1e6qtj3HHrjHC953kEQYBt23ieRzKZZM6cOTMPHz684iIA"
    "IcTXVq5cSS6XAyAIAowx4SbGGLTWRCzDjza3c/zkaQazOdbeMpPe98+Ryw7zYGcznufh+z6+"
    "7xMEAVJKlFJorXFdl8WLF2NZ1pYJAOvWrautrq5e1dDQgOM4KKXI5/MAlJeXh8VIKYVSispy"
    "yQ/v+RxvHu7lb2+eoOdoHw93tWAJQxAEaK0BKCsrQwhBLpdDa02hUKCpqYnKysrOrq6uuhDA"
    "tu371q9fb7uuixAi1NHRUXzfJ5FIEI/HiUajCCGwLIva6gRb75pDz9FTbP1KG1OrEkSjUeLx"
    "OMlkkmQyied5OI6DlBIpJZFIBKUUCxcutLXW98OFOiCEuLu9vR3XdamtrSWbzTIyMoIQgiAI"
    "wrZlWSSTSWDs/N+cTvO7nzRQUW4jpURrjdZ6LF+0Dt+RUpJKpaiurqa/v5+Ojg727t17D/Dj"
    "UiH6TDKZZGRkhLNnz6K1Rsqx9LAsKzSotQ7zodSP2eD7/gTPxWIxhPjPPWeMIZ/P4zgOWmum"
    "TJmC1vqG0ANAzPM8bNsOXxx/AZWeJajLzY+fK+n4uVJuDAwMhO2wFAdBwPHjxy/aQGs9+Xa7"
    "5Nh/uxagtrY2hA1/UokI4NChQ/T09NDb20t/fz+ZTIZsNovjOBSLxbDIlKqcMYbBwUEaGhrI"
    "ZrM0NDQwNDTE9OnTyWazNDY2hs/JtkKA8e4qxf1ycim3T567XDgAlFIf74FYLDYh3h8HMnnz"
    "yXOXkvG2whwoURljaG1tRSkVltCSy5VSCCEm1PkrwUweKx1tQIcAxpi+U6dONc6aNStMnFLy"
    "lNpX0rq6OrTWtLa24nkeLS0tFAoFmpubcRyHpqYmcrkcqVSqdNSPAWU2gOu639mxY8cTUsr6"
    "K/r9KohSqj+TyTwGREvVogy4FqgCKoEoELnKdj3GPoQKQA44D5wf/7dcAIkLWsYlvpo+pQQX"
    "tADkLwDxb1ieXX//pNp4AAAAAElFTkSuQmCC")
index.append('tango/actions/document-save')
catalog['tango/actions/document-save'] = tango_actions_document_save

#----------------------------------------------------------------------
documents_pickled = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAWdEVYdEF1dGhvcgBBbmRyZWFzIE5pbHNzb24r7+SjAAAAGHRFWHRDcmVhdGlvbiBUaW1l"
    "ADIwMDUtMTAtMTUNlAdXAAAASXRFWHRDb3B5cmlnaHQAUHVibGljIERvbWFpbiBodHRwOi8v"
    "Y3JlYXRpdmVjb21tb25zLm9yZy9saWNlbnNlcy9wdWJsaWNkb21haW4vWcP+ygAACABJREFU"
    "WIW1lsuPHNUVxr9zbt2qfs1097R72sNgDPYYsIkTGZEgRBagPDZJVuEfiLKIFCkPoSyD2JBV"
    "xIJFNkGKsogUKSGREilCUYIQCrEwgcSAH+AZz4Af8+yeftS76t57shhHQp7GDIsc6aqqbqnu"
    "+el8t+75SESwL1ZXT0Nkcf+LT4mVFZhLl4B3390bcbw3bwyc1jf9y5ffu/0T2gewvPyoGWz8"
    "JTz3N02s4He60O0uvMYsbBLDZgns5jrM1WXY1RWYa9dgwgilAObWSJxgYi3GxmJsHCbWocyp"
    "nJTuG88kybmPp/NuJ3Lh6Kn+b57vhP/4M0j7mD31MBonz0DddRRmZwP5zgaK/iaKW/dZFiFV"
    "QOKA1AGJACmAhLA3f+s6KoE4x1MA7gxgnvlpSR++6eCBP7MEdwgROADl7fP7JNg8caI7Zrk0"
    "9vjQ2BiZECNkxkSERkUBa0sYY8UZCzgDRY4EgOwlQWnhrNt7dgIIRMDM+ThcN07O/Epk544A"
    "AJAVZf/C8hqt3VgZPvH5fLFW7/iFzLrrw8rk/FrJV27strLCoChN9KMn1lYXm5NTIgyIYBBX"
    "tl8892A2TOSYtQ4Nla8tLTTqf33zvWdeeu7Hv7w9174y58Y9bZ2deW/5UvjVL4RHBL4sb3VG"
    "Fzfni81JfU5ItbSnQESwDo0/nr9nLKQB9gD2MNcw80db5a5iglKM0Pj3bfZ3t3qd9s+mSbMP"
    "wGPcPwljs9Qra5dvVKI/nZ/PPxxX29oPajONCiqBhu8pEABmYDvyjpZSH4I8gHyAPHr4yG5T"
    "KRbFBMWMYaHnGaIPBCBAqhTTynY1ffny7ExsuKU9j2brFdQCH9pjKMUgAhQRMuMW+/HMFpEH"
    "sAZIY65uajXNoWJGRUv4QGc8KaydcuBM+QsYiDz2sBXpuhWlmQkekwS+gmKUvaa/k0X+aDCO"
    "H2ImOMvqwnorW2gmewuQgq9R/cr9o9VmMJ5faAxmnEl7Zz/ouAMBOIeQPJaG79JTh7JrC/O+"
    "32q7IFCmUlEFuoeH3YrNtpbXeXNi3WFmYKVf018jXyDCYEKjgkZvNm8dmQ0Pi3PYLXUUZ/m0"
    "/PsBhDERETq9GAePPmg6TgmMqpFTCiQGymVy/NDggePzrbPnr5l5InCUoRMX1UHNN12AQZ5T"
    "pdSMsAbEAOLcOEqmSrBvD1hjQgJQrVhPRIikBEkGshHgYpDkqHhZ5Yv3jRY6Df0+gZAb1x0V"
    "zS1wAEc+CXxSSmmQFiIPjrQMwgMCMFQEB1hDDhCQ5GDJhCkWhUjgEgAOR9rRic8t8hXPQy6g"
    "4PpwJhL2AfYBDrDQMr2tsL0trOBESZplUyXYB1AU5QQA1ra9eHPkhSIO7CKwjUAuhJJECBZM"
    "zjt91+6JuZq/qpixFVW1kVohFEBIQ3vKzyWwufELC98CdMAKBGosADaimvfyO3PDVy/MXt0Z"
    "mfFglI0GI7cTpphYh4Ig6M4m9/bawZrnKRSlzCVlbQwOAK4ArHFXO+ut7rTXS6dEMK3vT9mE"
    "8SidkE9kndDNsnU07pfDG6Hpl+JXnBML1AfibFjzKV5oYdCpc9JPdFw6bua2GjWIILAAGXjs"
    "Ke05tRMGExG0DgQwmexM6q05eDClgBDaoJ1kQRsAxDmUBigNABGs7SK5dx7/6jT8j4T4aG71"
    "rpADYAGyAHs40o16b6823xFI80ASiMjYWAfl9gAEgJW9zmaF4EAQIQgxhLi2MXaPtxt6i5h1"
    "boLCiaLCVvM3LmIzzGphRcOvqrxKIHsggKWlpbwwBnCF85GFDgwRgrsF4YTgCAARSCkQKW8Q"
    "y/0L7eBKXGotFJRGPDue5F5aqhKkUAIskH1eYKoEAFCURrotE3TcR5tb+dyG4apvoZQh1gW4"
    "C2HFtxoNKUZqsOgcZZ7iLDOVrKrTma8/3q6yGxGsgrGFwhQz8okAWVmi17T+lx8a312UYRnn"
    "XhZlnCaFDs+utVevhIceU4qJmcFEYGbspnLcD9ywljXGNcVFy0+aTEoBQF46xmepQJ4b8bUo"
    "AAi09QJtG+0ZakCybqee1l98q7nsVLDgKfaZOSAiEBFSg3Y/dC04L72aNwdzgZFONQ7SPCUC"
    "pp5E0wHKEllx26a59Rsfaha97z/2Pu3GzZXlQe/m1bD1JSI1DyJAAOMclUZqk4xqa/0G0oSG"
    "w3joxNHUbjQVwDonUaqmlgwAmtVyvlmfzC92y6XZ697rK2HwKEBzDoAxDiySahYroEYhqlVa"
    "24e4qQBTna91ToYxGQhPPb3+F76S6iP33HzyVDf/NzEy5wSlEyDu74bXL6UgEidEuaXA7rn1"
    "gwEkWTFJTVW/8m79emkxBUL2bC8EisVb6myfnAvcFSuAsYI8aM4GvSXfOiGQmLcur7UL6146"
    "MMBr/7n4TfGqc++vB8kfzs5d3Brq8XSIPUNe9+PD98yOC4abGCtISp7JxG8q2PiV116JNgfD"
    "V6+/9MI+Rwx8gi0HgCd/+Nz3PM/7+Wyg08dPHlk+cyxvPnI8Pu5r50OwZ0C5IkI+HHzKZSb+"
    "z/p9y7uFfoBMOv77P9/wX3/nciXJi99f/e3z352a5E4AAEBEfPzbP3iBtf5Oo1bJW7UgPbZQ"
    "Mw/eHRTHes1oodtI14emvrKVVz/cSKs3+nFlOIkqYZK4KM1+vXqy9RN59lnziQk+DeDjcehb"
    "Ty9W/PwxCJ3xPXVaKXWMwE2BbDtnP8iMPU9O3m5pOXfhd7+IDrToZwH4f8V/AfURivkuNMG2"
    "AAAAAElFTkSuQmCC")
index.append('documents/pickled')
catalog['documents/pickled'] = documents_pickled

#----------------------------------------------------------------------
actions_terminal_on = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAOdEVYdFRpdGxlAFRlcm1pbmFs1fugkQAAABZ0RVh0QXV0aG9yAEFuZHJlYXMgTmlsc3Nv"
    "bivv5KMAAAAYdEVYdENyZWF0aW9uIFRpbWUAMjAwNS0xMC0xNQ2UB1cAAABJdEVYdENvcHly"
    "aWdodABQdWJsaWMgRG9tYWluIGh0dHA6Ly9jcmVhdGl2ZWNvbW1vbnMub3JnL2xpY2Vuc2Vz"
    "L3B1YmxpY2RvbWFpbi9Zw/7KAAAGCUlEQVRYhcWXz29dRxXHP3PftZ/9nuMfTWgFTtMQXDUO"
    "hcQtJUWARBELJEBtF0ioUhfAIlJFu0KI/wAJsWCFiNmw6AohgWhYdMGvpC21EyVO0pa2cpPX"
    "qLEd1XZsvx/3zdyZc1jMfc/Pfq5QS6Aj2ZqZ++6c7/me7zlnrlFVPs6RfKzWgRRgdnZ2YGx8"
    "+OfDlcq39u8/MAbmP7ymiCgqggKiioqCBkRBVRFVUEVE4lqEEIIurSxtbayv/bl2beknp0+f"
    "zlOAsYnh3z00c/LbleFK2mw14Q5HRTv/FWaOP3zP2u21H71w5o+HgSfN88//5uDkwcOX7rvv"
    "yIHV1VVWlldoNBt9hxhjun+96w/zrFwuMzExwdjoGHMXXl2dX7gwk0piZiYn753Y3Nzk/IVL"
    "vPiXV2g2WxHzDiYUVQNGC5cM21T1zre9Nj1z1HDXXeM8+Z1vcGx6iqkjUxP/PP/KTIpSLZVK"
    "pRACtRs3WXz7TT518DCVkdHumdohUYuZdsD1rqNJLahWdIcDrcYWVy5f5GtfPUmWZSSJKYnz"
    "1XQ3bBHhgWMz3Hv4CCraFRmFcRGNQFS7xkQKKIX4RLbBdX6//F6N5ZvXURTrLGlaIneBdKd9"
    "JYRA7j02l8IQ2wY7nhUGRbQITQGiA9QUIArQKkruAyEIRsFZi8oAQRwpCJ1iZExkwFpHO2tv"
    "GxbtUtpNMbRIL0M8o0hH3Q6BCFjraGWW5VurNFttMIq1FkVxLpA6F7qxSkxCCAGbtWjWN3uo"
    "V6Kzsg2ioBYK2pVuCOqNFo1Gi3qjVYCF5tY6IXhQsNZijCGEQCohdEWWJHHTWUuWtRgZHcda"
    "h80aRbEBifyjyI7w5N6zfnuLrXozhmZXLdOQoyKRAWdJkuhs6nIXq1iRsxIC1jmszTnyibv5"
    "7uNf59zca8yfX2BzYx2RsEN0PgQ2NhvU64W3xsQE7KZqHFEjEbSzljSN8ktDCKgq3nuMEkPQ"
    "tmRZRr3eZKQ6zFNPfJlvPvYQf335Kmdfmmdl+SY+d2zVWzSbrUKMvcP0LUNwEYAErA0MDA5G"
    "AC6EaNQ5jFGCBLKsyeDWbS5fnOfZH7/J0elpPnt0ii8cn+Kxr5zgD2fOMXt6ljx3XVtmr/7R"
    "syXOoiJR5M4ymJcLBpyLqecsqgbxgXaWMVCO1TCzbf71RvTQOs+jXzxOdaSC9w4J+R72zJ69"
    "TIIvmlMgzy3DzndCIITgsdZCwUC73cbUW9w//Xmee+Zppu8/iCr87eXL/OwXv+bC3BzeuT53"
    "1UCn6eymQCQUIYhpmOfx/TQvGLDOgoKzjo2NDdpWSNMShybv4fcvnONPZ17krdevEnLbz/EO"
    "j03/zEQGNLZknLO4PC8YkEID1sZKroJ4i89b1K4t8r2nn+G9G+8gPu+eZvpt7V4UW9u/DbmN"
    "DBBBiIQIwLnQzX0tCrsEj/ic2ttX+g/d4fheF5cP1oDGXIzr2DBIQ3A9DBhEoybEh36vDAxV"
    "xvnBqVOUywN7YvvH31/i0tzZvv3Q0QC7AHTS0OWOKCBBvMcnrofqHjGFnGNHP8O+feV+gBgW"
    "Ll0meNe7Fd/zebcQ7WTAbWsAY2JRytuo+j09zF2DU99/as9nEEt1yHdnCAS/KwSh0EAIeRdA"
    "khiq1RGazfoHGvhvRqVSxRQhCB0G8k4InEURnn3uFBKUJEm6d7ne+YcZ3ntc3sZgKJeHSJIS"
    "zWwLILIBpM7a5dW1VVupVMtra6tAkefho3v6wJfuZun9GmtXDOXyIGmphJDQbGbRaJqS2XZG"
    "0JXk3XfeemNu7tWNBx/8HKVS6aNb7RlL79cI4hkaGmJgcJCBcplqpQrEjlutVrm1srK5sPDa"
    "Ynr27EVbGT3wy/n5+Z8+8sijY4kxqApBBAkSC5PEGh7vBLGhiEhx/wto57koooJkgoqw75MC"
    "mOKe4ZkYn8A6x7Xr128v37r1q8XFRWeAQWD/iYdPnDx0aPKHaZp+2hhM/5XiDgxF8ty/W6vd"
    "+O3VhavngXWjqhhjBoBRoFIAKvG/+W7MiepqA3VVbZrdX8fGmIT4zXjnGQAPiPYY7QPw/x7/"
    "BrCRnYfwb6HjAAAAAElFTkSuQmCC")
index.append('actions/terminal-on')
catalog['actions/terminal-on'] = actions_terminal_on

#----------------------------------------------------------------------
tango_actions_edit_clear = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABklJ"
    "REFUWIW11X1sXXUdx/H3Offcx/be23Zt16127bqVh7WF2bGxjT2wERDMiImTsWRWUzZq4gMx"
    "6GJE0QlGDaAY2DIVEspAY9oxE5QC20RdXdlE2UNXuqeSPtzH3rb34dzH8+gf3uKdlHR26zf5"
    "5uR3cnLO6/c5v3N+AgX13H3YKbO8ZMJ9mGgCZjeq8e1HuogwRyUUDp7fIf2k5oZbHm2552v2"
    "XCaBb+CYdvb46yO6qjc92kVmLgDSlRzzS7fc2WY/cuC7KKpGSUWNtLC+cWHgw/5W0H8zFwCx"
    "cGAYpleOBrG4ynjwqYvI0THqG9c7BIEf7tlz5bVzAhAR3k3HfKahpDn4WDMSOSprm/CUVno9"
    "Fy33zwXAUji4t9n8IDR8ofXuHY9bXUYEtxEEDIq9lbaw//LSN8+aL8wp4K0+gp9pMoQJ//nV"
    "TRtbralQH9noEKWLljN8+YPSu27Wug+fI3Q9AR97r9EG46eToZFzF04e0koWr0NTMsjBARZU"
    "VdmcDuEH7/7W/vzfOzA7O6/Ez7aE6U7+fDs1Foulv+X2jW4zM046HsJWIWIrmWBBw3olMvIP"
    "i5FOLrljF8NzAgD45YOWB6wO60s337qwyF4axD2vhvoVrUAZr7R/X7lwOJZQVbN9H/xhTgC9"
    "r7A0IwvHi7zeyoaVX8BbsYwTr/bwxp6j1DmLWGCIHAkEZA1q90N0tgBpupM9HXzLMMRnFt50"
    "o1656DaCfWH2734NKWHS3rIaryji8/lwhMNiWtdbgD/PFjBtAscOsFE0OCII1cb7HZp95MQ4"
    "axxuVtYvobSqivcCfv440EfNbaa+6mEGTMP4zro2uq8bAODEq3i62gnV53Au08FTUoLs9fK3"
    "RATrfMHctq9dWLyijlhkkOFzr6ez8tBBr4OHG7ehXBcAwCMwtA5q3cBZh8i4Dbb8eAvrd7Zj"
    "5noh9z6KbkUxGgkO9mYnfcfO5DTu3dRG7LoAvgKftQt0CVacn95azPZnnxBsdhXTiKNlx7AI"
    "4+i6HzmRwrCtIRlPq6GBzlEMfcPaL+O/ZkAe0bD1FzzRuOn+7fOrq0ALo1NKJpXE7lDRs34U"
    "LUEsGsXmXocoLjGGz/xqwsylNqxt4/xM959xh/s1XCqaR1IzVBQ1BUYMJR3EbhNIjIdBkNBy"
    "BnaHl1igG00bEOtXPVYuOctP9hzg9msGAGDgVzNxQ1VB02R0dRJBSGJoObKpNEpWx9QzFHnr"
    "mRx5m2yiR6hf/binyN3wzvGX+eI1AwyBD9OJSFbT7KSSCRAypBNBSsqLiQSCuDxekjENhAju"
    "imYmho8SD3VSt3K3q6R68wu9B3ixtxPnrAEC/Csjh3VD8JCSExiGQiI6jkVSKCpxEx714fJU"
    "I0dSmNooZTVrifr+ydjgfhbe9ICj+tZvtopa8cjxDrbOCnDHEANaThY0NUVOtaHkkihKjmQ8"
    "SmlVHYkJGYuUQ5SqSccmMfRRKpfeSWp8kJHTP8Nd1mC7Yf1z5aLNe7Cng/bCe1/Vlvqjv2Lu"
    "/DwtNpdnmSgVoaRHEUSJtJzG6S7G7lpEeKifirpmov4IgmUcq8OLZ/5yTM1K4MIhUuNnlGRi"
    "dO9Xn+HpSATj/0oAkGJxXo4F+2Wnu4mUrGK124hPZMgk/BSX14NYTCp6kXmLVyGPCaiZMC7P"
    "GoorlqNn47mgr79j00M82d+PE3ACNkC4mgSsgK27F/+2zeldnsoGt2F4UZXLWB11yBMBHB4P"
    "Tk8tocHTlFU34PA0Ex29TCp+XgldejP+l5P6Qzv30JmfsFDYMwEseYA1m0W6ZzWywxLdUFG7"
    "xZoYO4W7opZYIIQoJXGVLsfEgZLSsTlLjHjotBYKRnq/8RS7ug7jK3hoYZkz/QmlfFRWwOZ0"
    "YntrL+98qnHzUsm+QjT1U0jWGkb7u6hr+Trp+KAeGjgkTsj6e7/7E3t//zaXABVQPuk4E+Cj"
    "BKYgu9u48XMbhe7qxh2ubDKF1ZY2Jn2n1Gw6QmDMfKPrKAdfO8IwoANavtX/6SmAOuNekE/B"
    "WtDSvu+xuXkJT+omRjzBidMXOfz0i/SlVMypaPOtTwMpBOWuBgD/eXcfAfJtKWiR/y6wQoCR"
    "7ynE1FHJ94xrYLqyFCDE/Fjg4590IWJq1lOJXDGza63C1V2YQCHiE+vfNMHbBDmTKQEAAAAA"
    "SUVORK5CYII=")
index.append('tango/actions/edit-clear')
catalog['tango/actions/edit-clear'] = tango_actions_edit_clear

#----------------------------------------------------------------------
tango_apps_utilities_terminal = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABYdJ"
    "REFUWIXllu+PXUUZxz8zc3Yvi7tLA9mCSKMUKm1JyIrtWqAYNdESasTEV2BifGGICYl/gCER"
    "FQIiP14Z4IW8QAgJP1xrxBRCAkQo2EKXbi1slbLbKpTt7ra7vXfvvTNnZh5fnHPPPXfv3caU"
    "Gl/43Mw9c54z53m+8/3OM3Pg/90UwBNP/3aLRv8mSrxGRM77T14UEUIIxBiL1n0fibHtE6Gp"
    "FJNpmt5x1533vA2gnnzy8c2637x17ejY4NqRi1WSJOd8liKCiOCc458fHZMXXvhDrVFrbLv3"
    "3gffS5TRj41es2VweGhYzRydxnt/zgG0LEkSRi5aq3Z8c+fgrj+NPwbcmHj81ksu/qyaOTrN"
    "G2/8hf3vHECidL2slEJrjdYaY0zRL7cz+Y3RXLFhPbJBWLfu86rRaG4FSIhUkiTBWsvE/gNM"
    "TL6JSfpA2iCk9S9tTxmilMYiQutXepkYAz+49XYuv3w9Rmucs5UMQG4hBJRSKKX56d0/RgCR"
    "mAXKNWwFzTSNefxYaAylcSIdMR6+63dobbDW4r0vpO5acan3zM8uFUlEOpNICUxxjTGDIlni"
    "KBGE7JqD8D5gjME5S3omACAk57VmqRCyYJIrIMXMpORX+axVBgKVK6bacSRiTM5AmrYBhBDa"
    "Cw3waWDu+CnMYIW02sxYiK0Z54zktHZSnz3LZi8472g0a9QbVZrNOqerSwWA1JcAlMtOG4MQ"
    "MRXhis2bMGj+/v4EoenyZO2azmZYlgRCTGnUq1SXF2naeh4U+j6TVZExBmctqXN4n3YDMMZk"
    "DHyyyBeuhh1bb2H95zbz2lsvMjM1RbA+29GQNisx4n3KyaU5qrXFUkUolGoL21oD1lpcmuJ9"
    "6A1ARFBJ5NDBvcSY8uWN13Prt3/EgU372PPXlzj58SziM7pD9JyunqRWX0KUMDDUT5FzRUeR"
    "MWCdwzlX5Ey898U2abQhTT0Ls0vE46c49t4xXh7czdVfGuXa0W3c9r072PXyM7z90mvU6zUW"
    "qwvEEDvXsKKneR9RShUSdAKIEecsSmuiREQHlIqgFMp4RAVEZWXmxXK6fgLrLH0VnYkM2dhe"
    "mVXxGABrLdbaTgAx5gwYjU8DC7OLDF96IWM3bOfrY99i7UWX8Pq7r/DoIw8x/bfDxDR0JejK"
    "u8LvfWwDcCsBSMS5FKMNMQbSYNny1ev54U238+7RCR55+gEm39yLr3uMBlMxXclX034lGOss"
    "rsxAmuYSWIs2Btu0HJv5F5/MHuf+J37J7l1/pDFfK50DrdirUL6SlHxs9FkAZy3NXhJY5zBa"
    "I4A2mld2v0hjroYEQWvdk9ays+uR6rgU50j2odKuvLwKskVojCGGSL1qqVdtV5SxW7Zz1YaN"
    "q071ww8/YM/4qz2ZiUFK/Xbl5AxEUudQWhd7fgt3i0KAjV/cxJ3f/3mP8Jk9+PtfsWf81U61"
    "cjTlI9uvZCAW+4AmRqFZ96C6aT18+DC/fva+VQFMTR3CLuc1XgIOEEsfOeXzp9gHrLMkSR9a"
    "axaOn+6Z4PmHxnme8VUBnMm0NoX2XQCixLw0NL/42d0kSXLGT62zsRA8c3MnugGEEOxyrVbR"
    "2rC8XKNer51VgrJ95yejTC78mZmnLmVxcbHwr1mzpjiQlFIWQAfv9+2feEe+MraNgYGBT50c"
    "YN+J57ChXtwPDQ1x2WXrMMZwwfAFzM3PiUQmgWF183dvHl0zPPT6zh07z7/yyg2qUqkQQiDE"
    "SAwh67daDMQQCbHTH/Pxnfetfnu8tZb5+Tk5Mn2kOXVo6raDB9/fq4D+7V+77hsjIyP3a62v"
    "Auk/JzT0NJX6NJ3+4B9HHjh0cGoPcLJVJwPAhcBQ3u9j1WPmrE2ACASgAZwC5stJFNBfav8N"
    "SwEP2BzI/97+DW/pAZYYDwhcAAAAAElFTkSuQmCC")
index.append('tango/apps/utilities-terminal')
catalog['tango/apps/utilities-terminal'] = tango_apps_utilities_terminal

#----------------------------------------------------------------------
tango_actions_media_seek_forward = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABGxJ"
    "REFUWIXtlFtsFFUYx/9nLju7O7OzszPusssud+pLgbWYYIxJC0EKiRfAWB+aUoUXnqwl+KYR"
    "IhESuZPwKuKDD5qCDybVxAR4QYRAa4wGlHaLKVja7uxuu9u5z/Fhaa1l28Kbif0nk3zJ+Z3J"
    "L9/5zgEWspCF/N/DTqtVAIsACAAsAP48e5+Wn1cg3bx1c9/iTJop6IUB27bdRz+eLU/Lzyug"
    "rVq98t09u/c8N14utUhyZHDowZAOwAbg1tirrlq9suOdt3c3lCtjLVFFGSzoBd113dn4uQVk"
    "WVYzS9IdRz89zm9pbpbv5XLbYmo0y3GBO6Zp2rZtmwDoJJ9IJGLJ1KKOY0dPcFuat8q5/r5t"
    "shzJhkLhOwzDWOVy2ZrOzyuQSCRi8bjWsautHZT6ePWV1/i6Z+uW3/n9duszcc0Xw9KALMue"
    "rusWAKRSKTWmKjP41ct/u/1ra1SRfTWm3ZNl2c3n8/YTCSxbtiwWiYjv7Wprx3hlHI5rI5NZ"
    "yrS8+VbANCc2jOYf7gwFhb5YTCtpmmbJsiyHQkJt3jBeGBq+v1MMh/tTqXRJlmVrZGTEqyVA"
    "JovGxsYVwRDf//13P6A4VgABAQjAsxwEIYSHw0M4cOAjc+jhX92m4xxiPKYI4j3GcyyH4Aze"
    "Aw4F2eCf2Wy2cPDgwX/dlqkONDQ0KCC0s7W1DYWSDs/z4Ho+XNeBaRmQpAh2bH+DW5zO1P3y"
    "c28bYUmREGxubW2DZVsgDAFDGACA6zqQpAi2v76DS6fTdT03b7b5vm9UKhODqqqWBwYGpiSY"
    "yUJRFEiSCADgWB4sy4FjGRDCgFKgPFFGabyITU2buBMnTkdCQeGwKFZ527arn2PBtEwYpoHi"
    "WAGl8SI2Nm3iTp48EwkI3GHft1rWrl0bnt4BbrLQNI0WilUxQQiCkOrpUOrD930EeAFBQcC1"
    "n350z39xzojK0cOO6xyZn7/qfn7+nBFTYp9Eo9qX4XB4oqZAPB6ntlNdCwYEgBBQvyrE8wHo"
    "eh6nTh839LzerSbih+SgrA/eHzgyJ3/qmKHrencilfpYjaj3Ojs7S4QQWlMgEolQ8dERsBwH"
    "3/fB8jyoT9Hd/a15/ca1Bwxh92fXrb9qGEaB5/lkoTQyO3/92gOeZ/dn1z1/1TCMwt69e519"
    "+/ZhZqYEotEo1YtVAc/zwHM8+nN97sVvuizf946tqW/4zDTNfHt7ewUAurq66OQM/MPfdS9c"
    "7LIo9Y+uWdNwbjo/W6YEVFXFyGh1PmzbxoWLXxuj+ZHLyUTiw0xmRf+VK1fGpl8hRVGoNG0I"
    "uy58ZeTzo5eXpBd/kEwuzc3k5xVQFIWKkohbPTeM3t5beS4QeH99dsMlRVGK9fX1j71mmqZB"
    "lMK42XPd6O25lRcCof0vvdh0SRCEUi3+SQR8URTRn/vjTFPjy2crlYqezWZnbd8kn8vdPbOx"
    "actZSZL0ZDI5Z7trZeolHB4eliilYiAQsBRFGSOEzNk+SqlUqVREx3GeiF/IQhbyn83fWcMo"
    "fSJnzd4AAAAASUVORK5CYII=")
index.append('tango/actions/media-seek-forward')
catalog['tango/actions/media-seek-forward'] = tango_actions_media_seek_forward

#----------------------------------------------------------------------
tango_actions_document_save_as = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABuRJ"
    "REFUWIXFl21sFMcZx38zu3e+F5+NjWUTY7Adp5apXUpzjUkwGILDq7BpAw4pIkQISpV+SaWm"
    "gjZ9oRVSGgVZ6odWCo3UD6hViYiitLQ0VDgBCkmkULAJFWBIDAHbmATs4259t7sz0w/YV9uQ"
    "Ypqg/qXRzuw9euZ3z8z8NQv/Z4k7BVSueLFeG7FOCtMIIoggZZQ+jBGvdu/b8u49Ayhb0lZo"
    "2+4fopGcObNqK6LTpxTISXlhfF9xqe+6fv9kd7r/evKEwnvi0t4fX/5CAaYue7EsIM2heF15"
    "YvbMqgIhxfSAbWFJsKRESoEQcPLsZbXv0MlkxjfzLv1168kvBKC2dVswmcx5e268qhdEWU//"
    "4BQrYOdNn1KYN7NmqrSkJOMqtDFEcmz6Pknw+73v9WvXm3Xhzed77xbAGv8iUrH42ckF0Ybe"
    "/kRN16X+Q9cHnO3XB1Ovd1++Gj5zvrfygYqSgB2wyLiKZNqjMD9CLBoKf3jp+v0DXX9/9XNV"
    "oKy1LWwlM+2WJeo8o5d//JcfHR79e8XSXz5ZWBT97fqVc3Kv38jgK40xhpLCKL977XDik8Gh"
    "uXe7FHL0wLqRnmWEuehr9fj4yQG6/7b1j9euDf3pbHe/si2J52syniY15PG1L1dELcyGu5kc"
    "xlWgfPn2VdqImodzT+w2xrwcCAQWWJY1BnLQizA06UEWNcbpu5bEVzf3Qigo2f3GW3w97wzG"
    "mGy8Ukp5nvea4zjr9+3blxkPYI8eaG1dlNr/p9b61+vWrVvY3NyMlDKb0BhD0snw6OZXkBJc"
    "X6O14caQR0lhPtKOsHPnTowxo5u1a9euJ9rb298HXvqvABlPX5xd9fENcU3MXrx4MX9+u5Pv"
    "tb15S9lsWyKEwPUUWhu0MeQELFJplxmrfzUm9hvzq3m2dRnt7e2bgB2AGZNr9KD/wPNXgpNW"
    "favpsccKLcuifkYJP9k4l1fe6GRhw1cIh4JYUmBbEgG4nkYbg9YGI2Dr5mVIKTAG3uv4iN6+"
    "q3z3mzPJz8+ntra2WgixcM+ePQc+E2BYG5cuXUoymcTzPJbUV9B/zWHv0X/x6CO19A8M4aR9"
    "DAZjbi6Lk/F5/eA5nIxPvLoE301z8nQ3v/n+QrTySaVSLFq0iFOnTn0HGAMwZoOtWrXq/uLi"
    "4oVTp04llUph2za2bbNhxUwerC7ineNnKC4Io4xhIJmh79MUH/YMcvlqkoFkhqrSfEI2HDl2"
    "hheeaaQwP4KUkqGhIaqrq8nNzV3Z0tJS8pkAQohNq1evFo7jjIzRWqOU4rm19UzJz+Gd4+co"
    "jIUYuJEh4bgofXNJS4tyqbwvjwNHP+AHa+NU3peHMQYhBMYYPM+jqakpGAgENtwWYMGCBbYQ"
    "4ul4PE4ymcS2bYwxKKXwfR/le/x0w2yCeJzvvsxDM6YQDNw00rxokIdqSnjr6Ac0zymnvqYY"
    "pVT29EgpcRyH+vp6gM3btm2TtwAUFhYunzt3bmkgECCdTiOlxPd9XNclk8mQyWTQymf7podJ"
    "DAzS0/cps2dMIRIKMG9mGe+e6KKsKIfH55Vn413Xxfd9bNvGdV1isRh1dXWVHR0di28BEEJ8"
    "e8mSJSQSCQB838cYk01ijEFrTcAy/HxDnLPnL3JtIMGKRyrp+qiXxMAgzzRX47ounufheR6+"
    "7yOlRCmF1hrHcWhsbMSyrM1jAFpaWkqLioqWTps2jVQqhVKKZDIJQDgczpqRUgqlFHlhyc+e"
    "+irHOrr4x7FzdJ7u5rnWGixh8H0frTUAoVAIIQSJRAKtNel0mqqqKvLy8ppbW1unZgFs2356"
    "5cqVtuM4CCGybWhoCM/ziEajRCIRgsEgQggsy6K0KMqWJ+voPH2BLWtqKS6IEgwGiUQixGIx"
    "YrEYruuSSqWQUiKlJBAIoJSioaHB1lpvhGEfEEKsjcfjHDlyhI6ODnzfZ6JaH4euziN0dd45"
    "1rZt6urqqK+vZ//+/U8Bvxgxoi/FYjGOHz/OmjVryMnJmTDA3SiTybB7924aGhrQWj8A/3HC"
    "HNd10VozadIkDh48OKGE8+fPp7S0lJ6engnFh8NhtNb09fVl90nWikfKHo1Gse3bOfStikaj"
    "Y54T1ZUrV7L97EwjRLm5uQQCgQklys3NHfOcqEbmglE+MPoSca+llMr2x1RgxDKbm5v/p2R3"
    "kuM4SCnHVCALoJSivLyctra2uzqGdyPbtpk8efJIfp0FMMZ0X7hwoaKpqSlruVrrMf07tRG7"
    "HXmOfz86X09PD1rrM0DIHi7ND3fs2PGSlLLsnvz1cVJKXerv738BCI7cikPAZKAAyAOCwMSO"
    "wsTlcvNDKA0kgKvA1dHXcgFEh1uI23w1fU75wy0NJIeB+DdAoXGCgbptnwAAAABJRU5ErkJg"
    "gg==")
index.append('tango/actions/document-save-as')
catalog['tango/actions/document-save-as'] = tango_actions_document_save_as

#----------------------------------------------------------------------
copy_textab = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAWdEVYdEF1dGhvcgBBbmRyZWFzIE5pbHNzb24r7+SjAAAAGHRFWHRDcmVhdGlvbiBUaW1l"
    "ADIwMDUtMTAtMTB9/vPYAAAASXRFWHRDb3B5cmlnaHQAUHVibGljIERvbWFpbiBodHRwOi8v"
    "Y3JlYXRpdmVjb21tb25zLm9yZy9saWNlbnNlcy9wdWJsaWNkb21haW4vWcP+ygAABrZJREFU"
    "WIWtl1tsHFcZx3/nMuNZ73rXt7U3iS+lNEmbAElbqREJIm1QLUoF4hZDH9JcilTgjRde4Rmp"
    "LQhaeEBQv1BUhEKgDUih8JIEcUnah+ZCk6hN17HXXsfO2rvr3Z2Zc3jY3fFu7DiXcqSjGc2c"
    "7/t+53/O980ZYa3lXtqBAweeT6USv9BatT33/cAWi8tfmZiYOHYnfvTdBh4fH1eO4+yRUu7N"
    "ZPqA9gkEgRGFQvHJgwcPzk5MTPzjdv7ErRT4/tMDmXSf+5pWwms+s8B0bM+DiYH7U1pLYYFq"
    "tQqIyM7zPASWmh/Y4tSFuYHlM1dsC2TNmIWcH4y//PpsEdZRIDPQ8caurfFHEYqSMwxCYi0s"
    "zm9ky9YHuPXSCYQArbV4u1RIP7S5mgawJkSVruIoy8lzxQnga+sCeI5wpYC8u43Hn/slStXX"
    "+t8vvUCxuITvBzTlX2Gx0VVrFzfey77v/giAcrnMsRf3s8FO40iRbFrcwR6QAARBAECtViOb"
    "nVxHgYaVVDhOZ2QnZV1BC5iWcesCWNs+GODIkW9x4sRfCQJ/XYCODpd9+z7X8GOj4HXuFfj1"
    "AWiVt956enoYH9+/bvA2Hy0OjGGVcrdRwEawhUKBo0eP3kXglftnnvkmSum6ErQn7i0BbEsH"
    "SKVSHDp0iJmZWYwJkVIxODjQZnP9+nWq1RpgI6l7e3txHAdjzJqK3loBWx98s4FSEiGIsqK1"
    "SSkbz9uzo3k1a/hbXwELpuGsUqly8eKFtjHZbLYR4OZ0rHuwFq5dm2T79k8g1UoWtK7BbbOg"
    "6dTzOti5cye5XA5j6rnR3d1NLBaLIObn51leXo5sOztjpFLdDRi7pqLrAqwlWbSe1jZye2X2"
    "Wmscx41m39x4zffmbupAxlZjCV8y6zbVqDtyXbcBAJVKBWvBdZ0ooOuaaAPG4/EIJgzDu1Og"
    "gK7tFCEj4Tnk+eMEW8aw1pLP5wnD+hyEoLHLU4BlcXGRUqkYBYnHEwghsNZiTNhQ1N5+Dwgh"
    "xE+eGw7nTUDmoST20gu4F1+n3P8YmUcOIJWDUpLmh6epTjqdJp1OtxSb+torpfB9/87qgBBC"
    "ANI3ViyVfQZrGlH+J65zCXdpEn38FFN2mKnN32DDhgx9ff2RzFNT11hcXIqWbGRkhFQqhVKK"
    "SrWyKgNWATSCq3e+6mzv39R5/8DDj2CLZ0HGELUlqP2HRO+j9FyPYzdsIJGIY4yJZE6nB+jt"
    "7UMIgVIKz/NwXRelFFKIVevfBtAMnj0S+2J6166fywc+1ilyp7DWgJMALML4FPIeP73Sh5r9"
    "LZ7noZSiblpXQUoZdaUUUkoOHz7MzOwMSGdtgKbs157verp/71OvMDIyaPJnEMJBxjdRLXTh"
    "dX4AOsHMe5LdY19ieHiIZDKF4zgIIaKAWmvmF+aZm8vj+z5BGPDmn//Eh9kPwd78bV1RQLwx"
    "xkDvY3t/bD++LUNtEWtC0Js4d/Iy/63F+PKejdQKgn91f4GM1kipIukdx0FrHQGcv/Au5dIy"
    "WmussdxYKOC6Lr4NVwM0pd+3a/PP7Cf33If1ESrGcl6a06fPyNeuD7Nt9xg3Zt6iWBXEH9xK"
    "V1cXWmu01riuuwpAKU1nLE4QBOTmppmZzeFqJzo5GmNVqwLib2P0i089/oRVHtYIgtzU8ivH"
    "3qkUPK9noDfBli2byU+/z8LoHgYHB0mlUiQSCTzPa1S/OoCUkkplmUKhQBgYcrNT5GfnSCYS"
    "ZDKDzEw2AdBCiE5rbVkDPLwl/fVwdHuPUA6iush7v//jB+8uye4daU0YF/iVIleGnkQIibMw"
    "Q6U0Tz7nopQAIRAIgiDA92sEvk8+P02pWKRcXKK/O0EyGSf0yxDWAAit1UAcqAPoru5tNtaN"
    "rd1g+cRfKj/83dyx9KeTz6a7NEJkqbz9EhWaKVwvPs2jeHRsMza610KQspYUQAFCIMSQEmU6"
    "HIUxSMARQkgNIMOwEiqNqRbInc3ahK/s+Wzp1dEB5ztxTwktC+3nXgGivaKuOjuu1QTYi4s1"
    "/+zl0oute8CGpeWTzGa/TXXRm5wrmR39ic9cvVZ69QeXpvdTPxbL1vgfoQVAGVgAqtZaowGS"
    "L0//oXzf8bOV3U/tHujpKPbu3Hj1CT9WPf3WqRlANfpHDd4EqAJLQP3PyFprhRCmOvX+9zrO"
    "/P1XozuGBicvxy8VTPJ0Y5DiHv4h1wGoASVrbRVa/g2FEGLhcGwoNjT6mzA/O2SqwVjXrxcv"
    "NwxX19B7BLC2vRxGM7N1kqwQ4rMLz8aGk0n389baS43Xtf8TwKr2P+isPLBV/G5YAAAAAElF"
    "TkSuQmCC")
index.append('copy/textab')
catalog['copy/textab'] = copy_textab

#----------------------------------------------------------------------
documents_python = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAAEl0RVh0Q29weXJpZ2h0AFB1Ymxp"
    "YyBEb21haW4gaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9t"
    "YWluL1nD/soAAAbHSURBVFiFpVdbjBtXGf7OmfGM7/Z6vZfutcnmsgpN1E2ziJRCsi1BoIby"
    "gJoWCV4iXiAgVEBQUCBCSIiLKqQCEiBe4AUJ1AqpohUFdhUKNBVpk6YskJA0yW6d9e6668va"
    "67md8/PgmfGM7ZAFjnR0Zsb2/33/93//OWNGRPhvxvj9n8g5iOwCYwMcGATxOIhKjLESFF4q"
    "qP2LtHDG2W48tl0CY+/57Md5RD2talo2mkopajSqRXQ9BqYojtk0bKNp2k3TMWpVi4T4RiGS"
    "/+l2iGyLwMTRJ76azA88MXbvvX1mo4FoOg2SEiQlpL8KkJRwLAvlpeXNWnHlrVhCzvzr+afN"
    "/xSbbyd7xvmpiYMH+64szFeuv3Lu7LU//6kcAicJIoIkCaZwZCfHU5nRkR3NOv/anWLfkcDg"
    "3KmkqmmsUa5Akpxfmn/qqFmvbzq2BSIX3CdDkJJAUiKWy0UZw/H/mwAaSDJFQbwvC86VByfn"
    "Pv9aNJVKMa74ZQhNVw0eUUGg3J3Cq3ckAACuTXYfOZo1G/UZNRpzpae2Cj3U2M7YFoFmrZq6"
    "PD9fAgihsETQU2ltYO/udC81sA0OXQRG3vWp+9R49CTAjjNAjyV1AKiRcALx2leOabq1l11q"
    "pPWa8v0va+u6pgtiIJLSYJw9W2SNL505Q06IADtxQhlfH/t9ZuSuA/1378glBwYAINBmwVV0"
    "yN2qO7kG9CYHsaGhIXnio48NAYBlGnj9wsVPXnj1wgEAx4CACcfXR7+V37HznTsPvzuXGhoG"
    "wMKgoeyoB6lgJ8hurUlAizDMHjoQS6aTM099ge3zCbC5r6uMKR8b3jsdJ/Kc7GblXXfVmHq4"
    "vzU9f3BGkjMOSNudDkAOHjg8059MxL7pExgxi/vj2awK1kvyHtlScPNxOyFQCgBwDAPD6eLa"
    "4HA+BmoBe0QmxgbBGZv1CUiwXdFMJt5bUq/dqF2C25AMbuubK8XysanXsOPusZSvQIBINKrz"
    "bz/JMioAqKp2TzSZipMLFC5DWHa72YRjWQBRu+aQgFt3YdlorK+//b6xFy/vmUzuGx8d9KUH"
    "CX/2ZxPKWqm8RwUAHlH3qbFol5H8eyGwcfNmo7m6XB9JFd7Oa/Wm346BXpcAJtJrzf2zNwb3"
    "TA2/46G5I5lW5m3gFhmBfC6Z4gy71ZZB5bJjGKBUKmwyV4Fbly6VHxp94fVD01f3T0xO3JVI"
    "JLSww1vwnBFlMrnE6Mg068skXEAPPKyAbVk2gKYKALZlXjTqm1Y836+F2k0SqoWCeSj30hsf"
    "mKnc98iHT6ZUtWPvCmYXyNBfPeAOIqul6hZJLHIA4MSvGbVavdd2unlrpTo3dWHnw8cf7gAn"
    "11BOoM08o9nh1pPuM2rfV6pbNL6MayoAaFF1sbmxIUgEDhRXBSYbiMWimq7rAWzZLavslvl2"
    "2ZerddhCrD76SxIcAK4vfK8iST5bLd5y/HZzDahzS0YiaofkHdlJN7uOfr9d9n959Ua5YVhf"
    "AQJngdjcOl26+uZHoulMHpyDpAMpBCQJJgRgWZ3Z3T7DTj8wkmBMQGES6xt1LBerpc99h54P"
    "ESic/3Fp+P5PP750/q8/i2iaxrSIAimgOIIsW3LTNNsgLqAUDv5w9lyDhDRB5PrCXYPXJMEY"
    "ob5licaWWbUc+0MebsjSqy//8I8AprN75qZ4JD4MALv61uO2TT8xmwYALzsJkANhW/j7P5Zi"
    "nDMbPYaUWCoU5RcBgDNQ2cTSL57DdSLyX1Q73wdUAGrlykIRwBoAHp/FgC3yME0rILP0ZX70"
    "kfdykMi2nrnPXaLPvLjY/NEz8m9o7VEEwAKgMMY4uadW+32AMY7W2aAAiLifsboFzbEkswwz"
    "rIBsEdFUxe/Ks+eu1lbWKmL2nrH41ESfbjvEAGguAdkKAMXFCRPweLgT7heV9XXYhmUz27Z8"
    "6dsKtO8LKxv455sbL//6d85p01r67dBASpeSm4CIAHBcBVgAp6sE1MHUAsBv3oIpHNsgYSCq"
    "q4D0zOWRaJksl1YR09neucP8wURU4ZVag0jSeQCudH58b20xCR6hjDEdgO7KpnhMTz2uHNs9"
    "GX/6/UcOZPsysUCreQoIAMBbxRoKqzUjmdD1828USi9dsj/4mwUUOjxgAjDJBe4kwF0CEbdO"
    "vlSfeQyzEyPad4cG0mPTuwZzuYyObFIHZ4SmYaOyaaBcMeji5ZWNRkO8snjFOv3zF3CjQ10H"
    "gEVE/n/Grv+GjDHFLU2IgDeePIkHcmn1mKYrBxloJwNTidEGES7Xt5yLxaJ87ge/wrWOn3mb"
    "gxME70mgQ40uAv/jIPJfFsPj3/wltKZKs+R6AAAAAElFTkSuQmCC")
index.append('documents/python')
catalog['documents/python'] = documents_python

#----------------------------------------------------------------------
tango_actions_edit_redo = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAABl0"
    "RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoAAAVwSURBVFiFxZZbbBRVGMf/35nZ"
    "nd221N7shVKLBSkWod64R0K4VAxNVmOIRtEXWUSefJFHo1FMTNT4pIlLYsCEqCSENUFUQkAU"
    "KtIChYKUWkrphd536XYvczufD+xututuoZDA2Xw558ycOb/f+ebMzhAz40EWca8TeHzalx6f"
    "dtfz3LMAgO1Cwa8en+Z+UAK0cPaKVULBKY9PK3kQAlg8f41zWd36OhJo9fi0OfddQJCC2qp6"
    "Ze3TL5aTEM0en7b4vgkQCAIqRs1uzCytFhuXv1KgCPWox6c13h8BIggSIAgEjB48lF8Iz6o3"
    "cjWn6wfPLm3bba+fzv+Ax6flAGgggVeJ6FlmLhWsztjW+BH69Quw2YTNBnKVYpCl4uem78MT"
    "sfGvDryl77hnAY9PW00C+2YWV2u11U/mFc8oozytEDnOfAhS0R+9AItNSDZhsQmXyIOKHBz+"
    "e3/4ZihwkCU2+726OW0Bj09zksBnBe7yLQ2LX3ZXFy1E1ApC5zBMGYMpozA4CpsN2GzBZgMx"
    "O4T+WBtUcqHMWYvzl85FBodvnGWJF/xePXTHAh6fVk4Cfyx7bEPV8vkbNRs6ovImJFuw2EjW"
    "idQnBK5FmhG1gwAATeSh0rUI/3Rc1Hv6uq+xxBK/Vx9PMNSpVi8UfLN0/vpHV85rVELWMARu"
    "bTbg1u5P1JRyJGQNJ+EAkKsWwzQtjI6MWAD2p8KnFPD4tLVVxbXrl8zdoATNPgAAkwqAkz8k"
    "e4kWMKR3JOcocdZAswtx4vTxiG7G3vdv0b9I52QUiN/33eue2uQK26OwWIeACgaDmOBSZkAh"
    "R8oVhL7YeYybgzBkBABQps0D6Tk40XI8Yprmdr9X352JlS0Dm2sqFhTl5uYiYPRAkAoGkK+W"
    "wcFu/DvYyr0jV6Ij40MyGBrNebPhPcEsMWx0AgAqXHWwwgKnzvwZsW3rNb9X92fLdGYBwoKa"
    "8jrXhDUCyRYIAvnOMvSPdeJwy75oKBrYy4yjANoFKX8xSwzo7YjZNzHT9QSi4zaaz50MSykb"
    "/V79WDZ4VgGh0ONFuRVkyChstlDgqERnf5t9qOW7AZbY5PfqTYmxL+1y82CsA6N6F2a56xEc"
    "nZBn21pCLHmd36s3TwXPngFGjcPhgC5DUIUTUSOCX5r3GsxY6vfqfalDJUuE7VHMctdjeGDM"
    "vtDeGmDJz/m9+uXbwbMKMHOJRVFItqFRLlo7m6IM+9N0eKJYHEPP9V6ro+vKAEus9Hv163cC"
    "B7K8jAShLRAZwq1HS+LaQDszI+MuBoDLHZeMjq4rV1nimenAswpoMblnLNhtEggmGzCNiGWG"
    "ZZCIBBEpRKQmAgB6+3vaAl1yxU9bjbH4eSU+lu5KwG3y/v6ei2dsacGQERRq7kDosnQCSA9N"
    "Wnyw7Ufr+eM7rVjaOQcABxE54rIZhf4nQETi23ftCXM08smNkUsRU0ZQ+khpUeVssTodDsB5"
    "7ANzS+dv0s4AT22riTqenaSISAETESkAFADKgZ3Gkf7Ojh3j4cFgYXGFKHxE2/BwFXLSJndO"
    "DEFNyKSvPg5OhJIaRCSAlLdh/IASl0q2tx4oaZxbs+jtWHTcbP+97etDn8dOjw3CBkBpGWQA"
    "8jZhp/eJmRFPySRwanvjx0VVyxvqXw+bY86LTVcPHvkw1BEOJTMo0uD2NNp2egbSBZL94jmK"
    "c807ldUFs5WaoasTN07tCXQPtFlmPBOpGciUifSVSwA2M9uTPkgy3IZEJDPkyCFRsVB1Fs9R"
    "3YoDSrBX6t0n9ZgZBcfhmUTSpSxmlpP2QIoEZYGn1olVpz9WnCFSJWxmtifxpvoki8ukCmWC"
    "U3zyTBJJOGcBTeuzPE0s2U0VyAbKVv4D5I/Z5OF31HMAAAAASUVORK5CYII=")
index.append('tango/actions/edit-redo')
catalog['tango/actions/edit-redo'] = tango_actions_edit_redo

#----------------------------------------------------------------------
tango_actions_go_next = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABHpJ"
    "REFUWIXtln9oVWUYxz/ve85x3mTqps4UM1MLin6XLucoKhMtCcv6Q4oyIygMQjcjCcKgosj+"
    "kUQjLITlD6SFGGWsabM23HIq5q/QzZlTN5vatru7e36879sf95x5d93mnOBfe+C5z8s953m+"
    "3/N9nvO+BwZt0AZoBUW2mVFsPXe9deT1JE8ee+fGwmJ7JSAGWsMaaOItBXLlh699a8eTrY8w"
    "tW563my97dxv+Nda57oUkFIwv3Dx0AWPvTEnlnD25b/LhBtKwFMuR5uruGdqvvP6vPdvH2Zl"
    "HywotmfcMAJaBySDOEebKhk5Yrh8+4WPckYNH1tesMxa1N8aPQ5PQZFtEHT2mWmIffrWdxxo"
    "LMNTLsZoxmRPZExsEpvL1iTrmw5/Pb5BLd26FTUgAh8sXotlOUgkQggEAqIYZkph8+epH/G1"
    "i9YKgyY7azRTRj9IeU1psvrozj1JGcyv/YzW3gjYvVMz7D6xCSmsLhdCpJG5LIXWGm0M2iha"
    "Ok7TnrzAow/NHToqZ2zhz1Wb/8pfLp+s/tw93hNMrzOgjMJXHr72CLSHr118lVoHeCg8dBiV"
    "8FDCRZG63u5eoObUdiZOuM1+ac6SCcOcrNqZRfZT10TAGJ0CUx6+cvG1G4KELnwC4aGEjxY+"
    "Cpe438LFZCPnO05yrq2O3cc34Vlx8eq8d7JzRuRtm7ncWdrvFmitCLSHQCKlxBZWiq+UYf8F"
    "ygR0eJdoS7aQ8NvRSqGVSXNo/ruBO/Km8/LcJbFtFSUfU3x8VuWq4JmrEvC1S8Jrw5I2juMQ"
    "aIMJFEYFBMbF1XE8lcAIAIO0CWcEUj8aYwxGQ6A9PO2iTSCAKf1SIOG109RWj5BgORLLFli2"
    "QNoCaQmkBOmk3gmDwGiDjsCFASPACO4e/wR5scls2bGus7X94urKVcGKqxHoNhfSEkgrjLbA"
    "CqOUAhHeaQwYHSlgAIMtYjw86Vn8uDbfl23oTHR0vlm9Wm0CTF8ERPp/Qqb2eynDp47Au1QQ"
    "IQGD0eGTA8OcXKbd/Dz1J+uCipqyttZGs+DQZlVL6vBT6SQyCch0BV58YEUXUKSCkCn5hUz1"
    "u+zMl/iBi1apmmNiE7k392kq9+72Dh6prTv1R7DwTA1nw7rhJF/eHXtqgQBYu+WTHi51t+Il"
    "K7AcgQ6H79bs+5gUy2f7L6XJhtMNO49sVMvaW4in1yVj980kYABd9UUwHBgCOKGnrx3AKSy2"
    "KxBkWZZAG4u7Rj5OzB1HSekG999/Lq6p/UatA/ywZrp3OxsyCejQFRCEbCPvIthVRAiGZt3E"
    "/bmzuHS205T8tD5x7lhy6bEf1K4wP3KVtu5zCEkDvkKZtEIWgC2GMC1nIfv37wt2/f5rS+M+"
    "/crJcnUiA9xPi1d8MfVEwABeCBgBB+G9FtEgCYzyoayi3D1wZO/B+h3+oqbD/JdBNIou9Hws"
    "9+dj0r4CHGRBkX0hL3ec33T+bMmh9eq9eJyAyy2MSPu9AfelQKZFUkaz0PWqNjc3Ld+zWn1F"
    "9wGLVBu0QeuX/Q/MEx4pyYpYiQAAAABJRU5ErkJggg==")
index.append('tango/actions/go-next')
catalog['tango/actions/go-next'] = tango_actions_go_next

#----------------------------------------------------------------------
actions_python_run = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAAEl0RVh0Q29weXJpZ2h0AFB1Ymxp"
    "YyBEb21haW4gaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9t"
    "YWluL1nD/soAAAVCSURBVFiFxZdrbBRVFMf/597Ztjxaod2tCCIIArGAoASKIJrSENEQjMS2"
    "EoWIEI1G/WI0mviIUUl88UEFoybwgRh5RCJiJDwUbUWwPLRQRB6i5VWx9sl2Z3Z27jl+mJmy"
    "LditKHiTk52ZvfP//+45d+bskoig21FCFraJ1/2kix8q0wSJRT/xyqKl/xsACCMU0RYujy3D"
    "/AF9Lj+AgDBoIFFBwSJ2zEGUF95yeQEAIDsHGD0+okYVDWJLV3JZbAkWXJtz2QCENGA8SKxQ"
    "0aRpRNHYY9weP4Dy6KTLAkBaAZ4LHP4OcFqAm6ZEqOiGoaytHVwRXYxyyrqkACANaAtiUpC6"
    "HyG/VAMDr1E07XZF+YVPCaI1KC8cf+kAlAKUBgR+tP4O2bcF4rRCJs+wMGbCSFZqN5fHXkAJ"
    "WZcAQPtZIPghOFeSozuAISMVTZ+tkR99XmIFe1FeUPTfAgQlAALzc18ADXWQ3Z9B3ASoZI6F"
    "scVFrKwaLos+jZcoo37PS0C6szkDsAVoYeBMO1C5CfL9N8DgcZpurbDQL/YqH4hW457CEf8e"
    "gII9kG7eJj4Ap807eQjy1cdAKgkquc/CqOLxrKWWKwqfABFdPIBKA2AArehsnD6cOGT7Osi+"
    "r0Gjp2gqnZ+F3P5LTFnBt5h71dCLAyAF6AgAAuICZOqgAHCsBrJ5hX/7nQ9ruv7mSamUOZi8"
    "O/bQPwYg0n4GkgL0sDEzA6a1RdyNK8XdtU3MuJmaZyzMdrP6L229I7q1qaTg6h4DdJTAvvDK"
    "RQBjAM+DuC7EcSCOA7YdEcdhsQ8d4NSZeuErh8MMm0C2jdscgwcBoGcvDdIA6466MwMsEOHg"
    "mCEsALNAwnMGGASrqBjZ02aR19JEZ1e+63n1Jw8bDwuGVTfu6hGACCCiIUaJ56YbCpgBCc3E"
    "vx5CUb9C9J55L6kBgyletcnEd3xpTEpePkuNb0zYLalQPyOA7UC0RyIpjaQjwn9jyBKuWqPX"
    "5FLqNW2mSp34Dc1LXzOpxoZqw7Ro7L4/f+6qnxHAcUQsW0FdERHbAUunlMNPuYgwA3rgUMq7"
    "636l8/pT0+frvLadVQ4beebGQ83v+6jnj4wASQcC1qLFEseBSFr6mUmYAURykDtjtuo7dbpK"
    "1NZQw3vvmFRr22YIHp14tOlEd/o9KIEIeQoR0XAcMDMgQmAWERZkjxxDBeXzNJRFp5d/6LXt"
    "3dPKgsen1jWuyaSdEYCIaP+YfMnylJBocfw9ABEI9e6L/DlzrbyJU1Tz9kppWLPKJBPtqwyZ"
    "J0tPtjX2xLxbAPLf3cp2gN6soMQKASS3eIoaUDHP8trb6cibr3vx2p9OJw09MqupZbNk/KPR"
    "QwD4nd9qT4rKYwUtikzfKAY+sDCSO3qs+mPjF3xq9VrPdtwP1rP3yop4vA2ARUSMzn2z4/hC"
    "cJn2gJWwoVyjkTtoCF23+K0sp74eNc8+ZxoPH6urNO6Ly1x7D4A+ALIApIIIIUwQDIDT4UKY"
    "8wCIKAIgB0AvAHnxpEQ8Q4SsHNStXsvH120wP6RSG9428U/bARvAcPgdggMzD4AbhNPlMxlC"
    "EhGLiFhdzLMD45xgVbkJR3Rz7RH8un4rHz9df2olnLV74Z4C0C+YGwp7F1h1mI0QKgG/mbcA"
    "aAeQ6poBF4CGX38FQLspmJNV1U4V3E3LkdjJvli6SXgsAYgDPzNhJIJrIaRJA+tcgqAuCQAJ"
    "ImoFkNME3v4R7P218FqCG+MBfTwIOzhPpIGEcOHvaEZHK+u8B6i7p4aINID8oCR2sIpQrKt4"
    "KHSeYHeP5l91GvisT9HhKQAAAABJRU5ErkJggg==")
index.append('actions/python-run')
catalog['actions/python-run'] = actions_python_run

#----------------------------------------------------------------------
actions_zoom_out = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAACF0RVh0U291cmNlAGh0dHA6Ly9q"
    "aW1tYWMubXVzaWNoYWxsLmN6aWbjXgAAAEl0RVh0Q29weXJpZ2h0AFB1YmxpYyBEb21haW4g"
    "aHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9tYWluL1nD/soA"
    "AAgJSURBVFiFxZZ7bBTXFca/O7M7szv7mF1sY7z4QWwsMAVDQAHJIDdNMSmQQFELkdqqJW1V"
    "NZVo1EiolaLKbP5oJSdKHalKS4iiKglSozQRImlsQ3kFUYTjBNT4RQKO18Zmvaztnd317Dzv"
    "6R94kRVoajeRejRHZ0aame93z/3unWFEhP9neOZz00svveTVNG0NY+wBAHVE1CsIQk8+nx9s"
    "bW3lXwaAfVEH2traNlZWVr5SW1vbUFFRIYRCIXg8HliWhXQ6jfHxcae/v//9QqHws4MHD17/"
    "ygDi8bgUCoUObdu27TfV1dVM13Vkcjo+HdOg6TZqy4OoLlfh88mQZRnnzp1zBgYGfnnw4ME/"
    "fWmA9vb2ilgsdrGlpaXGNE10difw9w8nChwsF1B8mih6LV0vBCzbCS0OeQK/eGS5r7ZqCVKp"
    "FDo7O99Pp9Mtra2t1nwB7vKA3+9/ffv27TWfjSbxx3evuTOuZ+Sxh++fuK88uEhVvIrDSZrI"
    "GNkbk4XRC3037adf7Vu3t2kqurOpju3YsaP5rbfeagXw9HwBxEOHDt25ePbZZ3+4Z8+epwqG"
    "id++9rG9tKriw58/usa/ukatCiteRRSYAAb4ZVEqCcmBmsUh0RKk3tNXxmQfc9QNq2qYaZpb"
    "jh071tnU1DQ2HwCheNLe3l7R2Nh4RFEUvPaP6whF1cHHmutKSkNSGAAYAwNAjIEzgDMQhRWP"
    "f8PykvL6usqP/np+LP3ZyE00NTUxVVXfjMfj0oIAHMfZ0dDQIH2SmMCVRD798Ma6XMjv8Tuc"
    "XNvhpuPyAicyQDAZYDDGDIHB0GasLGMCLa0qv/LnzqGcbdtYuXJllaIoDywIAMAmSZJwZSiD"
    "UDg4vnSRP2K73HZcbtgu6bZLustJ5wSdgEIxb2WNCQL0YEDJjtwy8oZhoKysDLN7xn+NOyYs"
    "LS39BuccV8fypIZLb8qScJ/jksEYuZxzV2DMBSOHc7KJyCWCky3YuYkpa0IAFGLEIDI9NT2D"
    "xdEwGGMb5w0Qj8eltWvX1tq2jYmMaS5fLBm2ww2BwfE9tXKNyC1WfEAEkUiAFwTFdd0fu9h2"
    "ZO+5F0FM9Mm+zNDNLMoXBaGqavO8AVatWuXatu2KoigosujJFRyu6ZYWCUgMRCRKAjGAbh+M"
    "CATuuA5jIJfDQ2AGYyTZjuMpDftg2zZc1zXnDbB37173yJEjA16vt3H5koBnKDdTmpw2p/yS"
    "R5n+1TvnPGQ7IoMpMm5omdyN/v7h6zO2K3BBDrqiP8AATmC2bVrRqsUB2LaNfD5/ft4AAKBp"
    "2hkAjQ1VIfReSpf3jmh9w6m8URaOWH5JNLKGm7ylGWOGEZpiZRUel6AygVRGUAGKwGHwewWf"
    "LElIJpPQNO2jBQEA6JmamsKmVTH87Z/jNYWCqXLyalnd0YhBExiyxBmHB14iEgQwxjljEIiB"
    "gGvDo1se/3plqSzLuHr1KuXz+VPzAbizDGVZPn7x4sV0IKDgwKP18o3R5FZGggeMPALgJWIy"
    "CVAYJ5WYEAaRnzFIBHhTt7S6ZSVyffP9NUIymcTly5dfff755/sWBHDgwIFsOp3+3qVLl7C6"
    "vhLfbaoo++Ta8Pf1GWMJgfmIoAA8xAkq46RCEEIMUBLDyQddPffIk99uiDDG0NXVhUwmczke"
    "jwtfJFyMu76Gzz333JFdu3b9tLKyEoND42g/NqgbXOyTffLHkYj6qSQL+vTUTFkuP7NC1wsb"
    "Hl5XtvQHLQ2y1+tFLpdDIpHA4OAg3nvvvU7TNL9z/PhxfUEA8Xg8GIlE3l63bl3L+vXrYZoW"
    "Ln9yE73D09Q/mtVnTNesLlX8X6sJ+9fXL8aypWXQNA2Tk5OwLAs9PT0wDAOhUAhnz54dmJiY"
    "eLCrqys1b4BitLW1PV5RUfFic3OzT1VVeL1eEBGICIIggHMOy7LQ39+P06dPj69YsSK2aNEi"
    "5HI5aJoGTdOgqio++OCDyaGhoS1dXV2DCwKYhagURfGZSCTSoqrq0kgkwsLhMDKZDDRNo2Qy"
    "eWN4ePj34XD4cCKReGf79u07ipDF37ZwOIyBgQGzr6/vWx0dHWcXBDA34vF4UFGUDURUC2Cg"
    "UCj8q7W19c787tu3z++67pu7d+/eGQgEYBgGRFFEMplEKBTCyMgI7+7u/lFHR8fr8wJgjAG3"
    "VwmbU4uJObUYFIvFhMbGxt/t2bPnydLSUszMzEBRFIyPj0NRFExOTuLUqVOtXV1dz9wTgDEm"
    "zIqJs3UugLB582appaUlWFVVpTiOw65du6afOXNG7+npsQFQMR966KGf7Ny5s23ZsmUsl8sh"
    "Go1ibGwMwWAQAHD06NFfd3Z2tt0BmBUWPyd+B+KNN96oX7NmzepoNLpSUZR6SZJiRESmad7M"
    "5/PXU6nU1e7u7v4nnnhiaBaCb968+Ztbt279y9q1az2apqGkpAR1dXWIRCJ4+eWXjZMnT8bO"
    "nz8/7WG3ey18LudCiCdOnJguKyubBpCybVvyer1ZImK6rmvT09OTiUQi39HRkQcgAeAA3AsX"
    "Lpw2DGNHNpt9e8uWLcFoNApZlmFZFqqrq2UAfsZYpjiP4hd04K6OfM4TKI56TnVnK1+9enXF"
    "pk2b3t2/f39lbW0t0zSNXnjhhY8OHz68iYhcz6wHXMYYnxXhswLF6s71wT3MWAS4Fwjv7e0d"
    "4pxvHB0d3R+LxfalUqnjlmX9gYjcu0w4x4xFgXuN+D+ugjn1LhAARPcQm/c+MAfuXuKYFVjQ"
    "u/4ngK86/g1HNBoJGP/yvQAAAABJRU5ErkJggg==")
index.append('actions/zoom-out')
catalog['actions/zoom-out'] = actions_zoom_out

#----------------------------------------------------------------------
tango_actions_view_refresh = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAB59J"
    "REFUWIXFl2lsVNcVx//33rfM5hkPttlxDWlqhKEsBlw15AMoJSVRi0IVWuOAmhTjpooUtVKU"
    "lrZS+6H5UKmt1EZFoSxpsEkFocrSqgkRcUMJTQBjlhoSiLENeLdns2fmrff0w8zQ5wXb33qk"
    "qzf3zbnn/zt3zj3vDfB/NjYTp9VPNy7z+dXvKByPOw5VOK5bxDlzGFiWC9Zuu/Ij13XeMZO+"
    "M23Ht1tTxVpbf+RbF/6088SMANbVH63SNX4wEvIt3bCyPFQ+r1iEgxp0TYEjJUzDxnDKQM9g"
    "yr18cyB9tz9FjNNB06Lftx6s6xofr/qZxs3geK/lwFP3dO8LsK6+6bt+XfnD9q9VBZcuLmVE"
    "gCQCSYJLBClzfgSAM0DhDKmMjdYbffbp8522Q26TI7G3Zf+OIQBY+73GhxRFnLRdNzAtwLqG"
    "pm0BXT3y/LdrAsVhH2RekEAgmQNxJIGIICVBEiApB6KrHK4kfHTptn26pdNwgAYm6boQ/F9b"
    "N1WF3jh5BV4AZbz4+l1/LuGMH2p4ojowK+KDSwTDchBLZGFYDhQhUBTUEAnpIAJsV8JyJEgS"
    "bEkwbReCMzy8ukKtrChT/3LyyoF4Mht4YtMyWjg3PCHZCQAUUOvXL5+vzysrwtX2AXr/41ty"
    "MJHhjIERUc6HSArO7MXzo+aqpfNDlRUl3KcypE0XGdNGMmMhlUkhqCvYsWVVIGvY0HSVuZKm"
    "B9AF31NTtcB36O2L7q27CTiShODctCynm7i7o2X/rk8AoHrPscj1W0M17d3x3YB8fE3lArai"
    "cp4fXCBtuHAlEE/bGDVdzInoaO8bxbKFE3dgTA1U73kl4FeKB1dWztEuftqHaDioKApH31Ai"
    "Lhz1i/8+uD02Wc2seLYp6nf5s4Kzn3xl5SLfysp5ymDSRDxjQ0pCIfO1D0Tx61fPUMuBOl5Y"
    "y72BOBUtJlDg0me94gsLSlhJNBgTQvSDWNv9xAHg6r66+Ln9tS8ZFlWevdx18tU3L6AkpKC8"
    "NACiXLECAOcMnMEco+mdSCa5YTnQfL7hkN/3QUDXP3Ac5yaRO+FMT2ath2p7APpYUbilKAri"
    "oxaIACKAMYCziYduTA0oNlxHALOjoX8EA/o1xnmyOBIMDA2PzKhjVtc3fj/s139c+9gqrT9p"
    "IJG2IJHrFYUdmBIg68guVXCMZrIf9nc77bYiRpPZhOm69uh04jUNTVt9uvbbXd9Y7dd1FUGf"
    "hvLSAMAABgZVcAgGD07OJiCte/r1RecP196ZScYFW7P7tU0M/NRM/afshNW7G0lwli3MJZFC"
    "BHWyQNLVZrce3j44U+EnnzwmuiJG+bkDuzoK9yb0AQB4+YWv+4Fc8Ugi2K6ElLlC6uhNYt+J"
    "8ynbcqunE29u7vBt3LjYKMzbi61vMuJ/hSdxPtlCSYTLnQm0dsRxuTOBa3dSiI2aGIhncODN"
    "lrTjOpsvHtz5+ZTpEjE3qpY3tw3M/Z8YuUCuiU0JMN5mhTSoguGPx85Jw3brCt1wKvvFL8Gu"
    "380+LCCrTl3tf6C5uVlRVW1r7ltjGgBPoTIGlBRpyGRtAMQFeG31nqOl0wF0Ri6F42n3qwBf"
    "pnCqaovP2UgkdzAGWEKMTAngfWYQATd7RyA5xw93PoQNa8q3CY72dfVHnq+pa5zY3POWlvaj"
    "qsKqOKNlibS19vjp601F4SLBOR+5uq8uXvCbtAglEThjmF/qR08sC9slxEYsxEaAJYvK1FnR"
    "IvXyp70vdXYP/Wp9w9ETtiNf0wyc/6TpqVT1i+9HioTvudG08+LyilDq7bN35p651LEgEPCR"
    "L+BTE4nUBa/WpMfwdz/ajKzlIpHKIhzyoy+RRfdwFv0JE66U0FWBaFCFlISunph7tyeWjo9k"
    "dCEUnXEFlH92S8dBIKi70WhY0QN+3OnqGcma5g8uvrKjccodIAJu3knIw2+18AfLS7JbNjzo"
    "VwQHYwQCkDEdpA0HQjBEo2ExuywSJgmMpA2kDRuOS+CcMa5ocEkqjgukkmlYhjFqxtVjXq3x"
    "AAwAbvUm0Pj31pHh2+cftVMVmzp6Yj9fs3ShuqRitpJM24ilLdgOwXIkTFtCEt1bzjUdQub6"
    "huW6ADFkMlkM9vVnjUTPrrbjLzDkak8CgPCIcwD6guptP7tyoz89dPtS7a13f3Orv+29z8xs"
    "8m8jfPa8z2/HF/p1BXOiIe7XFTCG/HshQDJ3lSTzeeR2Kz6clAO9g5nMYHtD24m9Z/M6OQdA"
    "snvogAZAq97dmMombj9z7Y29zYV7hVFa9ciS+csfq/VFSh8pDgdlaWnUHwz4mKapAGNwJGCa"
    "NtKGhWQy7SZjiaxtZv7TffGtn/ZfeacDgDVumMyTvQZA/3Lty3uuvP7cUQD6OIB7c80fKSpb"
    "vmVl8cIVNXpR2Ze4ppeBuEKMCQY5Kh2z14j3fTh045/vDlw/1VkQ8wrnr4b3FEwqlh/quM9q"
    "vn6EdzsBOABszxif8ZjsAZjeIrQx9lgWgrr5wE5+YUFYYGwjo7yv19/2rPNCGfnrpH9MCj+H"
    "irHZjhcuFFMhRgG4AD0ZSEH4Xq+d7lVL5IULENwD4BUvAHghvMJO/t4Em9G73iRrvKMg7oWY"
    "+A/kPvZfhD3CiG0yc3YAAAAASUVORK5CYII=")
index.append('tango/actions/view-refresh')
catalog['tango/actions/view-refresh'] = tango_actions_view_refresh

#----------------------------------------------------------------------
tango_actions_go_previous = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABGdJ"
    "REFUWIXtlm1o1VUcxz/nnP9/u87MihykIsO0FREUWbPdqWVWm9mDSgsCUxJNe5HY5l7GIKRe"
    "qEFB0BPMN0VNyjDwRUqW6EUDiQXqFmXqfNp13j3eu3vveejF/7/bvdet9kDv9oUfvz/nz/n9"
    "vuf3dA5MYQqTxOJGVV/d4LmJ7peT8C2iO7ydC+66f6/vlU7YyIQIPN3I9Jom78Di+1a89foL"
    "b0c85U+YgDfeDVVNzE3iH1qzdNP8Rfcu85VUE3YO44xAdaP32HTv1rY3Vr+z8OHKJX5710ms"
    "05MiMOYIRBvU+lkzZ3+09cXmMuUrOrpOkjFpHCDA/H8EmpHRpLe7cs5DWzbU7Yj0ZeKc7/4d"
    "YzXOWXAOB2osnXB8txbjIhBtYgaD3v6aB+qqn4tuiFzqaSeRuop1BmsNxmmkkDS/9gnWWRwG"
    "62woBhdqYw3vtrw5NK4I1GyPzHfCHF67bOOcRZVP+B1dJ0hm+nC4nGHrDLG/vsVYjbEaHWpj"
    "s2ibzenl97w66iFHJFDT6D1e4vvfravbMWP2nfNE2+UfyZp0+NfhsCAcFoPF4KTGonEu0MPk"
    "rDM4LM6Nnp2bCEQb/C13zCzfs652+zTpQ9vlI0GuhUAIEBIQABYrDBYbkBAaJw3kpScIvwYs"
    "Dkbs1wIC0Sb/q4ryyufXr2yMXOo7S2f3WQQCIQRSBloAQhCcDEvK9JPM9DKkk2iTxhqHcArp"
    "fBQlYW1YcIw4rQoIWGurhQeDmQR9Q9fRJgMEzpUQARkcg5ke+jNx+rPXydhU0AkOnAVrHVY7"
    "rHEY7fCIkNapsaVg7nlTcY6zuz7ev3Pzs0tfKlPS58y1GKUlPtIDQxot0iANUgmEFHhS4BDg"
    "HNaCMGGGAOcgm03lE1AUzYyCSdjaijm2S2/v7Uts3ffD3qRvytyjFXWk7SAD2W4yDCKURXkS"
    "5YlAfIHni3/WlEB6AqkEUoFUBa3vU1QLI41iGdtjvu6/kqn9/qd9iStXr+onF67ntrJZodHA"
    "gfIkyhcoX6J8ifRDxznnQeqC2imIeEHUR2pDCchTLbpt3hKWHLOHW28kuu5eWvVK6W/dB4mn"
    "/0TlOVlZ0QCOsAaCNATaYXVYE8YV2A7FjkYghwtHifd26FW6vm1PT1+idtVTayOdQ79yfvCX"
    "gIQX1MF7HzT/m5l8jGkUu5CdA2zvNYZOfGi2ZTd2bv5ioKVhzar6yO3l5ZzuP4RQJpfj47t1"
    "FNChZPMkk/dt8+znQlIMUyQa0Kc+1592nu7Z9OU3LQODceeqyuuZ5t8SDKYASWAISBc51Xli"
    "wrUcRntNuBG+XfyMuyAVBy+nzqyIqLKyRxY8o0pUKUdjR7gYs+8XnbiYRDYkV9CGo9WACw3Y"
    "PNGAd+5n3T5wieXOHv2sqztetbq2PpIXgeHwFkdwmNBNl8J/vaeGHZtwswF0MkHqYsy2li64"
    "Mb3jj/YHk0MD3sWY3Vl08nSeTO7ZVAQREvcAf/E29XL4GPHDtdx1NYUpjAV/A41jRqaMmBka"
    "AAAAAElFTkSuQmCC")
index.append('tango/actions/go-previous')
catalog['tango/actions/go-previous'] = tango_actions_go_previous

#----------------------------------------------------------------------
documents_unknown = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAACF0RVh0U291cmNlAGh0dHA6Ly9q"
    "aW1tYWMubXVzaWNoYWxsLmN6aWbjXgAAAEl0RVh0Q29weXJpZ2h0AFB1YmxpYyBEb21haW4g"
    "aHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9tYWluL1nD/soA"
    "AAPfSURBVFiFxZdLjttGEIa/ZrNJUZY4Q3lm5M3kDHOGXCgIECD7LH2CnMBLHyNADHg1Z5jN"
    "WBlLoiSbj+7KIm6GokgNBwngAhp69KP++uuvYlOJCN/Tgu/qHQi7f7x79+7n29vbX8IwlCAI"
    "EBGcc4gIIoK1tvntnOsd1tpmrd9XlmVwf3//+9u3b387C+Dq6urXu7u75devXxERwjDEOQeA"
    "UuporVKKdgq78+05YwxVVf0EnAeglHJlWbLf73HOEccx1tojB93PIQBdIMaYE8GdABCRIwdD"
    "318C4NzcCYDuBu+4C8Dn1g+AIAhQShEEp9oeDcAf1t7Q59xaS1VVlGVJXdfAP3mO4xhjDGEY"
    "nmVkEIBzrnHo09EG4JyjqiryPGe327Hf7ynLEhEhjmPm8zmXl5fMZjOMMSfARzPQjtwfIiJU"
    "VcXnz5/59OkTeZ5T1/VRCa7Xa4qiQCnFfD7HGPNyBrzzNhA/V5Yl2+2WPM9xzjGfz4miiKqq"
    "2Gw2bLdbAJIkYTKZNCyM1oAvubquCcN/p9tsGGNI05TpdMrFxQVxHFOWJY+Pjzw8PLDf78nz"
    "nCzLSJKkV5SDAHzeoyg6cay1ZjKZcHV1RZZlxHFMkiRorRtBPj09sd1uKYriqH8opRp2zwJo"
    "L+qKUCnVqBxAa43Wutk3VLovSkG7Cvxh3nyN+9T4ddZayrLkcDhQliVhGJIkCVEUNb3BBzQK"
    "QHfhUDS+tIqiYLPZsF6vEREuLi6a/HuG/hMDfRT631VVsdvtWK1WfPnyhfl8zps3b8iyrGHA"
    "BzSagSHrsuCcoygK1us1eZ4TxzHL5ZLlcslsNjvqhqMbUTsFQ2Jq94WiKNjtdlhrWSwWXF9f"
    "Nw2oq58+ACcF6pW/Wq0GmfAHehDWWqIoIk3TpgV78bXbep8NpmCxWAw+1fwIggBjDLPZDBFp"
    "Ig/DsFfIowD45qG1PhJknxCDIGA6nXJzcwNwknc47iWjGWhfSp4zz0I7ynNXs1EAnnPu5621"
    "7HY7np6eEBEWi8WL7gK9AMa+J4gIdV2T5zmPj48459Bak6Ypk8nkrPDOAjjXB7rmH1BRFOGc"
    "O3p6jrVeET6H3GvEGEOWZY3q0zQljuNmTXsMpeSozpRSgXNO+QOeM601r1694vr6mpubm6Mb"
    "0NhUNgwopTLgdVEURmuNMQYRIQiCoydatyR99EMV0LaqqkKl1A/ASkQODQClVADEwPTjx49/"
    "vH///sduafmo+q5qz5lSSqqqUh8+fPgTSL75OgCoVt+PgNdAOp1OUxHR/H8vr7VSyh4OhzWw"
    "Af6Sb45VX66+MaKBcSE+bw6w0uPsbyO/N3IC18THAAAAAElFTkSuQmCC")
index.append('documents/unknown')
catalog['documents/unknown'] = documents_unknown

#----------------------------------------------------------------------
tango_actions_go_last = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABPVJ"
    "REFUWIXtl21sFEUYx3/P7F6v1ZKq2FohiGggQhAsJKI1GmL4ABrAF1AThUSC+EE0agMEE8XE"
    "BCNCjIFEjSgBJEosMYhC02iqKEXTaLEQ3gMUSqCVltprr729nRk/7G57HH1L4zeZy2T2dmfm"
    "/5vn/8ztHFwr//ciQx1YWuZaxC6oXqu/GKjv9LfJ9RJuZ7eoCNZaqtf54g4VwHVijCocu0mW"
    "Hx61b43/bn99E53Ec4XUG8+vjxurMUbz3uYyANRQAZRSXUufeMctufOht0qXOVunLiE2mHGV"
    "RzYCtmeeoQJYS47jOMx/eEnujKnz5uUWuFVTV1DQ/xgb1p57QwYAVNqkONpYzYOTZ+Y+OX3J"
    "tFwbO1Baxuh+EDDW8J9EAEAbn6TXxqGLexl723h30aPLR8dz8mvvfy12b+/yFovBZgD0moSl"
    "Za7t7X52MUaT1ikMhkMX9nL78EnywtyVN26p+LCqdFnzwur39Y4rAIzBGI21pn8AgFWLP0Gb"
    "NIIgohAEpRyUOD2dBHzjoa3GWsuxxt8ZWTCOxbNXXLetYv3WB5Y3jMvcIRaLCfsOCCAi1NR/"
    "jxInABCFtaab3oYfbOBrMLHhVPMBCvNbWPDIK3nf/LT5TZYduiut9OtosNagrT+wBVF4O9Pt"
    "qFBciSL63RKRcJIAQIdgEcT51mO0p1p4bPpzeT/W7Hr6r+PVk60lbqxBD9YCYzVpk0JxJYAo"
    "QlsAsd2JZaxBW02Xl8TTnTR3nOdi22mmTZodj8dzJtQe/g1tfYzxw50wAIC2Pr72uoWVKMQR"
    "HASUBLEQS0on6fTaSHoJkl472vcxOtjrLckLXOpoYNaEF2MjRtxKV7qDtlQzvvEGBmjrbKYp"
    "UU/MieM6MRxX4RgFyqLTKXyTImWSGKtDJyzigEJAwPgBRH78BgDqm45SXDAmtGqQFnR4rQAo"
    "V3BcCVpHECUoBeKAIwqsxRpBtEWEwB5gZP54Jo+cwZ5fylMNF8/Ep42ddZXOgC8jUaAcQTmB"
    "uHKDa6UACaywVrDGkpGnjLv5PkYPu4dvq75MXm5t2o1iDpAzGAAn80sgHrZRJBxBqSAhAawF"
    "YwAfRBQTi2eQL8WUV27tTCTa1rS2+BuGF7mze1tgNoADPW+1p6asDBJPgYRREEUgLkEEdp9Z"
    "G6zeQEzlUFI4m66EobxyS+c/zamltZ/q8jFzyKOo9whnAkgI4AJ8vH11Kvu4YsMAi4A15Kx4"
    "aRVOTLAG8mw+Uwofp6GhwVZW7em4dFovPPK13g/E0u19W535QEX16E5/VG4B+X6KHOMTMz4x"
    "q4kZQ8yG9e5n3F3iBJZc7xRRctNcag/W+Pv2/3r5XA3Pnv1ZnwgXpI3f90svm0wAWk7SBRgC"
    "O3Iy2sxrlIKi/DFMGDaTH/ZWeHV1B8+e/M5f9PdxGsk87pm+j36ZADYUjdqo6mglgJ/RF1HC"
    "xIJZ7Ni1vevUifo/67alX00205413oqLoY+SCRCJaQIr/HAVEX0E5ofP8T3L5q8+77pwrmln"
    "zUa9Gg8vfJ4Oqw/4bhw9GAAyRCPBSDQCc+jJFTZsWtfVcj7xwR+f6U0Z/fysms67pWdrzy9Z"
    "2S8AIbkm8DlasRuKRwAC0Him7eW6LbqCK22LIHQ4l1d8B9pLEP9o++qrxAb6XxBty2zx7KzO"
    "zpso/H16P1iA7L4RQHZuZCbwoI5z10pU/gVN2Gs/A/1geAAAAABJRU5ErkJggg==")
index.append('tango/actions/go-last')
catalog['tango/actions/go-last'] = tango_actions_go_last

#----------------------------------------------------------------------
actions_terminal_off = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAWdEVYdEF1dGhvcgBBbmRyZWFzIE5pbHNzb24r7+SjAAAAGHRFWHRDcmVhdGlvbiBUaW1l"
    "ADIwMDUtMTAtMTUNlAdXAAAASXRFWHRDb3B5cmlnaHQAUHVibGljIERvbWFpbiBodHRwOi8v"
    "Y3JlYXRpdmVjb21tb25zLm9yZy9saWNlbnNlcy9wdWJsaWNkb21haW4vWcP+ygAABFpJREFU"
    "WIXFl0FvE0cYhp/Z3dix3RJMQFWVFCjiSAspQvTac3vpL6BSr720lar+hp56qgS9cOBUiapS"
    "2z/AAUhAbSSqSJVCSHqABJysHezYM7vffD3srmMnAeKWwCftamd2dt533nln9hujqrzOCF4r"
    "OhABXLlyZWzicOW7SrX68eTk0QkwL/hM8V5R71HAq6JeQQWvoKp4VVDFe5+VvUdE9OHqw83m"
    "xvrvy0sPv7l8+XISAUzUKz99MHPxk2qlGnW2OvCSZ0WLu8LM2fNvrcfrX/z62y8ngU/NtWs/"
    "Tk9Nn/zzxIlTRxuNBquPVml32rs6Mcb0r8HyKO/K5TL1ep2JQxPM3r3dmJu/OxP5wMxMTb1T"
    "b7Va3Lp5i+vXf6bdbjNozuHn3WPb2eZZdUeOHOHSZ5c4e/Z9Tp86Xb915+ZMhFILwzAUERbv"
    "32dlZYXJyUnGx8dzMEV1+Co6z67BNgXo7vbWWhYWFnjy+AndbpcgMKF3aS3ayVpEmJ6e5tix"
    "Y5nR+kYqzPSsum2zDZezujiOieMYRbHOEkUhiRP2JGCtpdvtobrdWQG8u24YaLhN8exxzuK9"
    "x2Bw1qJ+DPGOCHxfJmMM3nusdfR63V1A+x/9dvutrQ5Pn7aJ4w02NzcxJpsORXFOiJyTvrGC"
    "IBhSYBSg7fUuNJst4niDZrOJiOxcT1hrMcYgIkReBM3dHARBX65utzuSzM451tYeE8cbe4AO"
    "wBuwzvYHG7nEZbvYkAKOKOrua/RpmtJoNIjjGO/9M4GLUMBZSxRl9otEBFUlTVMMpq9AGAZ7"
    "GG97/kWEOI5ptVr7Au4T8B5rLWOlUkbAiWSjdg5j6JsQzJ4KpGnK5uYm7XZ7JOAivGbLsJSU"
    "cwWcQ0RInAVMPgW9IckL4E6nw9bW1p673qgKVFyaExCPSJo7M1Og1+vR6/UyYklKkrjnGmsk"
    "Aqo4a0kSlxFIcgVsroBzDufcSwHbKwqPuSQBIBAv/bVvXpQGvIRQFBHB+0zRwLmMgLP24NEH"
    "ojBwIOIGFHgFEuwkUCxDlxzcvD+XgLhtD7wSExQE8lUViCR9AmEYUK1WDwy0UqkQ5IOUXIEo"
    "KabAWUygfPX1l3jxQ7lcEARDed5+Q0RIUofBUCqVCIKQrt0Csg0JIHLWPmqsN2y1Wiuvrze2"
    "v/4fmfFHh9+gsbzEbOlNyuUSURhCENHpdjLQKKJre11EV4OV+38vzM7ebp458x5hGP531IFo"
    "LC/h05Tx8XHGSiXGymVq1RqQJT21Wo211dXW/Pxfi9GNG3/Y6qGj38/NzX174cKHE4HJfkLi"
    "PV78QMIh+QHE579kj88TEC3ee8WrZ2NqGvWet70HDEFgEEmpH65jnWPpwYP40draD4uLi84A"
    "JWDy3PlzF48fn/o8iqJ3jcHoi49Ho4fikyRdWV7+5+q9+Xt3gA2jqhhjxoBDQDUnFHIw58YE"
    "EKAHPFXVjtn5azXGBGRnxoPYFFLA6wDoLgKvOv4F1fVDE+oxNqcAAAAASUVORK5CYII=")
index.append('actions/terminal-off')
catalog['actions/terminal-off'] = actions_terminal_off

#----------------------------------------------------------------------
actions_attach = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAWdEVYdEF1dGhvcgBBbmRyZWFzIE5pbHNzb24r7+SjAAAAGHRFWHRDcmVhdGlvbiBUaW1l"
    "ADIwMDUtMTAtMTUNlAdXAAAASXRFWHRDb3B5cmlnaHQAUHVibGljIERvbWFpbiBodHRwOi8v"
    "Y3JlYXRpdmVjb21tb25zLm9yZy9saWNlbnNlcy9wdWJsaWNkb21haW4vWcP+ygAAB1VJREFU"
    "WIXFl1mMHEcZgL+quWfHnvWuN7bX8TrGBhLHsWxIhCCAOYxAxICEiQgBgUQQb0ghDyAhIXjh"
    "IeKBQ0goEg/kIQcOR1AsC8dxgnIQgo8En0l8JT6w9/Aec3R33Tx0z+ysZyP8gJSSqv+u8//q"
    "r7+q/xYhBN7NJN9V7UB+kTrx2K6H76nXh+4fGR5Zi0C80+DgA6ErwzXSETw4PHjw3uOdJ4qi"
    "6MyZN/ePN6Z/+uBPHrzYB/DYrofv2bL59t9XKgPFVqvJ/3uL8vk8mzbddt/+/XvvBG7pA6gv"
    "HXygUhkoXrhwnpdfeYF21FrQLoRACImUqRRCIGUmhUBImcre+kwKKVi9aoyxNTdx2+YtY9//"
    "wffu7AMYrA+NRVGbVw68xO49TxK1EwACAbrGCPOvBFIjhU4xewsL+2aPbdu28dWd36Jer1er"
    "xfK9i/oAQDtq0Wy2+fI9n2XZ8qUQAiFkexxYWManZUJ3y9I2nwJlfZ/fd4hme44oiqhUqmhr"
    "cosBZBOAd45CKUepXOxOQvBdRR0lIcguWAi+p00u7C883nu01hijUMr2n4Ku0wVwzhNHMTNz"
    "ZYyFcsFcY4leiN563wOcSmM1rXaTek2hjUJpjXO6H8B7nzmbxDlHFCUUim2eO7eF5TXD2JI3"
    "GChEqZIeExMC2VoJIeCcJUpaxHGLSEVYq2k25zBDBqMMWimUWcQCHQApU4A4iSnGOcZGZth4"
    "83YmpjZw7O1TDIuj1Ioz+JA6mSAd14oaNFqzKB1nDjV/jTgXCB6U0akFjOkHcMF2BzrnUCoh"
    "SnLc/YX388yBSUZGVrJ6dJTpq7dy7I3XKSWHWJq7RKwjWq1ZjLOIjk6R7WVncTbdGqMUWim8"
    "D4sAOI+1NjOjo92KIRe4eOU0rWg9a4qSC1cjivka2+78KK3mJg4fOc70+H4K5gpSZvgi0z//"
    "wLmAcwFlFEorfFjkW2CNRWtNCGCtI4oiZuccu5/LsX71ClyAnBRo6zk/FTFnSmzf9jFu2foN"
    "YlVDxQ6tLFq5NCedssW59DpWSqOUAvwiFrAWpRK891jraIhb2bRxBx/54K2cHm/RaGqkECDB"
    "+dDNp84cRzUmsHmJzInsxrxmcbZzDBVaK4JfBEBbQ6IUzjpGbvsKd33x26y9cSXnxlsYG5AS"
    "AgIZBAGPFDA5McH4iT8htSFfyGfXtOizr7Me70JqgST1gQVdhBDCGItKEt7Sa7jvO9/lpjUr"
    "mW5qlPXkpKBUyDFcldywrEROCFYNVfjngUPEV89htMNoi9EWrS1G2W7ZaIezAec9xmiMTZ1d"
    "9ioHhNGaf5xKuP2OD7P2xhV4H4i0IScEgwNFZiau8Pgf/sjczAyFvKA5M8u5w3/JnNdjrMNY"
    "j83K1mTSOrzzBJ+dCO+A/nhAzrWNVPkh1q+9Ae08QoALUK/mePb5Axze9zvmLh3k0Oob2XnX"
    "p9j9zGts3TJEfejz1Oo1ytUyU9MTvPDUs9D9lKdHwrmAdz4D8PMAndUD8tWJJbUdn96QHRGB"
    "kCCt4fG/Ps2b+3+NVdNIITh7/O+8uWkjNXmZ927awuDQILWlS6hUy5x86wRWu75YwjmP96Ef"
    "oIN585d+OLpqdLRQKhZwPoAUNJsxu57YxfG9v4DgUucScOm1Pey94Q7O7vsZ4OcdL/P+4PoD"
    "GZPYLoBbDGB41cYdN68blQBSgHWeR5/cx+n9v6VcKCGlQMpceryEYOLl31AtVBGyc+xEevUK"
    "oNCnn1pFsHXzVqw1BF/qB1gyUN2xvD4AAqwL7H3pBGLy33xm+3aq1QrVaoVSqUw+n5tXmEU8"
    "vRlASBAy0GrEaK0pFAsMVAdIVIy1Nt0CgV7ghJVKcaCQF1gXmJhJOHOpwRI7DqUiAY/zFmMV"
    "PqQAXfIemE792g+VcUsnmdxdpFQqkctJrLNYa5FS0mjMzcxdnXmkFyAE7zRAbBwnz14mThI2"
    "jK6jVhaUymXKpRKFYiFVkn0FU0frBCPz0dD0SY8QK1k2CMVSiXK5TLvVIleVWOf8+YsXL+7Z"
    "s+/1BQBRYhrGehLluDzV8MPDy+XZqZvUWHKkUShGoVDIByklAuEBfAghiwlCmjqByHxk5Lwn"
    "a8WHgDUmmZqe/tuRw8ceAvILAC5fOPPLAyfWfXLD2hV1Y7yuVSo5Wx469fKJgX+98eIjL5j2"
    "1TZgAAfY7N325OtJFoiBduYqKSAQjj7xo4MHj7593LnA8mU1EcdxY0mJiyPLypPeRHGm2GWK"
    "VZaTbMIom/R/5ahnEf7am1CfePXFB/6czz/68Tvet+70hSmZF+Y/0ezEeafjJml0YQGdTdIr"
    "Nb3RxzsnB/gMfP4UhBCCEMKeevpXx6LZyzsTffejK4aXvmfiSjQ0N/n2aaCRKfDMm7+TOyDX"
    "k3wGoQG1wALZVrSFEK9HrenPbfnEvfc7Wfn68tu/mRu8MvHj2UvH2z0TdLaiA3C9/3ChMzaE"
    "4MU7/fsJISTpfZbb/LWffyAeP3351LMPTfVM0JnEXafiRdN/AZGp5i/kAzdlAAAAAElFTkSu"
    "QmCC")
index.append('actions/attach')
catalog['actions/attach'] = actions_attach

#----------------------------------------------------------------------
actions_zoom_in = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAACF0RVh0U291cmNlAGh0dHA6Ly9q"
    "aW1tYWMubXVzaWNoYWxsLmN6aWbjXgAAAEl0RVh0Q29weXJpZ2h0AFB1YmxpYyBEb21haW4g"
    "aHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9tYWluL1nD/soA"
    "AAgbSURBVFiFxdZrbFPnGQfw/3uu8fHl2LkQ4txoQgRhkHARIAWWdpRAk7SwaINK27RR7aIy"
    "iVWahjapmoL5sGoBsTBN27hom9oiDTEqRDuSwLgVMUQIl625wSDECUkc4xAf2zk+F5/z7gM2"
    "ioCxZK20R3r12JLl/++853mPTSil+H8WN5MPHTx4kFcUZQkhZCWAckppN8MwXYlEor+5udn+"
    "PADyoh1oaWlZVVRU9IeysrLKgoICxu12g+M4GIaBSCSC0dHRVG9v76fJZPIHO3fuvPeFAQKB"
    "gOB2u3dt2LDhZyUlJURVVUTjKv41okBRTZTlu1CSLyMrS4Qoirh48WKqr6/vRzt37vzd5wa0"
    "trYW+P3+K3V1daW6rqO9M4i/Xh9P2iBxp5SlsCxvqGrSaZgp9xw35/zh6/OzyornIhwOo729"
    "/dNIJFLX3NxszBTwzAw4HI4P6+vrS+8Ph/CbT+5aUxY39ObGZeMv5buyZYmXUjYVxqNa7MFE"
    "cvhyz5j57vs9S7fUPPI11pSThoaG2uPHjzcDeHemAHbXrl1P3uzZs+fbTU1NP05qOn7+wWdm"
    "YXHB9bffWOJYXCoXeyResnfXZQsfvyc78gq5nEXLhNI5btZghO5zt0bELJKSVywqJbqurz1x"
    "4kR7TU3NyEwATOZFa2trQVVV1SFJkvDB3+7B7ZP736wtz8l1Cx4AIASEMVWSTUZYGFMgoNQj"
    "cY4V83PyK8qLbvz50kjk/tAYampqiCzLxwKBgDArQCqVaqisrBTuBMdxK5iIbFxVHnc7OEfK"
    "ppaZsvWUZSdBqQ0AxLZNQojGEGjKlBEjhKGFxfm3ft8+EDdNEwsXLiyWJGnlrAAAVguCgFsD"
    "Ubg9rtHCbIfXtGwzZdmaaVHVtKhKqW0DAKW2QYEkBZIPY9o4BVSXU4oNPdQSmqYhLy8P6WfG"
    "f60nQ5ibm/sV27ZxeyRBZU/umCgwL6UsqhFCLdu2LYYQi0sDYKV0SpGIJc34+CNjnAEkSigB"
    "S9Tw5BTm+DwghKyaMSAQCAjV1dVlpmliPKrr8+cImueXGwuz1DEeAAhAAQoOGuFYCsfpfcWO"
    "0/uK3IZuvk3xsmXawvmlPzk/JK6MDozFkJ/tgizLtTMGLFq0yDJN02JZlpFElosnU7ZtarYA"
    "lUmHEwCUIwbDMIBIVIZalsWzlKMgRLcJIbBMM5Xicj1ZME0TlmXpMwZs2bLFOnToUB/P81Xz"
    "5zq5gfhU7j8af32l2GW5eAY6R6jBMtBdf/z+lwVzyHdbqD7WU1J/3WJFp8UILovlXA9zKql5"
    "79Gy4jlOmKaJRCJxacYAAFAU5TyAqspiN7qvRvKvJfLP9aVYLc8jGg6B1WJJK9SoJpZAgk8n"
    "/IM7pa/dJwyVCYVMAS+1iM/BR7NEQUAoFIKiKDdmBQDQ9ejRI6xe5Mdf/j5amkzqsk15Jaam"
    "FEqgMAQxisfPbUoYhiEgtk0IGEpAgbuDw2vferkoVxRF3L59myYSibMzATw5hqIonrxy5UrE"
    "6ZSw440K8cFwaD2hDAdCOQbgKSUiBcMAgMk5HKDUQQgECvDhh0r5vByxonZZKRMKhXDz5s33"
    "9+3b1zMrwI4dO2KRSOQbV69exeKKIny9piDvzt3Bb6pT2lwKkkUpJMsGH4k7piwmywGGcRNA"
    "Cg6GXrHU+OvvfLXSSwhBR0cHotHozUAgwLwoOFPP/Bru3bv30KZNm75XVFSE/oFRtJ7oVzWb"
    "7RGzxM/msfERJ6sZQUN2RnRSrqrJFRuX5hV+q65S5Hke8XgcwWAQ/f39OHXqVLuu6187efKk"
    "OitAIBBweb3ej5YuXVq3fPly6LqBm3fG0D04SXuHY+qUbukluZLjS6Uex/KKOZhXmAdFUTAx"
    "MQHDMNDV1QVN0+B2u3HhwoW+8fHxVzo6OsIzBmSqpaXlrYKCgt/W1tZmybIMnudBKQWlFAzD"
    "wLZtGIaB3t5enDt3bnTBggX+7OxsxONxKIoCRVEgyzKuXbs2MTAwsLajo6N/VoA0oohl2d1e"
    "r7dOluVCr9dLPB4PotEoFEWhoVDoweDg4Hsej+dAMBj8uL6+viGDzPxt83g86Ovr03t6el5r"
    "a2u7MCvA9AoEAi5JklZQSssA9CWTyX82Nzc/ub9bt251WJZ1bPPmzY1OpxOapoFlWYRCIbjd"
    "bgwNDdmdnZ3faWtr+3BGAEII8PiUkGk9szCtZ4r6/X6mqqrqF01NTe/k5uZiamoKkiRhdHQU"
    "kiRhYmICZ8+ebe7o6Nj9XAAhhEmHsek+HcCsWbNGqKurcxUXF0upVIrcvXtXPX/+vNrV1WUC"
    "oJm1bt267zY2NrbMmzePxONx+Hw+jIyMwOVyAQCOHDny0/b29pYngHQw+1T4E8TRo0crlixZ"
    "stjn8y2UJKlCEAQ/pZTquj6WSCTuhcPh252dnb3bt28fSCPsNWvWvLp+/fo/VVdXc4qiICcn"
    "B+Xl5fB6vTh8+LB25swZ/6VLlyY58nivmafWdAR7+vTpyby8vEkAYdM0BZ7nY5RSoqqqMjk5"
    "OREMBhNtbW0JAAIAG4B1+fLlc5qmNcRisY/Wrl3r8vl8EEURhmGgpKREBOAghEQz95F9wQ48"
    "syNPzQQyVz2tW+luL168uGD16tWfbNu2raisrIwoikL3799/48CBA6sppRaXngGLEGKnQ+x0"
    "QKZb0+fgOcOYATwPYnd3dw/Ytr1qeHh4m9/v3xoOh08ahvErSqn1zBBOG8ZMwPOu+D+egmn9"
    "GQgASp8TNuPnwDTc88KRDpjVd/1PgC+6/g219gj+XLtPWQAAAABJRU5ErkJggg==")
index.append('actions/zoom-in')
catalog['actions/zoom-in'] = actions_zoom_in

#----------------------------------------------------------------------
documents_pydoc_open = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAADt0RVh0RGVzY3JpcHRpb24AQWN0"
    "aXZlIHN0YXRlIC0gd2hlbiBmaWxlcyBhcmUgYmVpbmcgZHJhZ2dlZCB0by7UZ1hFAAAAGHRF"
    "WHRDcmVhdGlvbiBUaW1lADIwMDUtMDEtMzG9E+8ZAAAAIXRFWHRTb3VyY2UAaHR0cDovL2pp"
    "bW1hYy5tdXNpY2hhbGwuY3ppZuNeAAAASXRFWHRDb3B5cmlnaHQAUHVibGljIERvbWFpbiBo"
    "dHRwOi8vY3JlYXRpdmVjb21tb25zLm9yZy9saWNlbnNlcy9wdWJsaWNkb21haW4vWcP+ygAA"
    "BkRJREFUWIXdl91vHFcZxn9nZtazG3ttx3biNGmLEhOJD4uKuI1AIAUh4UaCXADiAhRFcBGJ"
    "f4DrSiAF9SY3RECu4IZGSgmXrZBSEGDJqK7kVhEEmsZxHGfjOLuzs7uez/PFhT2b3bVJogqB"
    "xCu9mvM153ne58x7zhlhreV/ad6TOs+dO/d6uVw+CgghhLDWOkII4TiOcF3XcV1XuK7rFPWB"
    "p+itO47jCCEEYJrN5g8vXLjw96cS8H3/a5cuXfp8nucAfPDRBm/88SZhnONheOWTB/nBN15m"
    "e14QQiCEwFrbLffWARYWFoLr169X+xQ4f/78a47jzOzBYSyOY8rlMkII3n5vlbW7NbbGplG5"
    "5vbibb55apaDk6NPlLkAB0iSREopoy6Bs2fPfml+fv5Hx44dGy4iLV5YXFwkyzKarYh3lldZ"
    "ubNOpjSiXkNVRkmTnLs3f0My9RwHP/EqaZpSq9X2JHHo0CGq1SpbW1saeEzAcZzWyMiICoKA"
    "MAz7XkrTFM/zeP3NRe7ICmpoAjk2gswzVJ5hjWJ/6W8cqXzA6keKysQXGQyiAHddlziOaTab"
    "Wmvd6hJQSm2EYZhPTEx0Xwaw1nLgwAGyLONBK0WVXJSUiKiFr3NKWvP14yscmYypeIY8WsOr"
    "vkylUukjIISg3W6Tpim+79NoNOKLFy8GXQJXrlxpnDx5Uk1PT/dF32g0mJ+fJwgCtFIoJKfG"
    "lvnuqw/wXAlG8sK0S9mTIGOkTInjmCRJ+qIvzPd9pJREUVTvbXestTZJkqRarTI0NNT1er3O"
    "1NQUnU6H0ZJBy5wvHG3w6eOjHH+xwvEXPMpOArJN3GmSqP2EYUir1drTpZSsrKzYPM/f6SXg"
    "AbTb7cjzHmekMYaZmRmCICCOY749N8XSrQYjZUC2qd3f5OatTYzOcUZewZZepDT+EnEco7Xu"
    "zlMo4TgOWZaxtLRU63Q6P+tTAKDVakVaa/I8J89z1tbWmJubY319nTiO8V3Dlz+1H2EMyDaH"
    "JwyHp0p4jiXyTiGH5naBF9+R67q4rksQBARBcPPy5ct9S+ABKKUCz/MwxmCt5dGjR/i+TxRF"
    "feuZ6s+x8P6fKWGwtkrkfhapy8g47io3aK7r4jgON27caIZh+OPB/kL3NSklQgiUUszOzlKv"
    "13n3nktDDjPkFSRGgRk+zvmR8lLVfubkG2d/+vttdQx27WFroVDgdiFhrVbj9OnTBEHAg47g"
    "W6dnacfqybMLYICT7WnY4esBzxd9Vd/j579dyj2ALMtWWq2WklJ6YRhSrVZpt9t4JYdOotgI"
    "k12YvSLYgYLthbf9Y4pzoWRknmbymgNgjNnodDqJUooTJ05sg3sl9pV94kxhLX1u+soWay3G"
    "Wgw7z6Lf9I83xhJlmmrZ4593G4HMsr94AKVS6UEURWmWZdWZmRmUUrRSGBvdR5KbbfY90XWr"
    "A9Fhe1fC9illgSTXGGOp+C7rm63m8q++H3oAaZpuhGEotdZUq1XiOCaIFMPDFTKpMbYfaU/w"
    "AcDePq0tuTIYaxEC4lSilPkH7OwDV69eTZIkyeM4xvd9PM9jtaHwyz7K2D3k3F7lQv5t3700"
    "xljSXJP2BFEZcrn/sC2lkm92CQBkWZa4rksURZRKJe6HCq/k7Uw4CLgDxm5AYy3KGHJlSHON"
    "Nv3p4Zdcbt+rb+bKewt6bkRZlqXDw8OEYcjk5BQ4HqnU3ZwvZDe2ILJNAnYUKr4B25uAe5i1"
    "hJ3k0XuXv9PqI6CU2nJdl2vXrqG8UTjyVXJp0MZ23ZinTP4Ucx1BvbmFNuatoq1LwFpbm5yc"
    "JAgC6naa5/bvp5MqzICE9t9WntqMEII7681Nlatf70VgNUkSOlsxndFDPD/kk8nde/uz7MK7"
    "huw0aK0Iws69v/7ye7f6CAghnDNnzmyMj4+zoQ8yfugwSQG+1473LOC2rwZA/VGQtBu1X/S2"
    "FVmwr9FoNGpNmeXjs4yMjqK03Xbz2PUzuDGPs8HsfKjGQi4Vmw/rmx/+7rU/CCHKfQoAcnl5"
    "+U/7po5eV6L5lQ+X3919p3pG6/0HADAWqfDvg9mqvf/2T9K0lQHd000UabbDahwYBkqA+3FJ"
    "7GEKkMAWEFpru7dfMXi27/w+uf9hAtpau+eZvovAf9ucpw/5PyfwLxjDPlNkX36mAAAAAElF"
    "TkSuQmCC")
index.append('documents/pydoc-open')
catalog['documents/pydoc-open'] = documents_pydoc_open

#----------------------------------------------------------------------
documents_pydoc_new = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAACF0RVh0U291cmNlAGh0dHA6Ly9q"
    "aW1tYWMubXVzaWNoYWxsLmN6aWbjXgAAAEl0RVh0Q29weXJpZ2h0AFB1YmxpYyBEb21haW4g"
    "aHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9tYWluL1nD/soA"
    "AAWoSURBVFiFpZfdbxxXGcZ/7zkzu7O2t3GcjR2gLqlAcVLa4osKVPGhSFyAhECo4o4b7pGQ"
    "kJD4O3KF1GsU0V6lokIoqIVQCSFCWyrFDnFT1zWpE8frrL1fnq9zXi7s3a7XM7YrXml0Zs45"
    "Os9znveZd86IqnLaEBE5bnj04V9/IJr/GnUHUbJHsr1K+6UfEQOqI6DB5wCUkvZQ3+uvM/Xy"
    "18OvTk6Fc1bkKRETTkY+m3pR2w8/yh59upqtiEh7QELGFbh+/fqv5ufnfx0EgRpjUFVUFe89"
    "3nvJ83zY55wb3ud5TlTZNpO1tXBiYstGlR0bBj0jOHFqNI6rur394G+Lz797LcuTO4153ShU"
    "oNFo/GZxcXEujmNUlSAIGCWpqgyEGRVI6BKYf2PYwkoTazOEPiIZqiFIxOrq9PcqYfSXyQlx"
    "bEmb89o9REBE5ObNmz5NU3q9Hs45oijCOXcIsIhAaO8hwSrGrGKCNQxdxJ4HqggJ+A1mzubW"
    "mHBBoZOF7kkI748rIOMAZfeHWmKs2SYwTYLgMdZ0EXsJ5BnE1FHfQew6kxMfGBtUvmzwG14q"
    "c6xJNCRwYDjx3sso4PhVRMBID2t6GNPFyC5iZ/fB7fMgc4hsghdMsIkxjxrqZUZUztCgbsYV"
    "GOT4uN2PX0ZSRBxCjki2L7upg1xAgm+BzIFMoVoRMBEqFcSEWKpHUuC9P7LLk1KBRIiEICFQ"
    "ARLQLugmmv8ddHP/mUS994mIpqjPcCSjBGRUgdOAf2bCOkod1Tpez2D8Y5T1A0OtHZBZR91j"
    "1Pomqi0xvk2TzrEKFOW82Ac1lAaeWbxv4WUP41dQWkB1XxG/Ra9v/UQ1WbeB2zA+e2QvanyE"
    "wGiRMeYzi5xkRM+zeN3FEYMDazcRtzNSBy7Q2uk5eeru/TCMP07D7H6Dw4VIAJxzIiKEYci4"
    "IY/1AXU8lxAOFHEziHQQcpQAkTM0W+suT/buOp8uv/ANuqoHBEZqvhRVvbK3YFwJ5QKOKVSn"
    "UdlGtAPkqFpscJbHTe9e+1P63rVX2RxgHElBnueFQGXgxUq8iGoMdBASvFZQP03zyZa79iq9"
    "UcBSEx7qPKYgFZXl/ajtp2JfS8QMvymHJpa+hmWg46TG78uibPyIAs650pVOo8RxMaLAcHJh"
    "CgZGLFOiyBdFuxxf53OloNlscu7cudLdlCnhvWdvb488z4njGGMMURRRq9U4+NCVEhgqADAz"
    "M3OoEJUBj+++3W7z+zf+zO21Lnu5YHzG5dmAn/34amEKjnwNB4cPay3e+2ONOEoKoN/vs729"
    "za0PO6w+2KFTf5pm7YvcWstYWl6m3+8LYMsUKDwPnBSDOb1ej7feepvb/9lg69EuOQGdtRWC"
    "818gccKDlTf56L9xCJwFWkUEoKQOFIGOEnTO8fDhQ373jy3y2StMXM4J04Q8TcjSFO8yrr7U"
    "44ffdtHy+9HLt27H64O1jqTgNATGI01Tlpbv0q9O45wjz1KSfo+42yXtdXlh8g6XLk5w+dkp"
    "WbxS+y4Q/l8KFEUYhrg8RrOUhfRtXvnmI2oVQDOe+0pEvWog6x/5DyjyACf9LY0eWgCq1SqX"
    "FxYI3nmHJK3y/ec2+cHVi+D6kPf226xLp90mSbP3gKRMAQYKnIbEkLkIs7Pn+c6XlA/W15mM"
    "DGS73Fv5hLv3PsW5jMkzV1jdOJv89rXeG4ArIqCAc86JtXZ4HjDGYIw58Vg2NTXFL37+Uzqd"
    "Dp+8+0/I2iw8U2W3VWdnt0349C9Jn9yJ4c0e4IsIeCBbWlr6440bN34ShuEQpCyKxpIkkQf3"
    "K1VJPg4qdk/6ezkfbjRc3l1KlpaW/sq+/EMCMlKvDfvurDYajUnvfaCqRxCK+sbGjXOu5pyb"
    "9t43jDGb1tpOGIbdVqu1C8RApqp+nMCgRJqD6+QqVB6DdSyQH+xYD1rPyC/6/wBawvaX+H+R"
    "pQAAAABJRU5ErkJggg==")
index.append('documents/pydoc-new')
catalog['documents/pydoc-new'] = documents_pydoc_new

#----------------------------------------------------------------------
tango_apps_help_browser = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACG5J"
    "REFUWIXFl3twVdUVxn97n3Nubm7euZcghEdeBBICEQUFIgVECqIo1uJMp3WodqyjMzpjZ7TT"
    "h20cK31N/2jL2FYdKXaqRcbnDKGpoBFaAY1BHgHMgyRKQkJy87yv3Nyzd/84594k1RlppzPu"
    "mTXn3Dl3r/Wdb31rrbPhS17iSv+4bl2t2ZFhrRGI7QKxRkMAyHEfjwgYEOgjNnpfcXjiSEND"
    "beL/AqBoW22uGE/7MYL7yubN4MYVpVkrquaKqwJZ+LPTARgcjdIbHKOx+aI+9EH7WGvnZdA8"
    "q9PGf9b5eu3w/wygaPPOh6Uhntxcsyj9/q+vtMrnBa6Is7ZPgzzzyvGJ/YfPRpWWj3fWff93"
    "/xWAonW1Xu3z/nVx6cxNTz741YzK4gIQjuN/nfyEEx9fIjgaYXAkhhAQyE3Hn5PBsvJZrF46"
    "l5I5+QB83NnP40+/FT7d1ltPOPrNzoba2BcCWLy91hMOp72/bX1VxU/u3+BJ91i0fhrkuTca"
    "aTzbjTQkhpQIIZBSIBApL1prtNYsryhkxy1XUzonn1g8wVPPvh1/5dDpcz5f7LrmfbXxqfGM"
    "6eG1yCw+9uq2G6tW7nxoU5plGrzecJYnnnubSwMhTNPAmmKmYWCaBoYpMQyJaRhIQ3IpGOKt"
    "4+1k+dKoLJ7BjStKjb6hcN7JloFrhlsO7oUnPh9A8Rbvo6uuLrr3N4/ckm4Ykt/vPcqe/R9h"
    "GAamaWJZbnDL+W2axqRJA8NlxzAkAI3newhF4lxbMZs1y4rNM+19c0PZ++NDLQff+0wKCu/Y"
    "6c/UVsubv/12/ryZubxUf5Ln3vgQ0zKnvK1kadkMlpQUUFEUoCDPR25WOuPxBH2DYZpa+qg/"
    "3kEoGsdWCttWJGzF3ZuXcuf6Ci5eHmXrw7sHR4mXd7/2w+A0BvylN+265/bl19+8eqE8c6GP"
    "n+85jGkYWC4Ay3Luf/3AV1g038+MXB8+rwfDkKR5TPKyvCyan8+qqtmcau8nFrcdnQCn2vuo"
    "LptJSWEeE7bynDjdXTDUcvBNAAmweF1tpmXKu+65bYWh0Ty97zhSyGkUO0BMhBAI4RAXTyji"
    "CYWUEukKMz/Ly/b1C7EsE49lYlkmhjTYvf8jNHD3lmsM0zTuWryuNhPABIj4vFvWXl0s87PT"
    "OdXWS8snQTwec4ro3DSYBglbcfx8P+8199I7FMEQgg3L53N7TWkKXOV8Px7LJCFtXKx0dA9z"
    "rnOAyqIAa68tkQePtm4BXpaO9vWOm65b4EPAkY+6HDEZTt4NN/dJML946QSv/fMCA6PjpHks"
    "LI/F2a5BtNYpMUtJirGpLL7f3A3AxpXlPiHFjhQDaJZVlc0EoPWT4DQ1m8ZkKizTJDRuY1mm"
    "C04ipWDNksJUD9Bac7E/jGUZrmuN1qCU5sKlIQAqSwrQWi+bBCDwF+RnAk5fl27wqeYAkZM9"
    "wLWaxVexqnJmKritFO+e7sMyDdBOc1JKYxiSkdA4CMGM3Aw02j+VAfLcwTIWibuiEpNApJMS"
    "w208ydJcu3QWaxZPCW7bHGjspmcwimkYTmAlMWzHTyTmDMiczLRU/ctkNxgajboPvUghppuU"
    "GFJMY6O6OJ/ViwIopVBKYds2dR9e4uPuMbc7Tm9MUgqyM70AjITHUy1IAghNsH8oDEAgz4cQ"
    "OIqWjkkpEC4rSYfXL/SngiulONYyRFd/1GXKAZxkUrgvkp/tAAgORxAQnAQg5InmC5cBWDgv"
    "4NS5EAhAINzyIlVmUgiy040U9Uop2voiKYakEAiRvDp7EYKS2XkAnOvsR0h5IqUBrfWeQ8fb"
    "1t2xvtJXs3QuB462TfZokbxMGZxC8If6DtI8Fh6PhcdjojSpBuXin7Kc3csXzQLgrWOtEWWr"
    "PSkAvkis7kjTBTU8FqOypIAF8/x09Y6QFGjyTdHJstLsWDsnNZIBXj7Wj1LKYSS5B412nRTN"
    "ymHBnHxGQ+O8836r8kVidakUNDfUhhIJtfcvdU22AO69dRlCCNeZU8fJe6U0ylZYBlgGmNKx"
    "+ESCiYRNwlYoWzn/UxqtHOB3ra8AAX/7x0nbttXe5oba0GQVAPGE9dju1z4Y7u4fY9F8P9/Y"
    "WOUEV06O7eTVnXBTBaiUIj4xwcSETSJhk7BtbNtOPdtaU0ZpYS59wRB/2ndsOBa3HkvGTU3D"
    "0fb6aE7ZBt3RM1yzuabcqiwKEI5N0N495ChaSKcihJPRa0pzsbUmYTugPmgbJmErB4DLxETC"
    "5oYlhWxdXUrCVvxgV32krav/qa4Djx76D4kllxalt/7q9e2bqjf99Lsb0oQQHGrsYO+hc0gp"
    "3emW/Bhxm5NbZlqD0g79CTcFt60u4YYlhWhg5/MN4y/WNdW3vfnoNhD6Mww46wlmV9/w6snz"
    "A1sHRqKBVUvnGQvm+qkuKyA4GqVvKOJAdrcn8zz14yNh2ywozOVbGyuoKg4wPmHzyxcOx1+s"
    "azqTlhbZ3H92vT29Pj5nzVn1SLqVH3ipunzOxqceutlX6n7lXrw8yqn2flq7hxgLTzAWiyOF"
    "ICfTS44vjbLCXKqK/cwOOHOl49IwP9r192hT84V3e4+9cF90sC0IRL8QAOADsgvXfu9Bb3bg"
    "kTs3LPN+52srzPlX5V7RUerTy6M8/0Zj4uUDH45Hg13PdB/9425gzLUhQH0RgDQgC8hKLyid"
    "7a/c9oCV4d9WVTpLbF5TmX5tRaGYkecjJ8MLAkZD4wyMRGg636PrDjfHzrT26NhYT33w1Kt/"
    "Hh/u6XUDh4BBIHwlDIBTohlANpBhWb6s7PKNK30FCzZa6dnVYORoIX2OExVF26Px8NCZSN/5"
    "d0bb3mlKJGIhHLpDwLAL4jPnxSs9nBqABXhddrw4XdRygSrABuKuxYBx9/6KDqlf2vo3PYe5"
    "6vmkuwMAAAAASUVORK5CYII=")
index.append('tango/apps/help-browser')
catalog['tango/apps/help-browser'] = tango_apps_help_browser

#----------------------------------------------------------------------
tango_places_start_here = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABSlJ"
    "REFUWIXdl1lsVUUYx/8zc7a7daUroXQhlkpoQ4sVA8b6gilbIEIDggEiEiSRFwzEJ/pCXXjg"
    "QR8sAW0I0QQSicZIiC9IsClFFqlC6HorXW/Xe+/p7b3nnpnxobbpJW1pS+uD3+N3vpn/b2b+"
    "c853gP9rrNp1WZtNHVlo4ZLDl/YzkC+lhAMUZ+9Uv3MCIHK6eraQ4sXvX9ri0tVvD2wtMt4o"
    "yaZPvP1rE1bf93ff/f72dGMWbAcKj1xMNYTSeGh7cbxUFNhcQpE2Lvxwz1Sj4czfvn4vONU4"
    "ulAAGicni/LTjYR4Jxo7g2jzjSAzJQ5Ll3iUCDUqphu3IACF7150MUqPvr4mS2/sCkICEEKi"
    "c3AUhfkZBlXJjkUF0HW6JTXJTVwOHYOmNZHv80eQlRYHSFLyQgCrdlXOeKUkIRtezklVff5I"
    "TH7U4vC4dAjO00sOVzvnASDJ8vJPz5ghPZSz+ZNg9uaq/VNOQkmypjMaifKYvC0kKBn3eaI6"
    "Z4DsTZ9/mBTvOHZ0TxnbVV7q1hXlfO6mqi3P1nEhvIFg2NbU2Ol0hcIM2yAgPHcI5pwA8rd9"
    "5iFEnN5UVqS19piQTMHO8lJFEHIpb+OZ1Mm1DLjT1jVsexyxizQ0hkF/CJSSlitXKmK353kA"
    "Yc4rUpPilbQlcXjQ5MOv9zvgdjuwesVSw1b4yRgAxut7B4KGxgjIpDdLSpyOx20+Swh5dTqd"
    "aQEo2I6VKzKNJ0+HwIWEkBJ1j7rx6ppcnVIcTdt4xjVeawmHyYVE1BYTZ+5xqFCpxMOmHoVS"
    "XJgzAICSrPREtHX7JxKdfSaYoiIj2UMczJ7kBVuldExY/Gu83FQXrtc2WlLImtvVe5vmBJC5"
    "tdIppUh3OjUEQ1bMM29PAMsyl6gScgMAFB+6WECkuOlxaLBsCQkgM8lAR++wbO0cClpW9PgM"
    "i5wawBg1VACghMJ65mqFLRuMMUooSwYAytgxl6EWFOSlcv9oFJpCkehScb22kQsujzyoOTg8"
    "Z4DWxFxTEvDASBhOI9bZDk1BYCRsQwovADCCbbvfKsS6wizW548gJU5HQ4tPhsJRJcevTWu+"
    "GQFwpYJT0BbfoIl4V+xL0O3Q0NfvtyXFnZLD1SrnMlNRGf78O4BwlCMlXofKxhcisucHAEAK"
    "cbW1vdfKSHZP5AgBDI2if9g0OHi9orscACAkgS3Geo5AKIqoJSVltPbuud0t8wagjF3wdvUp"
    "To0izjm2C4yOeYJzAS2smLe/2BdglA72Do0gwaki2aMhErFQ+9ArbFvMaL7nArT+dKKJc1FT"
    "/0eztTI7GZQQcCEmrpniUFQAICBnb/7eEtaZBOwofrzxyLI5P3Xv/L662QDM2BFlb69MQFRv"
    "Xlf8UlIUKmnvCWBtfhpu1TXADEUeS0LfznmltCnU3V0jBN9DKIsQKU7Xn9tbNVMfOGsAAMgp"
    "r9qpG9p3b64vUhraBpCe5IQ5PMzbO3xsNBL9yvvzxx8AQNmBb4wbNQfDsxGdHM/tB9rcK66G"
    "I1Glpb1HZiS70DUwgrycpWx9aQEIJdvG6+YjPiuAZaY3GwA0hSHBrcOKcjxo9kGAQgqZWVJS"
    "PeV3fsEAnl470UIJqbVsLobNsY4nagtwPnbE/tRux6ICAIAQ5Hirt0sKbiPJY8Dj1DDoN0FA"
    "BpuvVQYWHcB77WQdF/JUw1/Nlko44gyK5raOMICzLyIOzOHPaLjpl1vuvFuir3/otW7fAOO2"
    "vLw8FP7I670hXhRizpFdVmn856KLFf8AcP0p5DnhnVEAAAAASUVORK5CYII=")
index.append('tango/places/start-here')
catalog['tango/places/start-here'] = tango_places_start_here

#----------------------------------------------------------------------
tango_actions_go_first = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABOpJ"
    "REFUWIXtlmuIVVUUx39r73PHrlpgKUoPjRJBSSytzPGRYUWiVFZDalHQg9ICCR8R9CEJlIiC"
    "MhGiInxERZYVqSShH8qCRNMeSI7FpBONjq953Ln3nL336sM59851nIfNp6AWbPY+927W/7fX"
    "Y58D/9t/3QSgdmmkXf+oudDld71AsS8HU5fa2Yps3f2Kk/4AROXFqic3YMRixPDsuvml1g4G"
    "QO8A05bnllw06OLVbYUWwPVHH1NZqbL7982onhOMc6yuDlu7zL552bCrVq9Y+Fo+Fw3olzhU"
    "RSAQCMGj9A4wczGDGwdGn04YPXlK3S2L8pHN9VscqiKgqnh1qPoeN09eweXxoGjvrOvvmn7/"
    "rKfy9c17cL7PMjlfgDQCQUO3G6ctzU2qoWb//bOeuHrGtXNzBxp3carwF149CG7KM+T7A9CZ"
    "AvW4kBC6icDUFfbOGpt/76G5SwYOvWi47G/8itgVCepTcO8jsdGZ2mXnVmJkcxixxEkx312n"
    "VAEEXIjPAZi6LFo+ZNCwlQ/PeSbvJWF/485UWAIqAWOF5x9ZQ1DNqYacaiBoGknVQOJjQHh5"
    "/fK+I+BDQggpgDVEtcvsO1cMHz1/we2L8sfaGjh6+mB6cxgFAqDs+m0DSkAJmQ+HD54QHC44"
    "nIu5bczj55eCxMd49ahSEyXRjgljJo+dfdP8Cw417+FE21EwIJLqq2S1Ipk4AcWjxqPq8ZKg"
    "kj4jPXdWlxqopEBunjjnmhvHzcjtO7qD1tIJjBFEBVFFjaRORTMAzSA8AY+agJJ2lIrrhO0N"
    "wIeExJcI6pk/91GuHDou9/XhzZRcO2IEg8EgCEpQiH2BOLQTawGPw2uMakAQRCIMEaIGIzZL"
    "Vx8AbaXTNLcdoSNpo+n0ES4dMpqcraG1dAINHvUOLzGJdpBQQIymYAZEBDFgRNJrTB0+OFSV"
    "EBSnpb4BAGJfJHYd7Pz6Sw7V/1q8dcqdF7SUjtPYeggTCcYK1kplbYwgVhBJa4OsyVRBQzrw"
    "ZEXbvZkefo0bmxo++3zX+4VrRsxk7Ija7LSpoDEZgBWMBRulUDYy2AzS2s49ItKjXrcAomhT"
    "Q/L08WPHVn20fX3HiPwYJl12B8bazlNXQ2TiJhJMZa4GqLjOddWMuoqXzbVjv3vdrZ34WMuf"
    "m7dvXDtn1j35KSPvZW/TZwSTpLm3MPeq5UhWB2VT1ao0KBoqKSi/uWJIy6VngCIWsHvf8tvG"
    "zSst2OI/2HDb9NmDp41cKN83fUxCexoNAy+9sbInN13NklVFNvcMoIFyWZlfPvE/jKqVu3eE"
    "LzZNvmHaJdPHP5Dbc/wTCqEZABFJ9m1I7is0cQpIshPG3aylatArgBgUOkfDbvdH6zHmBf3m"
    "7ZaWM1ffOqNuwI+ntnWGXkiyU3nK93TnXD2g6mLovgsAm6PcROXhTtZz4sA7buHPP/70zZat"
    "HxbHD5ldFldjKZJ+wpVPm5B+p7kuYOW5d4BoYCrK2WEstZ+m9ds1bnH9oYZNGz96t+hK6aFM"
    "jgLQkY0iUOoCk1T5qthZAHXXPVdZXziqIloRzxwXgfY96/yLjfXNK9dtfLVDg9bYAXRABaK8"
    "r1QFUl6fdSudz2e5IW2fiLSKTdUsEx60MwcNlw8ObnEjTx6mmIW3PHxVFLq9Dv/Jt7xUiduq"
    "52pTOnPs6O0t9L/9W+xv8tKNJLV1FfAAAAAASUVORK5CYII=")
index.append('tango/actions/go-first')
catalog['tango/actions/go-first'] = tango_actions_go_first

#----------------------------------------------------------------------
tango_actions_system_log_out = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAN1wAADdcBQiibeAAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAY6SURBVFiFnZdNaFzXFcd/933Ot62xDLLGtsaR0lSJjTAmCCdRszCpVsFgEmiITVuyyKbF"
    "2+BVN00TJ4VmlU0KST/ovnRRaEOySMam9SIYIqwiqbhuYuvblkZv3te9t4uZ9/xmNDMKPXCZ"
    "N+/Nu+f3P+fMvecKrTX/hwnABBzA6lwnpgEJRJ2hOvf6mgXw+pXXfhlF0bXv5FkIDMPAdV3y"
    "+QK5XA7HtjEMA41GSkUYhriu+8H1d967BgQdoMEAURRd+/GVn7K4uEir1SKKIoIgIAxDoihK"
    "RxzHSCmxLItiocDVq1cZHz+GEKITFNBa43ke7/36+lXg7Y7zgVGw0gvLwjRNLMtCSpleK6VQ"
    "SpGkyjAMHMehXK6Qz+cwTQshRAeiDVAqlRgZqQKUgGaHbjiA4zhYloVt20gp0Vp3jcS01jiO"
    "Q7FYxLLaoTcMIxMBBUCpVALI0V0fgwFc18VxHKSU2LYNkCrXWqcqtdbYto3jOBiGkVEvOjMZ"
    "gMZpz2FmHgwHcBwnBUgUJ46B1FkCYHcKLzEhIAlUm0ckNEMt/YEQAtM0cRwH13VTJ7Zt47pu"
    "mh7LstJ6SeD6iRSP74m/PP104Y9CnBsagSSUhmFgmiau66b3EuVCCJRSGYDBAhO2hfffLzbv"
    "3PmzgGmgODQC2Zwm3xPFWfWPAQaHFmD9iy9Kt996669Tr7wykz92rG8xdgFkHfcCJdVummam"
    "8mFQjQnP47P5+U++9+qr05NXrliDaK2ulzIQvUCu6zI1NcXe3h7b29uZ/O+3cGuL/K+u8+TL"
    "L9dPvPSSqXZ3QSnjT0I86vnpN/sA+qlPcm/bNkePHuXIkSM0m8n6kn0f/PUNPpv7AdNzc4yf"
    "P296N29SOHeOuXfftTEMG61Ba3Qc87c33igeGIHs3+/GjRtUKhVmZ2dxXXefcn9tjU+ff4Hj"
    "MzMcO30ar9FAS8nO558jzHYJaKUgjilfuDA4Bb3qk3H48GFGR0fJ5XLcvXu3y3nr/n0+fWGO"
    "2vQ0R0+dotlogJRgWW3nSc0ohZYS5Xn7AXqj0JuOSqXC2bNnWVlZ6dRBR/nqKn8//xy1yUmO"
    "jI2x9+WXoBTCtsE0EaaJjiK0UhiuOxxgkHrbtpmZmWFzc5OFhQVqtdpj9Q8eEG5t4U5MECwt"
    "Ea2uIiwLHQQoz0M2m+ggaAu0LIxCgfzp021/gyLQq356epo4jmk0GulqmdjIzAyzv/uExa++"
    "ovXoEWa5TLCyQnjvHvHmZuocQMcxcmeHeGOjP0BvGoQQlEolhBDcunULy7LI5XLpOpCkoXbx"
    "Imc//ph/LS/jRxH5M2fSwsMw9g0dRf1TkE1D8ul5HgsLC2ityefzWJaVPkvM930OvfgiT334"
    "IXfefJPJsTGKZ87Q+vpris8+i3AcMAxEB0D5PnoQwKC/YtKgJPeDIMDN5RAo4lgSxxGl55/j"
    "+Ae/YfFnP2cqDKk88wxSSm43GpEMQ7vH1cOBAP2KMQtimiZLS8vU63Wq1WonFe09sDw7y73X"
    "foT4/R/8J6IoV5qYQGkdXobzgA+0kjFwO+t1mrRoSTOilMJreezu7hDHUXuTspPnLsHkKdbn"
    "5n6xvL7ubS0tJc3CLrDXgQiAvaEA2Q0o6QscxyEMQ4SAYqFAqVRKu6a0U87nME2T4uXLjf/U"
    "aj/57/a2Rxxr4BGwA2wB21rrqG8KsgCJciEEDx9uo9DUJ+rU6xNUq1Vc1yWWcdp4CwPy+RyG"
    "EFy6dOnBP0+cuP3NxYsX3CD4IbCmew4iQ4vQMAzy+Txr62v4LY96vc7JkycpV8q4josAoihM"
    "3gI0SmlkHOMHPtVq1Z+fnw/x/X8AN1/v4ysDoLuUl8tl1tZW+fb+BvX6BOO1cQqFArbtIAxB"
    "FEfEMto3odIaKSWtlg/tPB98MoJ2jZimyaFDh2g2d1n59zK142M8MTVBzs1h2TZaaaIoJIqy"
    "HV/39FprpJL4rRZASDs5BwMAjIwc5v7qt5TLJZ76/pM4roNhWsRSEivVdtpZfLKdQNfsWqOU"
    "ouWnAEMPnynA+sYqSseMjlY7RQdxFCHjuO3woAbwsX+UUgTt9T85nA4HsG377Y9++9G1frvg"
    "Qc6TZqUbQmPb9jscEH4A0ed43tvsfzfp3aYzY6j9D4bLjedjXIWXAAAAAElFTkSuQmCC")
index.append('tango/actions/system-log-out')
catalog['tango/actions/system-log-out'] = tango_actions_system_log_out

#----------------------------------------------------------------------
documents_table = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAACF0RVh0U291cmNlAGh0dHA6Ly9q"
    "aW1tYWMubXVzaWNoYWxsLmN6aWbjXgAAAEl0RVh0Q29weXJpZ2h0AFB1YmxpYyBEb21haW4g"
    "aHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9tYWluL1nD/soA"
    "AAKDSURBVFiFxZdNbtswEIW/oSRHkl0UqV1vg2yCbHKHHiF36FFyjh4guxyh0AmCLHyMLlrY"
    "CiSR7CIWoR/qx06ADCCIMxL5Ht+MxrRYa/lMU5+KDoTdwOPj46/r6+v7MAyNiABgrcUY07vq"
    "ePdej7XWzq+qSj0/Pz89PDz8HCVwdXV1f3Nz860oCmoC9b0m44v7rJneKIowxtwD4wSUUqYo"
    "Cl5eXtjtdqRp6p6JCHmeIyIkSQLA6+srQM+P49j5t7e33N3dEQSB6eL1CNQ7TJKE7XZLmqat"
    "HR8OB0TExQ+HA4Aj6vOba8wmUJYl+/3eySgiLQXqeJ7nbt6Qr7U+jUATsLn7+lqv12w2G0SE"
    "/X4PwGq1AnD+crl0fv3sLALdMbzJe3l5iYgQRVGLQBiGPX+xWJyegiHwrjLN+Jz7JAGtdQ9s"
    "yJ8L3OwnkwR8KWj6vtqYQ+CsIvSBd8mdQmCWAsa0e8V7cz7VLUeL0Ad+KvC7FWjaWIF9aA0M"
    "FdtUXUyR9G1usAiHbIrch30FY4vMHXdj766Bro31Bl/h+qx3JBsiMNaUfDGl1OCXNEqgK9PY"
    "ZN97Y2nwreP9LWgeu6YA54CPmTcFc8DnPp9ScDIF54DPTRuc0Qem7NT5LQVE5EJrPfpnZQ6A"
    "tda91xwbY5SItM5nTgERuQC+a62VtZbNZvP2wvGIVcuqtWa1WrlF4zhu/dDUx/EaPI5jF7PW"
    "KmArIspa+7dFAIiBpCxLFUVR6+A5t9M14z7FqqpSQHrE6hEogSLLst/W2h9BEHjlnVtc3Tla"
    "a8myLAMKoHLPOr3/C/AVWAIBniI90wyggRz4B/yxR2DxdT5gcbz8MpxulredF9baVq//DyIr"
    "U/T7KcauAAAAAElFTkSuQmCC")
index.append('documents/table')
catalog['documents/table'] = documents_table

#----------------------------------------------------------------------
actions_python_run_drive = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAAEl0RVh0Q29weXJpZ2h0AFB1Ymxp"
    "YyBEb21haW4gaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9t"
    "YWluL1nD/soAAAbzSURBVFiFxZd7bBTXFca/c2f2Ze/6Obs2NphXDYl5g7ARj4JjQQARW4li"
    "0yoFlTZ9pI+0FWpF1aZRFZVKqUpUCZqmVdNIJKRNmqStiCglPGpKDQaiGOFQbJKGRwy28WNt"
    "7+zszr339A/PGoNToGmhRzqax71zz+9859ydWWJm3NSqycRBljef9PFN3GoCR63XZL1V838D"
    "AKFcEO3TDdGfY2Nx9t0HYBBKS4gKCx/VjjqDhtjSuwsAAIEgMGOuT0yvKNWm0ajro9uwaXLw"
    "rgEwGYCS4GhMUOUyIiv6NZ0YakWDVXlXAMgQgEwDbX8HnH5g/mIfVcyepA2zSa+3tqKB/HcU"
    "AGQAhglWLvj8O+D3moGSMkHL7hdUEPs2w2pBQ2zunQMQAhAGwBj2+BXwqX1gJw5etNLEzAXT"
    "tBAndEP0B6gm8w4AGMMqEIadca0k55qAidME3VdroMB6gqOFb6OhsOJ/C+CVAPCCXxsAus+D"
    "T/wJnLZB1Q+ZmFVVoYXZouut7+CHdMv1b78EZFwfXAO/GFwK7megMwE07gUf+yswYY5Bn1xv"
    "Ii/6I91qNePhWPl/D0BeD4wKjgHGh+Vr8WPrC3DhjV06Cz7wMuCmQNWPmJheNVcbfFqvjz0O"
    "Ivr4AGIUgAZUXOAdWYKUIhwJLcBTRV+Fzb7hcWcIfOR18KlDoBmLDarZ6Eckf5uqL/wbPj1u"
    "0pjcbvU25IboGZ6/+B6KlaLv6Jt4MfAwrpRWIREswFBKof1SPwxBqDQuYPPF7bAoce3hcB5o"
    "US1glYJbDkrVekxqxd8IvNH9y/9IASIDTb1hbJu8FZ1zHoKdHYUjGWlXw28aSDgSg5FSnDSm"
    "jjyjNaDi/Zzes5PTxw+ymrPa0Cs/H0j783fE11hv9VYXjr9tgD/3FWG3uRzZZeUI+U3kBE3E"
    "nCsY508hFDAwLzKEhjPbUZM+xek02HHAjgOddJgdR3PybKt2Oy+zLpoKNWUBJZNY7ih8DgDG"
    "/Gh8ou6Z1QWFkdrcLL+80Nnz6m5Y/oP5NSgeVwzBEs6JPZh/cT+quY2fnP00TUMSj7Tv0OXq"
    "CpKawRrQGqw1oEEwK6oQWLaOZH8vDe7cLuXlS21KYtOU5p7jwA09UPetF5+YP2vyl/JyQqVp"
    "V6OjK57obDvrv2fhPB8rCevQr7Ep/iZrDdbM+G70y+Lxyy8pSw9C83BgDwCUF0PW6k+RKJ5A"
    "9uG9aqhpv1IuPzVIPT9ZcILdkfJmAGq++OyamFXwwPsdPSfD2eGqytllDzCMYigF1d+BOcnz"
    "vO74T3kkOwaSbLJfSXjXXtYGQotqKLRstXAvfoC+P+5Sbk93s9L06KxTV/9xo+IjJUjYKHTb"
    "9uzY3LD2GZ/P5zv6fpcrAzE4UkG7JmLlFo5EHiN5/hzmt+xTzABrCUcDmpm1BoySSZRT9xlh"
    "5ORT7+7X5cDRw45WvGXe2b7nhrX5iAbPKDB+7dPjn//m3LeGUDC9vWMItpPGgGviajyFolwT"
    "xTkmBoaSqFtYjM4tG+SU+BUNTaw1AF8AkZW1IrzkPmGfbqHu3+9SbnxgL5i/svBcz8WbNfiI"
    "AlWhY5g8+UHLMP1oevcqelMCiaQNOyXR1WfjUsSPmcUCKemgc2mdCL/yrDKZODxtBhWv32iQ"
    "4aOO538lB94+GdeMry853/PKzQKPAVixYsX3w+FwgdYan71/Kn72RisudCXhSo2CSAAlYYnl"
    "MyxIKVF070yK+3Ixcd2DRmHVEtHf3MQ9r/5OpezEbxWpzTWXBnpuJ/h1JWhsbLxQWlo6IZVK"
    "gZnR1ZvAy4cv44MeiYpiA/VLYjCEgGmaCAQCaDuwX1fmhPnDnS/IodPvdqQUPbaut/cvfMs/"
    "GtebAIANGzYsLisry2NmZGVlQQiB/Igfa+bm4d4iA/VLxyEUDCInJwe5ubkwDAOhaJTObPme"
    "23my9bldSbdqXW/vIQAmERlEJEb5iP3bEtTW1m5l5ggRQSmFrKwsZGdnIz8/H/MqJo5MllLC"
    "dV2Ypomisol6RyTy5G+63vsDgGwAfgCu5xrDL2/luQagiShzHxmlTABQSlkDAwPwBqC1BjOP"
    "nGd89LVt29wcDPoBTAUgvSDKO0977txwTGUgiUgzM5teZrq7uxvt7e0IBAIIhULw+/0QQkBr"
    "PaKKbdsIBoNIJBJQSrGUMhdA1FtYfkTWGTUyUDaAOIB+AAkAbkYBMDPKysrgui6UUhBCjFEj"
    "4xmlRmWtvOApL9vkKLe9exlINQpsuASNjY2vrVq1apzruqyUIq01K6WglCKVsMNpsHSHM2av"
    "dioej9t9fX0HAPzTy8YeBZJRIPMdrTMBb+yBkW1IRBEAQQx/92bMAJAHIDCqjto7DnlZZRbP"
    "bL8x2/BmW/Nf7rKqxJgppxIAAAAASUVORK5CYII=")
index.append('actions/python-run-drive')
catalog['actions/python-run-drive'] = actions_python_run_drive

#----------------------------------------------------------------------
tango_status_image_missing = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAA+FJ"
    "REFUWIXll81rFEkYxn9V1Z3pmQw7GWX3HzCJIP4B3hS8ySAiTCYBISGIYjAHb3tJ2IsH2UBu"
    "QUQhh7BENjlHz0EkIjnkICHkIjlpCOqMk8x0err2kKne/po4iXrygaK/3urneZ96q7oafnUI"
    "gLGxMSebzc5prcue5+V/JqFlWV+VUv/W6/WJ+fn5hgWQz+f/7u/vHxkeHnYKhQJSyp9CrrWm"
    "VqvlFxcXR7a2turApAXged5YpVJxfN9ne3sb3/cTnYUQqcfjnqUdi8UilUrFmZ6eHgMmZVtA"
    "vq+vj729vQS5ECLS4i88rqWJqFarFAoFzFBbhkhKGSE/TYbdxGitAbCsI+pAgMHm5maqiONg"
    "akYIgZSyoyNSSgYGBtBapwswhIODg10RnxS7u7sIIdBaY9t2ZwEnRVo/Y3UYSqkgVikFQGK+"
    "HSvi9Wv00hLSdZFSIqVEKXV0/vkzraEh9MJC9H5oSGzbDhxwHCcpwATF7wkh4NUrWhMT+A8f"
    "4t27h9jfD0jEhw+4V66gt7ZozcwgISAPizHjHkZCgLHGFE2QxZs3/9u7vo539y6iVkNozeH4"
    "ePDMunULaVkJF6SUgQNhJGrABIUrWwiBmpxEf/xI68ULAPyNDRpDQ4hMBn9nBwB16RLZqanI"
    "+JtzU/nfFBDYGp9G+TzZ2VncixdxZ2aOXrqzQ7jUep88QUh5IgGJIrRtO2JbpCmFc+cOudnZ"
    "eDd6KhVkW3zcetOMgLCI1CKMLx7hatbv3rH/4EFCgPv8OdVr1/DX1zsmEC/wVAFmrsankBCC"
    "w2fPqN24EcRnbt4ke/t2cO2/f8+Xcpn9qSmk1h0dCMMKkxsH4sRSSj6dOxfpWJibI1MqIYTA"
    "uXqVL/fv4+/tAXCwsEBudBR1/jxa68j6/80aMA6EyVsbG5GY39++JXv9epBZ9vJl/lhdJVsq"
    "AdA7Pk7PhQsdHZBS0mg0og4YF+I1IITAHhzEGRlBV6v0PX6c/qE5c4azT5+C66LbY22y11rj"
    "+z62beO6bvoQGAFmtYoQ9Pby26NHEVfSvv0AOE7E9sDqtgNdCTCdu9mAGDFhxDM397oaAuOA"
    "WQkNQfwIoS9aB0dkaFHSWifdigsAIorD16fZ/RwXG8yMuAPfs93qVpQQgmazmS7gezPrJjYM"
    "CaCUqh8cHJDL5VILrZMzp4nNZDI0m00sy9oHclY74J/l5eXRcrncUywWEyrTkJZNN3Bdl6Wl"
    "Jffw8HAZOCr51dXVPz3PK6ytrZVarVbuVG/uEpZlHTQajZcrKyt/AfVwGjbQB/S2z9UP5vY4"
    "+hdtAp+Ar4Du5OOPJjfwIbKH4T9/92V3KArmHQAAAABJRU5ErkJggg==")
index.append('tango/status/image-missing')
catalog['tango/status/image-missing'] = tango_status_image_missing

#----------------------------------------------------------------------
documents_pydoc_startup = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAACF0RVh0U291cmNlAGh0dHA6Ly9q"
    "aW1tYWMubXVzaWNoYWxsLmN6aWbjXgAAAEl0RVh0Q29weXJpZ2h0AFB1YmxpYyBEb21haW4g"
    "aHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9tYWluL1nD/soA"
    "AAZkSURBVFiFjZfLj1xHFcZ/dR/d0zPTk/G47bFjGxI7BmLLMMGECAWkCIFQIhIHRXJ4LACB"
    "kGCH5AiBxAblD7AQWbJATrwAFs7GI4xkCeMFZGNF2CGJZ2w8Ho/tZMbd0933VXWrDot+pF/T"
    "45JuV986p+p85zunTtVVIsLDNqWUGifeZrxjSKTHqBoHYMCg2qIfJxsE5QALuA6IIQBnz579"
    "5YEDB04FQSCe5yEiiAjOOZxzKs/z7pi1tvu/M97W68hVR8cYo65cufLH06dP/w7IRcQBBINe"
    "VyqVXy0sLMynaYqIEAQBvSBFhA4xoyKyFaNhGGKM+QXweu94HwCllLpw4YLTWhNFEdZaJiYm"
    "sNb2GdwKwFYp0gEVhqHQCotSSikRkUEG1KABpRRaa7Is2xZAoVCgVCqNBNGj2zcp6FFQgHLO"
    "dUGMerZjYPxGaXnfC2KIgU6MexczxhBFEQCV997DazT6AYQhxRMnxhnenoGO0DnXN2HQq42j"
    "R9nY2MPSUhmAqSnh+eez7TxHKdXJhS0BKHoY6DVeKBQol8vd95mZmMcfj7t69frWCTgzMzMo"
    "e3gGBoH0LrRdPozS62FgfA50iozneQBorWk2m0MLBkHA3NWrSK2GUorw+HH8gweHQPSyOo4B"
    "BWCtVUopwjDsTpy7O8esnmV152ofiDzP+fjJJ/uMTW5sUKlURrLR3mHDAHpqvhpV9eznWoVI"
    "1lplNfCDHo/69aO4QfPWJiIgCOKkC/rTjx0oL144f/nm0vVLKyvv/waoDoUgz/PuhN64r91d"
    "ZW52J82oidZ6pIfdRZSHUm1X/U/GZ2d3+J7nHTn42KEjly4X9wEvbZmE/QsqxFmiOObMW38l"
    "1W1GpO2/SMuaa71L+xdRn5wNShBRlKdLvHLiW+zft//4yZMn/S234eDj+T7W5tQaMfsPHCaY"
    "mEKc4ERwTlC+jwsCDlVSbn2kiOIcsTnOCU5AxJFrzf9WPmB9fR0ntjA1NRV6g85aa4f2k/ex"
    "h0rbiac1mcmxTjFR8nnmmMfXnvJgz2EK09O8+k1h36MBzfIe1OQUQRjixMcSkItPmsRkxpCm"
    "aWvtUSHo0NbLQIdJbQyNRpNcR/z85YTnFlIaqaOZO0p+DXEp8+U6cWbYSISfvRiRxg9YWbnD"
    "+x8u8+H1ZbTORgLoC8H6+npX4HY5bKGVnCbT1Ot1Du+LCbwMk2f882aZKE5wWQOjM27fSag1"
    "IpbubrK5sczh3ddZXV2j+qCKMRqdarIsERhTCefm5rqFCMC1t5MxmnyzTiks85d/eLyzspPm"
    "xCPo2ia3GjV++vsCt7MycbzBDnufcrHKi1/JePN8Aas1Yi1aJ2RZaycNAehcPnzfxznXvQ9o"
    "Y3BO2h5s8ufFAP+JLyFeAVO/R7y2TM3PObjzHt85FvPVo5rZUobYDHEp1kyTG41zljRLMWYY"
    "wMj7QKflRmN066lHGVkORf8GuRdybPYG334h59kvFMnShP8ux5y/DPfqIcaE3L6VoZMUazTi"
    "ctIsw+Z6fAh62+TNSaSqSIoxcRSxdqdKcbKOrN4GFL99/VO4POHM21V2zTqe/bzl1NlDRI98"
    "FmxO9O55lNW43OCsJUsyrDOjQzAKQPXRKtFmszXR5mRpjPJ8VLus//i1D9qzFT94IeTrCz4v"
    "HbnBm9dmyW5dxSYNQGHzHOdycmtwLn94AMViEREhSWIQh801uU4Hotfq/nQuQWdFXvuhUL1/"
    "gbfeybpyZ3OknWO2ndWjcmDk1drkhjhJcOKwRpN7fnfhwYP2zNspF//V5NSPyqzeFS7+OwUU"
    "zlrE5UDr+2EUA11BL4hisYhzjiRJmCxNkMSbZGljCGRvq9fgJ7+G3TsDNqstugVhz/wuxIG1"
    "wwwIYK21yvf97n3A8zw8z8MYQ5LEfPmZBQ5/5gk8r50BysPzxt8HxVlMbgiCkOnpaTKdIM7K"
    "/fv3+74LHGCuXbt2/ty5cy+HYdhitb0Vl2/eKO3dMx9Wqw+Y3TE51mBvO/gNuH4xZdrNUCpN"
    "kSQRQRBQb9TXFhcXteqp+x4QAsVKpTLlnAtEpOva3v17n/r+9777xq7du+Y95QXO2dZJN6oX"
    "wdl27yzOOYIgxFNQrzekVqveXlq68cbfFv/+h14AneuS134GeZ0A5p9++ovPFSZLFREZPMi2"
    "a6KUErG2+e6V/1yKomhNRD76P5kd6cnq3tuiAAAAAElFTkSuQmCC")
index.append('documents/pydoc-startup')
catalog['documents/pydoc-startup'] = documents_pydoc_startup

#----------------------------------------------------------------------
tango_actions_media_seek_backward = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAA+lJ"
    "REFUWIXtlF1MW1UAx//3nHt7b1ukFEpbbTEpbDiUj0IIMBBx2eKWGB8w4UkhPGhMfFAw82FG"
    "XYxPPkLnky884xITkyUEx3QhwpAhWDqwoVJKb9tZWuhlCoXeDx8GyIIFJosv9pfcl5vfOed3"
    "7scBcuTI8X+H/stxLAArAAsABkD6CftZYQCY88x5lW0vt371ysXzGoDSk/jkMRbXA3i2vr72"
    "9baWlptdXV2dO/ezPcV9fut33d3dbx7hZ4UCsLlcrpcuXrpw64MPe/6UpJSmaZr26muXtgGU"
    "ncRnj1jcxPO8vfFsw1vFlqJ3r1z5iHfX1NH01iZUVX0SftYAAUCx213V+ozD8UV7e7ulq7Nb"
    "UDUF639IADToBcNJ/KwBBECRw+Eoq6p+/hOXy3Xu6tXP9EVFFmxtpaEoMgghYMDsH8M4HA73"
    "Y/hZAziLxeKqqal6o8BsutzT08s3n32RZuQMNtObADQwzO43qwEAKEuZc+fbOosKzZffe7+X"
    "b25qoZvpDaylVqFBBTQGmqYBDJBnfAq8TgdBELR0On0wwGQy5TU3N3QKeuHj/v4vYbPakVhb"
    "QSaTASUEDEPAMAwYBsDOjgQdz+qLhU/7+q499FfjyMjy3z551DcYDQzP89gfsPdLVFZWKsnk"
    "2uLTdltq/M5Yg81mI2WuMkIIhaqqYFl25+LAshx0nA43R4blbUX+fOLOeIP1GP7w8JAiilGP"
    "JEmpAwGxWEyNx+OSTifMbm9tfitGwk6fz+t0V9dyBSYzNGighICjDyemhOL72yPKxNjdt2V5"
    "62sxEnH67nmd7mp3Vv+H27fU4GLoWjKZPBiw+3JjsdhGefmZRHAxNMKx3Ix3drpRlmW+/NRz"
    "LKXs3sSEEPw4NqqK4Wh/JBILSKn1EUqYGd89b6MsZ/jT/+SPj6rRyH2PKIpZAwAAgUBAEUXx"
    "gdNZEkqsxK5n5K3M9C8/1zmdJaSwsJAoqgJKKH6anFDDy2L/1NRUUhTFBwaDMbSa/P26rCoZ"
    "7+x0ndNRQsz7/MnJCXU5JPYHg0Hp0IBd/H7/dlVV7fpSMDzDUnIjGhNLI5Gwrfz0GY7jOExP"
    "T6pLS2HPwsKCBADhcHi7trZ+PbQUnqFEdyN2f7k0Eo3Yyk/t+DN31V/nFzzHDgCAubk5LRAI"
    "bFRUvLCyHBKHDHre7w/MN6mKyq4k43wsGu/z+Xypg37FSigkDukFnX/ht/kmRVbYRCLOx+PJ"
    "R/yjjuI9BgYG0gBi+fn531it1nGO9/YajcZ39Hq9cpRfkJDGWZbrNeYd9LMfUYcwODhIR0dH"
    "CxVFESilksfjWT/M7+jooHa7/dh+jhw5/lP+Akl39GFkFh9JAAAAAElFTkSuQmCC")
index.append('tango/actions/media-seek-backward')
catalog['tango/actions/media-seek-backward'] = tango_actions_media_seek_backward

#----------------------------------------------------------------------
tango_actions_view_fullscreen = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAABl0"
    "RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoAAAR6SURBVFiFxZdbiFR1HMc//3PO"
    "3M+cVWdnZ5w1ofISuiqiS09GkWQiaT0E9lAPrRChmbSUmAVbIHgpSli0oB4i6qHLGrpQBBKU"
    "PSrmsrvmlluwl7kY7dxvZ+bfgzvr7MyZcSS3vvBjhvn/znw/5/v/n/85R0gp+T+lVb68+/7x"
    "Z5Gi3zSLxoKbarYEQu7rPfDap3MASNHfs+cFw+NyL7Q/6WzG+PijD/uBWwCmWTQ8bg8bd59s"
    "eKDLrnGsdztdKwINe0Z+i3Dg2CCZXLFhz/BAL5WklTq6TMGySmaZvr1bm5oDrFkR4J1Xd6Bq"
    "KkWzbFnVqgNopCMvP0Z317KWetevCnL8wLaWelsG+PbCNQoFEwG3rULB5Lufr+Fy2v49gAAC"
    "Pp3YXyk+G7yMWRNhrUyzzMD5YRLpPJ0dBh63vXUAUTsoIOj3EmzXCbZ7SeWKXLj8J2UJQoi6"
    "ksCVsTDlkiTkNwj5vXT6DbweR91JWQJU5LRrnOjdzkOb7iWwRGdpu5egTyfk01GEYDI8A7I+"
    "+mymgNtpozNg0NlhEOq4CfFw932cOrzTckq02h+cdo33Du6ge+0yHlx3D5+cvUTJLOH3eQn4"
    "PAR8OobuRNTGBegeB51+A2U2EUUIlnUYPPnoWpx2jdOHd/LikbPNAU4eeoLNazoB8Ljs9Dy1"
    "mZ8ujmO3aQTadQI+nUVel1VwACwyXCiKQFEEi71OulYGsWkqAOtWLeX0G7uaA3TPmlcn8kj3"
    "/UxG4yzyumjzOhuaV9SmO7GpCg6HDVWZH9X6lcHmAFbSNIXlSxdbxt5Iblfz1d8QQDRwuRPz"
    "O9E8gMpqXmhVe9Qn8B8AVGs+gBALl3Wtz6zqNiKrvV1KSS5fbOk+MLcpZQuUy9JyrFp1AKPX"
    "I/OaS2aZK9fCTEzPkErnWzJPpnNMROL88usUplmaNzY0Fm4O0PPWGUbGoyAEBbPMV+eHGfk9"
    "wkQsyWQsQTydvzVVFjWTyjMZTTIRTTB6PcYX3w+RK5ZACK6Mhdnz9pl5fnWLMJUp0NM3wKlD"
    "uzj34yh/J3KE/F6kBKQECaoQdTcYgGQ6z1Q0zlQswfSNJNOxFFOxBFf/uMGOLavZf3yQbM2T"
    "Ut1lWIF47s0vadMdhPwGZSkpS4mUEq/Hgcdlt7xadLedbK7IVCw5WwmmZz+/+WGkzscygWrF"
    "U3mkTNw8cSkJ+nQ2rg7Vba8VKUKwcXWI0fEoE9H4nHkqU2jocdsHkkQ6z0Q0jttp45nHN+Cw"
    "a5bPApWy2VR2b9tAm+5kMtrcvCUAuDklT2/twu2wtXQVOO0aO7c8QDrb3LxlAIB9x84xfD3S"
    "Uu+lq1O8dGKwpd6WAVKZAs/3DTA6Hm3aNzQWZu/Rs5hmCZumWFa15hahqmqJbDZrjHz9SlMD"
    "VVHQtMbcm9Yu5+Ln+5v+RzabRVW15ByAEEI5dPjg66c+6D9aLpf0pkffBSmKkg6Hw31CCLeo"
    "vB0LIXyAD1gCeIH4XfZVgcVABpgBIkBEVL+eCyFUwAE4gexdBtAAG5AD8lLKEsA/MrexdRcV"
    "2gIAAAAASUVORK5CYII=")
index.append('tango/actions/view-fullscreen')
catalog['tango/actions/view-fullscreen'] = tango_actions_view_fullscreen

#----------------------------------------------------------------------
documents_pydoc = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAACF0RVh0U291cmNlAGh0dHA6Ly9q"
    "aW1tYWMubXVzaWNoYWxsLmN6aWbjXgAAAEl0RVh0Q29weXJpZ2h0AFB1YmxpYyBEb21haW4g"
    "aHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9tYWluL1nD/soA"
    "AAT4SURBVFiFlZffaxxVFMc/Z2ZnZzfZTZpkWzUm0laaNi0tgQoiiPZNi2AFffPFZwVBEHwX"
    "/4C++eRrUQRpofpQUYyPlpqK3Whrf6QxraZJTHY3uzu/7r0+JLPMzv5KDgwzc8+Ze773e37c"
    "O2KMYa8iItJPPWA8dmRMwqn0A5ByKD3u/XRpUBpQgI5BdAC4dOnSR9PT0x9nMhljWRbGGIwx"
    "aK3RWksURa0xpVTrOR7ftYv1EtuEYSgLCwtfXLx48VMgMsZogEx61aVS6ZO5ubmnPM/DGEMm"
    "kyEJ0hhDTEy3iPRi1HEcwjB8H/gsOd4GQETk2rVrOggC6vU6SilyuRxKqTaHvQD0SpEYlOM4"
    "hp2wiIiIMcakGZC0AxEhCAJ83x8IIJvNks/nu4JI2LZ9lEkYCCBa6xaIbtcgBvoXys7qkyA6"
    "GIhjnJwsDEPq9ToApcVFrFqtHYDj4F640M/xYAZipda67YP0qjZOnWJj42nu3i0CMDxsOH/e"
    "H7RyRCTOhZ4AhAQDSefZbJZisdh6HxlpcORIo2VXrfZOwJGRkbRu7wykgSQnGpQP3ewSDPTP"
    "gbjJWJYFQBAEbG9vd0yYyWQYv3ULs7WFiOCcPYt99GgHiCSr/RgQAKWUiAiO47Q+HP9nnAPB"
    "AVYmVtpARFHE2uxsm7OhjQ1KpVJXNnYrrBNAoudLt66nTihEhCmmqNfraK37NqFKpdKmc12X"
    "bDabXGjvEERR1JqwW9wH5UI3iXWDqgASSZieIL4ajQZBELSN95PR0VHy+fz+y7BXF4xDlHY+"
    "OTmZpLlNUknYJh0MKKU6LK01C/uJjYgwcXwC13W7lukg2VMZxnt528TSuzN22yNSDls2+wrB"
    "+vo6ExMTAOiDGnNoZ3zj3w3SiQo7+/3U1BRaa5rNJlEU4XkelmWRy+XI5/O9yzDNAMD4+Hir"
    "ESVlcnKy7w5ZrVb58sr3XF/aphkJlg45cSjDu2+e21sI4sOHbduteg+CAM/zejqOn5vNJqur"
    "q/z45xZP1moUZ84QBj7zS4+YW1yk0WgIYPcNQfo8MEhim0ajwfz8z9y8t8b6aoNIHGpLd8gc"
    "fAZfCSt3rnLvb88BxoDNngx06wNDD4YY+X0EcYVvh6FSsRARxsbg9OllfN9neXmZrxeqyLNz"
    "FE5GhIFPFPiEQYCKAs69UOeNl1VucSH30vx1b3lfADYnN6kMVxARTnQcVoQwDLn/YImwcBBb"
    "KaIwwG/UCT0PFQacKZSZOTxEMW9kbjb/yvx175t9AXBdt7Wvi0grOeN3z/MoFAqoSGHCgBn/"
    "B95+cZV8FjAhJ5/PUXQtCBsd/wHdcqDn0TqWdGfLZrPMHDuGdWOBMHB57eQqr587DKoBUX3n"
    "Hm5Tq1bxg/BXwO/FADEDSRCu65LL5fq2aNd1eXX6Jr8tL1PI2xBWuH3nIX/cfoRSIcOjs9x/"
    "POZ//lX9Cjt/Rx0ADKCUUmLbdus8YFkWlmV1Lbvkc6FQ4IP33qFWq/Hwxi8QVjn+nEtls8hW"
    "pYoz9SHBf7c8uFpn5xetA4AGwnK5/N3ly5ffchyn5aSXdNP5vi8rd7Ou+A8yWbspjWbEX49L"
    "Ktou++Vy+add+lsAJNGvLcAB3FKpNKy1zhhjOjx0G0vpLaVUXil1QGtdsixr1bbtmuM425ub"
    "mxXAA8L43zAJIG6R1u41uAv1lngeG4h2V2x275rEL/r/t8+a4OmDETIAAAAASUVORK5CYII=")
index.append('documents/pydoc')
catalog['documents/pydoc'] = documents_pydoc

#----------------------------------------------------------------------
documents_pydoc_openrun = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAADt0RVh0RGVzY3JpcHRpb24AQWN0"
    "aXZlIHN0YXRlIC0gd2hlbiBmaWxlcyBhcmUgYmVpbmcgZHJhZ2dlZCB0by7UZ1hFAAAAGHRF"
    "WHRDcmVhdGlvbiBUaW1lADIwMDUtMDEtMzG9E+8ZAAAAIXRFWHRTb3VyY2UAaHR0cDovL2pp"
    "bW1hYy5tdXNpY2hhbGwuY3ppZuNeAAAASXRFWHRDb3B5cmlnaHQAUHVibGljIERvbWFpbiBo"
    "dHRwOi8vY3JlYXRpdmVjb21tb25zLm9yZy9saWNlbnNlcy9wdWJsaWNkb21haW4vWcP+ygAA"
    "BqBJREFUWIW9l1tsXFcVhr99LjMee8ZxEl8SOfeq2EMaCo3axi2JUCgvpVwEwQkoPPCCEC8R"
    "b31AKkXiInhAhQcUlBbREpUmLRFVqKIiqNQgqhDTNEnbxMSJnfqSZGyP7Zk5c+Zc9l482DO+"
    "jN2UFrKkPXvPWues/z//3mvvc5SIsMh612wyYn/LUuGvODaT5/9sVp3HWI0ofmBUcszsb32K"
    "r6/deGcJVC3bnWTr3d81dmrQ9LYdZd/a7XeWQCKF6tzsqJ49Nt079ptM5qL0tp9if8fDd4aA"
    "40B+GK6fR7VkbLVrr+KTD3zONK96Xfe2ndVfa3sMpdRHJaDqFuG+1m5jqUs88BDKn0LGLqNR"
    "DDmbWL9xA01t62FqXLjab2T8xpAgT9rjk8/zmsQfmsCBAwfuchynDeAxPbS5V/f/QfXsQbw8"
    "jLzD96MvcbZ9L+0zV3jGfQ53YxbVvg2K08jVSzHDg3kUP7YarCM8e9P7rwgcPHiwq7u7+3RX"
    "V1cKoLlw03rk1JON6tN7kdIkz461cop7mdAp8jRw/L6n6bw4SkIloXM7akMWyj4MXIxkqL+C"
    "0b+w4uCX/LEw+UEIOCLSnM1mU7Ztp6enp3F8fzZiOQRi8/vMl0nHOb7afIautiJbP5tlemyC"
    "RH8JcmeQt9+CLTtQ3btc1fWgy8CFx83g24/L/tYjdqx/xktT19+XAHDD87wgnU6noygijuem"
    "0nZwbJvOwmUOPXSOe3evIy5X8CcGcXI+VGdcB3C5D7nyFmzejvrY/QmV7YFr579tBv71Helt"
    "O25j/4hjNy8uS6CpqelWoVCIOzo6KBaLuKFbU8C2LX4d/waPLVRyFS78/QLb+yLS4TKLX8dw"
    "7TwyeAE2fRyV7XHI9sDQxX3m8hu90tv2V1vUDzmeO73wNuvw4cOR53mVRCKxKJ9YDlg2DTom"
    "/epVKiffJXtVlgdfdKPA9XfQrxwhPn0C07LeMl/8ntI9vXu9xo7XSp9v7Ss+2vaFagk7AKVS"
    "qWyMIQxDoiiqKQA2FIWkCMl3K8tiGQOCmu0FtK76BblyRayZwDif+YpSd+1UklqjyqdeuE9P"
    "TT41s6dNb4BXHIBCoeA5jrMoubJdiKw6ECMgpgoksz5mfbWYsnC23UPiU7uVtW6zFfRf0OWT"
    "LxGOvXdOND/dtiX/J46JrilQLpcLqVQK13WxbJswBFs7aN8mLCvECEYEkSUkRNWAEYUkGkjc"
    "8yCpnbtRyRSlN/8hlReei+OZqZctrX5+9/mJM3WLcK4fqcofRZqyDwnf5o1KJyfWHaK6WQqz"
    "QLUpYFYF5bhYmRbszCpEa/TZaeLiBCVnh57Y/khfZLtrgJ9w6PiSKZTnHQCt9WChUMD3fRw/"
    "oORBxricDDfx8DcfBbXykXEbc4CeereggMMv9lUcgCAIBnzfF0CFUYzvQ9I4FJ0MWhQjE8vv"
    "rkuPEan9gMwNZEGwOo5jobVJSRiblx0AY8yY53l+MplsNAa8MjRpm2Q6gxfMnzELAWXJQGqQ"
    "C3314JVQ05J2uTI8no+0/KVK4MbMzIzvum5jHM+ugUndQLq5kUpoEFmarP7p6hWYD1aJB5Eh"
    "0oZMg8O14anpvsP7rzoAtm3fLBaLYSaTwfcDPB/yYQNN7S1UohgjsjLAov+yvFICQWyItQFA"
    "G8GrhKMw90Jy9OjRqVKpFCuliKKYclkY8FwSjSmiePYJqqVXG8tsBQjVEl1wHdU4xNpQDuMa"
    "eMKxyOU9iY38uUYAIAiCiuu6GCOUK9A3kKchmVgAuBRMlpChFjNGiI2hEmmCyCxSJJWwGRyd"
    "GI/K8Yswvw/g+76vlCIC8jt3UNmylUhTk3+p7Eaktg9UZa8SNSJ1FVI1x1bcuFWa+ufT37i2"
    "iEAUReUoiig1JJjcdT8NmUYqkZ5bgEKsZxPP7oQrZL+NKQVFLyDW+s0aoQXxnDGGKIqYMqto"
    "bllNJdTERtBmQYktsvkV+EEouY7F9dF8qVIxz9QRMMa8p7VGa824vYn2dDOlQDNfdPW4t3Et"
    "js8pOXJz6tbZzkt/qyNQLBZHcrkcozOKxm1r8SO9OPn7IKwYWlKO09NFEwbeCXniCVP1WwBK"
    "qcZcLjc5Pjkd5Zs+QUtbB1EsRLEQzvWRXrnFKzUz37QRRkZvTA69fvR3Sqna209NgeHh4XOJ"
    "9ux0vDrVOvTvfqn7XvgIJsqdMUZ0ITf421uXXp0Bakdq7cNEKdUCrAYyc8Sc5ZJ9SIuBECgC"
    "UyJSqCMwR8ICGoDk/5hABARAICJmYeA/lCkxCeqB1nIAAAAASUVORK5CYII=")
index.append('documents/pydoc-openrun')
catalog['documents/pydoc-openrun'] = documents_pydoc_openrun

#----------------------------------------------------------------------
tango_mimetypes_x_office_presentation = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABP1J"
    "REFUWIW9Vl1MFFcYPd+9M7MgUkBARbHLj1QLNtYF1hBDojUh0QeSrhlrakNfTG1iDQ+Ntk1t"
    "4ou21gd9NTEhMTbVEFuxjU1r0hC1Ji0ImoA/aBVocTUiBRbY+b23L866wgK7tXiSyczc+805"
    "5zvfTHYJT7Ft+7a3GeGEbdvzMcdQVXVMSDSc+ubU90psUeHHP9nz2fylS5fOtT4GBgbmHzr8"
    "5XEAzww4jovu7m6Ew+E5NzA0NATHcQEAzwy47o6z5858523MJRSFw3HlDgCg+I2vvj4gg1U1"
    "YIxB0zQoigJFUUBE4JyDMRY7vHUAIKLY4cGr8/bjzydONuHTvZ8TEJeAB7/fD8557H7iyRPc"
    "aGlB5PZtsOFhCAAiOxsLVq1CeX095uXkxGqJCO3t7QlFAaC6ujpmKpbGZAPp6emwLAvCddF6"
    "8CByu7qwobwcCxYvhly0CK5hwDEM/H3xIi41NUHZtAkb9u4FMQYiQnV19XOik43MaoA9Jbp8"
    "5Ahqx8awvLYW0nHgRKNwnoq7hoEcImwuLMQf587hSkYGahsbASCWwOTuPXPx6SY0wDkHESFy"
    "4QJKGxrg9PfHhC0VuJhbgagpYBsGLNOEWBRAz4+/oraxEUSEYDA4bfdJJeAZmBgcxODDh8hI"
    "S4P9+DGc8XEMbS4DW0Jo+bMOphnFPAUQTx4hs6sdkUgEWVlZU96B+OtgMJj8CDI2bsTPx44h"
    "UFeHhWVlQCSCgbdy4eQMY93YffRbpRjruo67HZ0IBopARGCMxRJI1L1Xk1QCtfv24Zfxcfx0"
    "/jzyAahv5CHcVgDDjSDSexbtv9Uj++Et1C7XEPxwD7KyskBEaGtre47PG0vKL2Fefj7qjx7F"
    "vZ070d3SgpHbnRg9+QCSAT65GHXLBrFiZwNeX70aeXl5MeJ4sURjSMqAV5SZmYk3167FqspK"
    "GIYBy7IAAKqqIj09HT6fb4rATJ/g5OsZE+js7HxuPVkBD1VVVQnrkh5BIBBIuatk1mZNwCuK"
    "T2CmTqcTraysTPhs0iOYTJBqp8msJTTgzamjo+OFOk0klghTDMQTv0in02HWBAAgOzt7RpL/"
    "E1MMHDp88KWJA5P+EaUK/Z0tcsVrK3Hnbo99+ttm7b9wsNlLEiMUCq3zftsZI1XX9ZqXZiC0"
    "PVSoaOzyssJX8dGu3SguKgWYuBR6L1SQKlfKI9B1vUZLU668usyP3t778PuL0NfXC7+/CP1/"
    "9cE23arm5uaryfLx2UueYevWLe/n5Ob8UFFegZ47PbAdRx8Z+eeWcHF8whgPrVkdwPhE5IPS"
    "suJbN7pudifDmVQCuq5zptCh4qLij/PzF6Lt6u8TVtQp7+vre1BSUkIAIIQo0dLUm8HqIMLh"
    "MO733jvQfPrMFwBkygZ0XecANAAaYyxP1Vj3mjVVPtu2cO1a5yMCf5eIhlzXZUTEAIAxJh3H"
    "WcIUOlkZqHpFCoFr1ztHCbzGdd1hIrKGh4etaDRqtba2WgBEIgOk63qabds+ItLUdHWldN0m"
    "ApVIAEQUBtFuhZQxIYSPMeaTUvqklBpjzBRCmGDIEq57GCRzpAQYcEcIdxdj2j3btk3OuWma"
    "pjE6OhptbW11phsBrV+/nhcUFGSrqjrPcRxPRDqOIxVFUaSUHAAXQsQ4pJSCcy5s2+aapjHD"
    "MEzGmMk5j6iqOmIYhl1RUeHs379fzDiCFDD5+RnnnQj/AgAr4F2TsJKrAAAAAElFTkSuQmCC")
index.append('tango/mimetypes/x-office-presentation')
catalog['tango/mimetypes/x-office-presentation'] = tango_mimetypes_x_office_presentation

#----------------------------------------------------------------------
tango_actions_edit_undo = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAABl0"
    "RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoAAAXTSURBVFiFxZZ9bFV3Gcc/zznn"
    "3t6+XZB2dRsUug6hMmSrwiKtmzjmHyWa+YckMwEGy6JzCSaaaDLHYnyZJmZGEf9xjtnRLeqm"
    "Lr5k2XQzyGiB8aahrIxSRkuBSmnv5fb2vpyX3+Mf7b1eLpeuL0t8kie/37n3d87383t+z/Oc"
    "I6rK/9Os2d8q0vW8fP/oMzJvLgDObG469KJEjfJHhfVjYX4yF4AZR2D/HllmjJxYtOLBey3b"
    "ceciPmOAznbZ4DiVx5a1fru+rvHzIYU5J9C0AQ7skScj8xr+cMf6pysrqqsEZK7awDRy4G8d"
    "UlkNv12w6L77Fzd/JaLeOwTZM1jh2/ggIKYEONguDdWO9ffFdz62pHbx+lCQOYIGl0GcD0R8"
    "SoCuX8t9dqT6labWH1SXz6+XIH0UNUnAZuLkBBGxwzYXD7wgcYRzGvB7Mby6dquemi6AlGpE"
    "XXvkG+XRpU8ta/1exAkFBNnToFlUs/kxVNUGZozAj+O7I7jJPhJX3nOH+//lq3Hf8DweuWeb"
    "Ds8IYG+7RMI27QsWrn+gofmrEQ36UX8IAMUH9SYBXDAeaq4S+ENgxhCrCrvso4hTz+jgv/1L"
    "fYcynjf6aOsmfXFaAJ3PSbUVovPWpk3Lb172QNhPHwFNki8UDQAfVQ9MEm98Lxpcv0GxPoRT"
    "fjdq30V/958z46M9B2KjtLVt12wpgHwZtj6sYwi7Rwb3B142huXUoiYDJg0mjWoG1SwaxHCT"
    "r5cUB1ATwxt/nSDVQWPz5yILFja3zJ/Pj6Z1BACde6TNCUdfXt76eEWkIip+5jCoDxg0SOCN"
    "vwmaZqIKpu5DYtfgRB+i9+0/ZTLxvntbturh9wUA6OqQlWD/Y+maxxZEP3yn7Y/vw3gD+Om3"
    "QVMARGp3gAaopkEzaDCKnzmBcU8DQf5ZdtnH8Mwa7T30XP+8CMtXbNRr2nfJTtiyWbshWNl3"
    "ZFfPxZ7fuOLcgvHO5cUn0IXuf+7ye/Y/nzp7/C9j/+nvdX1WU1bzNezImvyyIHuSSKVK9KYl"
    "N8XSfKlY64atuGWzXs76rLl89s3Xzh79Xdqp+iJ2ZPX/FqiH72UCdzy2LjF84cFLZ49/q/dQ"
    "x8X3jrWnxG7CqVg3+XhDkD5CtLa+QoQV0wYAWLdVM5/cxBeSo+d2nup8Nq3WKpzK+wELNRPR"
    "cKG3dau++qktujMeozExHPvpyc6XMr5fgV12BwAmGCFU5oglrJoRwORWde1mfdxNx7/8bmdH"
    "KpsOEaragJpxipOwbbtmWx7SHRpknxg4uS9lhRpAwqhJ4oRA4SOzAJiwli36gvG8z545+trV"
    "+OULZqISStuFcnamk8nziZF+FbsOwUJkHFVqZg0AsHabdnmqzYPvHj9/8fRbnqiWfCNt3KiB"
    "Gp5JXb3iiYTBqiAzNowI78wKQCbMEhH701sY6OvhEyOD5w8bY8LdZwiJiFPgtohYxjDme2kf"
    "DCJlJEbjWRPw12kBFAg6IhICQkA455t/SHr7z9nguuzuv0AIKCv8HwhnfaJqLEEDPNcQG0r4"
    "ls8vr9MqbEQiIpNQOZeiebETjSKJRD4bFdC7m3B+9gQHlzTV1ZZXhYLB0yPWyEjm6c88zI8B"
    "o6omp+kUiFtF4qVcKIJJJPLCudF8fRttldUhNxQxp4YGYvPj8cyBHbvZxcTHhExu1Kiqiqrm"
    "dm4XiRVfF/5WCJIzA5hnv8vapqXWI3X14VQq7kZHh83J7/yCp946Tiq3ZtIDVTU5gBsJT2cu"
    "gLl9EfaTj7KusYHVlVGy6SShcwO88c2d7Lt0CbdQODdX1aAwAqV2XSoK10Rg9Soq7vk4NXc1"
    "cfstdSz0fcZiMYb2HuTEr17hSrFowXWQP4LJHLgRxDWJWFWFXVOD03gr4ZW3UVl7M+UVFo5n"
    "8IcGSO7vJnHsFNkiQS0CCXRS+LrXcdFxvG8VFNg1lVAknBt9LRIs+T1QADMVQH5ZkXhuzEeg"
    "WHTaAFNAlRKfUJ7hA/8L5wToVGBKwGEAAAAASUVORK5CYII=")
index.append('tango/actions/edit-undo')
catalog['tango/actions/edit-undo'] = tango_actions_edit_undo

#----------------------------------------------------------------------
actions_python_run_selection = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw"
    "SFlzAAAJOgAACToB8GSSSgAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA"
    "AAAUdEVYdEF1dGhvcgBKYWt1YiBTdGVpbmVy5vv3LwAAAEl0RVh0Q29weXJpZ2h0AFB1Ymxp"
    "YyBEb21haW4gaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbGljZW5zZXMvcHVibGljZG9t"
    "YWluL1nD/soAAAXdSURBVFiFxZd/jFRXFcc/5703O/uDXWdnZ4Zlt1CgtjSrFQq1oO3WLEjE"
    "pqlJI4tJjaZaNTH++MPUmBhN1GjSmPiPRaMmxqRaCCltYpqYFhHbGoEtrYJsKysmCwss7f6a"
    "Wdhlfrx3jn+8NzNvdlcgKniTm/fm3vvu93u+55x77oiZcdU2IB6HzL/6ov+8OddaYNnMfn9n"
    "Ztv/jQDC7Y7IAR3M/oRPdbfdfAKG0Nsj0tX1uBaDtxjM3X9zCQAkm+E9GxLOur5e9dxXdGf2"
    "Rzy2pvmmETBxIfCxbM6Re/tFMtkv6dzlYQYz994UAuI64Jdh5M9QzMPGDyak732r1fUO667M"
    "DxiUphtKAHHB9bCggp35K/bPIehZ5Uj/RxxJ554wMscZzG24cQQcBxwXjLAXLmInDmDFArZl"
    "u8d7N92hjnNMB7PfZkC8G0DADVUQwm7UXXL6MNx6hyNbH3ZJZ75l2a43GOzq+98SiFwAEXh9"
    "AibOYMd+i5XnkYFHPO7a3KeOd1x3Zr7Od+Sa+1+/C8RtBFfgikFe4e05eOVF7OjLsHK9Kw/s"
    "8khlv6/DmSE+nrv9vycgUQzEwWctJKCxdedOYX/YA5USMvCox7rNG9S1k7or9xVEZMmtzYxn"
    "n3/2kRXdKz631IKOseF+p62lTRJJbPadcLBSn/cv5+k7+BSuBo0frl2PbNgKs1PY0AuBzU4d"
    "dd3Eo+wZH11E4NAfD/6q//4HPq16jcq4RJu+cJa2b36Ytsrc4sllKWTLw5DpxY4f8oPho74G"
    "9tXk8xM/ry6pucDMMNPr7qoBQeDj+0tXalUICnkr/+5pK792yIL1O1zd/tlkualzd+Gjmd9P"
    "D3TdAtCQs396axI/qEsp4iAiaEze6vXB8zw2rmkHM8wgCMJX1RBcFVMzTA07NWxNq9aLrLhN"
    "grWbpHj4wIdU+Qzw3QYCo2MXePudidrv9vZ20uk0+Xy+wToRWLlyFUFgKFAqoVICVcOq4AqK"
    "4PVtJtn/kPj5abn09FO+P35uJPB5bO3Q1GuLFPBEcaVubcJRepanWZFLRxlokcVGqjWBIwpm"
    "lEpmFA0NvYMqSCpH645PiNO9Ui6/+mJw+fDBIKjY9y7J1A83HbNaGDcQ8M0hsHq6VdTh/MVJ"
    "pqdniF/dent7WZ1pxpUwdopFzIpVq11atmyTlv4dTmVslJndTwaVqYmhQOXxu05M/n1hrDQQ"
    "SCYSLGupl/nWZBPZdJpMZ2dNATOlOeEhZqgaqlAqY1Y0c3tWS8fHPum4HZ0y/cJz/uyRV4sa"
    "2DfuPjXzs1Cbxa2BQOuyNjQ6PasWX5yYIH5vXZ5u4+5bOyLw0AVlTVrH9gdl2X1bnfmTx2Xi"
    "pz8OKoXZlzC++P7T02NLAS9JAKgdWOHTMBNE6oTMomAzDZ8idH3hCafZS8iFX/7Cn33j9YIa"
    "X77vzNS+qwEvIqBqtDYnSSabQrnN6kd/lGpmhm9w5HSed+daSLW6kGji0sg/OL/3maA0P7c3"
    "kOBr287NTl0PeJ1AiMjE1Awz+cK/WWo1V4gIqzO3YSZoqcTZ3+y7oIUrn39oOv+SXfOPxpIK"
    "KKpKz/IM3bmu8PCwWuKBGaOn/gJ+hXs2fwAzoyUhYVw5Un554z0PPrl//2nAExGlsW7GhFxM"
    "zqtPwvmLE+QLs8Q+qL33dL4Lt5Tnlk4vGg9JqudVjkxOtgIZwjJVIayRBgRRV0Dj5KpkPKqz"
    "qnRnOsl2pWIBV1fCz48R1OpFnYCpOuPj42uBjgjMB8pRLy54lqokRUTNzGIKGJvWtNdA4x2M"
    "N99UyrQ2jEXvUi6XUxHwQquralRJzQMFIA/MAZVQAY0DhukVAwCMO+9cF6uY9XkAEQki8FJk"
    "7ZVYn4/GShGRIEYMT0Ra9+7bk3Jdl0QiEfN9NeqtYSyeDQB+oKRSqVHg9Wjzqgpa+yDyclXs"
    "hTHgP/PrPbtPnjhxVlUXXNFMSqVys6q6ruv64jhBZLKJiDmOqAXB9MjIyN8iaeuM47tcJTX/"
    "BRZJfDTq2jAFAAAAAElFTkSuQmCC")
index.append('actions/python-run-selection')
catalog['actions/python-run-selection'] = actions_python_run_selection

